(* 
File name : linearSearchWithBreakDemo.sml
 
Demo file for proving Linear Search with Break example 
to be used in interactive session.
*)

(* some users may wish to run these first four lines  manually *) 

val xmech_sigobj_loc 	= "../../..";
val env_loc 		= "../";

loadPath := xmech_sigobj_loc :: !loadPath ;
use (env_loc^"PLSEQ_environment.sml");

(* 

Manually construct the info on the type of variables used in the
demo-program. In a real application this info should of course be
constructed automatically by the parser. As it is now, PLSEQ does not
have a declaration section. It is intended to be a part of a larger
language which does have a declaration section. That's the reason why
we now have to construct the typing context by hand.

*)

val varContext_ofDemoProgram =
	let
	val p = TypePara.parseInLine;
	in
	[ ("b", p "bool"), 
	  ("n", p "int"), 
	  ("N", p "int"), 
	  ("a", p "[]int") ] 
	end


(* reading the program now.... *)

val theProgram = parseProgram varContext_ofDemoProgram "linearSearchWithBreak.plseq" ;

(* generating the verification conditions *)

val generatedVCs = genVerificationConditions theProgram ;


(* Starting interactive HOL proof now ... *)

set_goal([], translate2HOL generatedVCs) ;

(* try to simplify the expression *)

e (RW_TAC std_ss [ARRAYREAD_def]
   THEN TRY (UNDISCH_ALL_TAC THEN COOPER_TAC)) ;

(* results in six goals... *)

(* subgoal 1 *)(* this can be automated by selective UNDISCH then call
the cooper *)

val lemma1 = COOPER_PROVE (--`~((n:int)=N) /\ n<=N ==> n<N`--) ;

e(PROVE_TAC [lemma1]) ;

(* subgoal 2 *) (*that is a bit difficult to automate as it requires a
smart choice of a cooper lemma then calling the meson *)

val lemma2 = COOPER_PROVE (--`(i:int)<n+1 = i<n \/ (i=n)`--) ;

e(PROVE_TAC [lemma2]) ;

(* subgoal 3 *)

val lemma3 = COOPER_PROVE (--`0<=(n:int) ==> 0 <= n+1`--) ;

e(PROVE_TAC [lemma3]) ;

(* subgoal 4 *)

val lemma4 = COOPER_PROVE (--`~((n:int)=N) /\ n<=N ==> n+1<=N`--) ;

e(PROVE_TAC [lemma4]) ;

(* subgoal 5 *)

e(PROVE_TAC []) ;

(* subgoal 6 *)

val lemma6 = COOPER_PROVE (--`~((N:int)<N)`--) ;

e(PROVE_TAC [lemma6]) ;


(* alternative *)
(*
e (RW_TAC std_ss [ARRAYREAD_def]
   THEN TRY (UNDISCH_ALL_TAC THEN COOPER_TAC)
   THEN TRY (PROVE_TAC [lemma1,lemma2,lemma3,lemma4,lemma6]));

*)   
