structure ExprHol   = struct
 

(* ============================================================
(*DOC

<MODULE> ExprHol
<AUTHOR> Ade Azurat
<DATE> 9 August 2001

<DESC>Provide transformation from Expr structure (ExprDD.Expr)
into Hol term. 

DOC*)
============================================================ *)

local

open HolKernel Globals Parse goalstackLib listSyntax;
open ExprDD TypeHol exConst Term pairSyntax;

in


(* ============================================================
(*DOC

<ITEM>exprInHol
<TYPE>exprInHol : ExprDD.Expr -> Hol term
<CALL>exprInHol expr

<DESC>Transform expr into Hol term.

DOC*)
============================================================ *)

exception HolFail of string;

exception HolArgFail of (string*Term.term*Term.term);

exception HolExprErr of (string*ExprDD.Expr) ;

fun exprInHol exp  =  
((
  case exp of
    Ident (v,ty)         =>  let val guess = (exConst.TermS (v^":"^(TypeLib.toString ty))
					      handle _ => exConst.TermS ("unknown:'unknown"))
(* raise Fail ("something wrong with : "^v^":"^(TypeLib.toString ty))) *)

				 val tyhol = typeInHol ty 
				 val flag  = (type_of guess)=tyhol
			     in
				(if (flag) then guess else mk_var(v, typeInHol ty) 
                                 handle _ => raise Fail "ExprHol: redefining Identifier.")
			     end
				
  | Lit   (lit,ty)       => (mk_const(lit,typeInHol ty)
                             handle _ =>
				(* naive approach, the exConst mechanisme should be changed totally,
				   wait until starting rearrange the source files, 
				   hopely before Februari 2002 *)  
                               (if (lit="-[]-") then mk_list([],(hd o snd o dest_type o typeInHol) ty) 
				else intLib.term_of_int (Arbint.fromString (lit))
                                handle _ => raise Fail ("ExprHol: Unsupported literal const: "^lit)))
  | ArrayAccess (a,ind)  => let
                                val index = exprInHol ind
                                val array = exprInHol a
				val tyArr = type_of array
	 			val tyEl  = 
					mk_type("fun",[type_of index,
						mk_type("fun",
                                                     [tyArr,hd(snd(dest_type tyArr))])])
                            in	

(* NOTE: I rename EL to ARRAYREAD. The name EL is already used in the
list theory, and since you implemented it not as the list-EL, a fresh
name seems more fitting.

The way we handle arrays is still very crude. Should improve it in the future. 
--Wish.

PS: Ade, you did mk_var EL ... very wrong! It should have been mk_const EL!!
*)

                               (mk_comb(mk_comb(mk_const("ARRAYREAD",tyEl),index),array)
                                handle _ => raise HolFail 
			"ExprHol:Type mismatch or the array theory is not loaded")


(*
                               (mk_comb(mk_comb(mk_const("EL",tyEl),index),array)
                                handle _ => raise HolFail 
			"ExprHol:Type mismatch or the list theory is not loaded")
*)
			      end
  | App (f,a)            => (mk_comb (exprInHol f,exprInHol a)
				handle (HolFail em) => raise HolFail
			(em^"ExprHol:Type mismatch in function application")
				handle _ => raise HolFail
			"ExprHol:Type mismatch in function application")


  | Unary ((idn,ty),ex)  => (exConst.funOp idn ty [exprInHol ex]
				handle (HolFail em) => raise HolFail
			(em^"ExprHol:Type mismatch in unary operator : " ^idn)
				handle _ => raise HolFail
			("ExprHol:Type mismatch in unary operator : " ^idn))

  | Binary((idn,ty),lh,rh)=> (exConst.funOp idn ty [exprInHol lh, exprInHol rh]
			     handle (HolFail x) => raise HolFail x
			     handle _ => raise HolFail
			("ExprHol:Type mismatch in binary operator : "^idn))

  | Quantor((idn,ty),vl,r,p)=> (exConst.funQuan idn ty 
			       (List.map (exprInHol o Ident) vl		, 
				exprInHol r 				,
				exprInHol p				)
			     handle (HolFail em) => raise HolFail em
		     	     handle _ => raise HolFail
			("ExprHol:Type mismatch in quantor : "^idn))

  | Enum ((idn,ty),exl)   =>   (exConst.funOp idn ty 			       
				(List.map exprInHol exl)
			     handle (HolFail em) => raise HolFail em
			     handle _ => raise HolFail
			("ExprHol:Type mismatch in enum operator : "^idn))

  | Tuple (ex1,ex2)       => (mk_pair(exprInHol ex1, exprInHol ex2)
			     handle (HolFail em) => raise HolFail em
			     handle _ => raise HolFail
			("ExprHol:Type mismatch in tuple "))
)  
  handle HOL_ERR _ => raise  HolExprErr (ExprPP.toString 30 exp, exp)
)

end (* end local *)
end (* end struct *)





