structure ExprHolSem  = struct
 

(* ============================================================
(*DOC
 
<MODULE> ExprHolSem
<AUTHOR> underdarkprime & Ade 
<DATE> October 2001

<DESC>Provide transformation from Expr structure (ExprDD.Expr)
into Hol term. Using semantical transformation for visible
operator

<REQUIRED> upredTheory

DOC*)
============================================================ *)

local

open HolKernel Globals BasicProvers Parse goalstackLib Dsyntax Psyntax; 

open ExprDD TypeHol semConst;

in

exception PredFail of (string * Term.term)
exception HolFail of string;
exception HolExprErr of (string* ExprDD.Expr);


val mk_val  = mk_vartype "'val"
val mk_bool = mk_type ("bool",[]);


fun castName (TypeDD.TyVar  x) 	= "var-"^x
 
  | castName (TypeDD.TyCons (nm,[]))    = nm
  | castName (TypeDD.TyCons (_,(a::s))) = 
	raise HolFail "ExprHolSem.CastOper: Only allowing simple type"

fun castOper ty = 
    let
    val nm  = "cast_val2" ^ (castName ty) 
    val ty' = mk_type ("fun",[mk_val,TypeHol.typeInHol ty])
    in
        mk_var (nm,ty')
    end


val lambdaTerm = mk_var("s",mk_type("fun",[mk_vartype "'var",mk_vartype "'val"]));


fun mk_varSem (v,ty) = mk_comb (castOper ty,
                                mk_comb (lambdaTerm, mk_var(v,mk_vartype "'var")))

val exprCastName = (castName o TypeHol.typeFromHol o type_of)

fun cast2pred exprTerm = mk_comb (mk_var ("cast_"^(exprCastName exprTerm)^"2pred", 
                                            mk_type ("fun",[type_of exprTerm, mk_bool])),
                                  exprTerm)

fun typeE expr =
	let
	val sc =
		let
		fun f (v,t,_,_) = (v, TypePara.parseInLine t)
		in 
		map f exConst.context
		end 
	val (n,e) = ExprLib.tyPhaseOne sc  expr
	val (_,subst,ty) = ExprLib.tiInfer0 n [] e
	in
	(ExprLib.tySpec subst e, TypeLib.tySubst subst ty)
	end ;

fun mk_pred (flag,exprTerm) =  
			(* [=] type check, find out the result type,
			   [=] cast the type into val type
			   [=] make abstraction
			*)
			if (flag) 
			then exprTerm
			else mk_abs (lambdaTerm, cast2pred exprTerm) 
			
and mk_flat (flag,exprTerm) = if (flag) 
				then mk_comb(cast2pred exprTerm, lambdaTerm)
				else exprTerm

(* semExprInHol: bool -> Expr -> term ( flat ) 
   in calling this function in order to transform unity specification,
   it initialized with flag = false.

   flag = false, means that it allow encapsulation where needed, once
		 encapsulation occurs, flag become true, saying that,
		its on state predicate term already.

   if flag = true  => flat transformation, without lambda encapsulation. 
		      once it true it would remain true.
		      it reflect ot the condition that, if the flag = true,
		      the term is already inside a lambda encapsulation therefore, 
		      there is no need to make the visible_operator visible,
		      since the hol unification would not recognize it anyway. 
		
   an encapsulation is needed when, a visible operator occurs and its arguments,
   are not in state predicate form, (not encapsulated). 

   The returned value flag is to indicate whether the 
   resulted Term is encapsulted or not,
   false =>  indicate that the term is not in lambda form,(not encapsulated)
   true  =>  indicate that the term allready encapsulated in (\s. X) form

*) 


(* ============================================================
(*DOC

<ITEM>predInHol
<TYPE>predInHol : ExprDD.Expr -> Hol term
<CALL>predInHol  expr

<DESC>Semantical transform expr into Hol state predicate term.
Required the upredTheory library to be loaded first.
DOC*)
============================================================ *)

and predInHol exp = 
    let val (flag,exp') = semExprInHol false [] exp
    in 
	if (flag) 
        then exp'
        else mk_abs(lambdaTerm, cast2pred exp') 

    end

and semExprInHol flag bv exp = 
((
  case exp of
    Ident (nm,ty)         => (false,if (List.exists (fn(x,ty)=>x=nm) bv) 
	                           then ExprHol.exprInHol (Ident (nm,ty))
	                           else mk_varSem (nm, ty)
) 
  | Lit   (lit,ty)       => ((false,mk_const(lit,typeInHol ty))
                             handle _ => 
                               (false,(intLib.term_of_int (Arbint.fromString (lit)))
                                handle _ => raise Fail "ExprHol: Unsupported literal type"))
  | ArrayAccess (a,ind)  => let
                                val index = ExprHol.exprInHol ind
                                val array = ExprHol.exprInHol a
				val tyArr     = type_of array
	 			val tyEl      = 
					mk_type("fun",[type_of index,
						mk_type("fun",
                                                     [tyArr,hd(snd(dest_type tyArr))])])
                            in	
                               ((false,mk_comb(mk_comb(mk_const("ARRAYREAD",tyEl),index),array))
                                handle _ => raise HolFail 
			"ExprHol:Type mismatch or the array theory is not loaded")
			      end
  | App (f,a)            => ((false,mk_comb (ExprHol.exprInHol f,mk_flat (semExprInHol true bv a)))
				handle _ => raise HolFail
			"ExprHol:Type mismatch in function application")

  | Unary ((idn,ty),ex)  => (if ((is_visible idn) andalso flag=false)
				then (true,semConst.funOp idn ty [mk_pred (semExprInHol false bv ex)])
				else (false,exConst.funOp idn ty [mk_flat (semExprInHol true bv ex)])
				handle _ => raise HolFail
			("ExprHol:Type mismatch in unary operator" ^idn))

  | Binary((idn,ty),lh,rh)=> (if ((semConst.is_visible idn) andalso flag=false)
				then (true,
					semConst.funOp idn ty [mk_pred (semExprInHol false bv lh),
			                                       mk_pred (semExprInHol false bv rh)])
				else (false,
					exConst.funOp idn ty [mk_flat (semExprInHol true bv lh), 
							      mk_flat (semExprInHol true bv rh)])
			     handle HolFail x => raise HolFail x
			     handle _ => raise HolFail
			("ExprHol:Type mismatch in binary operator: "^idn))
(* assuming all quantor are visible in HOL *)
  | Quantor((idn,ty),[],r,p)     => raise HolFail 
		      "ExprHolSem: Quantifier may not have zero bounded variable" 
  | Quantor((idn,ty),[v],r,p)    => ((true, (semConst.funQuan idn ty) 
			              [ExprHol.exprInHol (ExprDD.Ident v),  
				       ExprHol.exprInHol r,				       
				       mk_pred (semExprInHol flag (v::bv) p)])
				       handle HOL_ERR _ => raise HolFail
				      ("ExprHolSem:Type mismatch in quantor operator: "^idn))
   | Quantor((idn,ty),(v::vl),r,p)=> ((true,
				       (semConst.funQuan idn ty) 
			                   [ExprHol.exprInHol (ExprDD.Ident v), 
					    ExprHol.exprInHol r, 
					    mk_pred (semExprInHol flag (v::bv)
				                     (Quantor ((idn,ty),vl,r,p)))])
				       handle HOL_ERR _ => raise HolFail
				      ("ExprHolSem:Type mismatch in quantor operator: "^idn))
  
  | Enum ((idn,ty),exl)   =>  ((true, exConst.funOp idn ty
			               (List.map ExprHol.exprInHol exl))
			     handle (HolFail em) => raise HolFail em
			     handle _ => raise HolFail
			("ExprHolSem:Type mismatch in enum operator : "^idn))

    
  | Tuple (ex1,ex2)   => let val (_,ex1') =  semExprInHol true bv ex1
			     val (_,ex2') =  semExprInHol true bv ex2
			in
			(false, 
			 mk_pair (ex1',ex2'))
			     handle (HolFail em) => raise HolFail em
			     handle _ => raise HolFail
			("ExprHolSem:Type mismatch in tuple ")
  			end 
) 
handle HOL_ERR _ => raise HolExprErr ("ExprHolSem.exmExprInHol:",exp))

(* ============================================================
(*DOC

<ITEM>predFromHol
<TYPE>predFromHol :  Hol term -> ExprDD.Expr
<CALL>predFromHol  term

<DESC> Reconstruct a term predicate in Hol into 
our internal representation of expression (parse tree),
by dump the term as a string and the parse it by ExprDD parser.

DOC*)
============================================================= *)

(* top level should be in the form of :
   -> comb   example:   p OR q
   -> abs    example:   \s. int2Pred (1 + (val2int (s "x")) > 5)

problem :

  >  How to remove the abstraction of predicate level.
  >  How to remove the casting operator.
  >  How to remove the bounded variable safely.
  >  How to transform the term form into a term form that can be recognized by the parser. 
  >  How to simplify things and make use of Parse.term_to_string function.
  >  How to bridge the syntax different between two representation, hol and our. 


alternatif :
  >  working on the term level, indicate all term that have abstraction, and remove it.
     consequences: required extra type control, to make the mk_comb succed, also required double
     parse which is not efficient.
     working on the term level required the removing of the abstraction has to be done together
     with the removing of casting operator. 
     Mapping term operator to which Expr constructor, should be implemented in low level,
     ( low level mean as a function over data structure ) 

  >  working on the character level, might have problem identifying the bounded variable. 
     we need to read a arbitrary sequences of character rather than just one character 
     in each run.

  >  working on the word list, (list of string) like a scanner. 
     required a function to build the list. (easy). 
     Might adopt the Parse library parser and pp. 


decision the third alternatif, re modify parse hol library. 
result : not nice to much thing to do, while ignoring some information 
that already exists such as type informatio in casting operator.

Now: Try the first alternatif again.

PredFromHol : term -> ExprDD.Expr
PredFromHol

algorithm : 

identify which type of term it is.
for a predicate term  it should be either is_comb or is_abs.

is_comb  ->  dest_comb,... recursive for the second arg,
             *unfold* the first argument, get the operator name, recursively over its argument.
             Construct the ExprDD. 

is_abs   ->  Remove the lambda part. Remove the predicate casting, save the type information.
	     Destruct the second argument by applying termFrom Hol which ignoring/removing the 
	     existence of lambda bound variable, casting operator, state application (e.g. s x). 

unfold: term -> (string * ExprDD.Expr)  
unfold   ->  check whether its a is_comb or a is_const. if is_comb then recursively apply unfold
	     on its first argument. otherwise if is_const, return the name. and its argument if exists.

termFromHol: string list -> TypeDD.Type  -> Term -> (ExprDD.Expr,TypeDD.Type) 
termFromHol -> destruct the term and build the Expr and it's type.
               The term could be in the form of 
		is_comb  -> apply recursive for both side, get the operator construction from the 
					first argument.
		is_const -> identify the const if it is the casting operator, get the type.
			    identify if the constant were integer, match it with the type.
		is_basic operator such as is_imp,is_eq,is_disj etc, get the correspondence contructor.
		is_var -> build the identifier with the given type information. 
		is_abs -> apply predFromHol.

*)
(* removing the lambda abstraction *)
(* dest_abs : term -> term *)

(* receive the lambda abstraction, output the lambda name in string  
val getLambda : term -> string
*)




val getLambda  = ((fn (x,y)=> (x,TypeHol.typeFromHolSem y)) o dest_var) 

(* getOperator : term -> (string * Term.term list )
   get the operator string name, 
   and get the argument for the operator if exists otherwise empty list *)

fun isCast nm = (String.isPrefix "cast_val2" nm) orelse (String.isPrefix "cast_" nm)

fun getResType (TypeDD.TyCons ("fun",[x,y])) = y
  | getResType ty = ty

fun getOperator te = 
         if (is_const te) then let val (nm,ty) = dest_const te
			       in (nm,TypeHol.typeFromHolSem ty,[]) end

    (* required some checking whether the operator an operator or a casting operator *)
    else if (is_var   te) then let val (nm,ty) = dest_var te
			       in
				   if (isCast nm)
			           then (semConst.CASTOPERATOR,(getResType o TypeHol.typeFromHol) ty,[]) 
			           else (nm,TypeHol.typeFromHol ty,[]) 
				end

    else if (is_comb  te) then let val (arg1,arg2) = dest_comb te
				   val (oper,ty',argl) = getOperator arg1
			       in  (oper,ty',argl@[arg2]) end

    else raise PredFail ("ExprHolSem.getOperator: No operator symbol found",te)
;
(*
val termFromHol = fn :
  (string * Type) list -> term -> Expr * (string * Type) list
*)


fun  termFromHol strList te = 

    if (semConst.is_number te) then let val (lit,tyHol) = semConst.dest_number te
                                    in (ExprDD.Lit (lit,typeFromHolSem tyHol),[]) end
    else if (is_pair te)  then let val (arg1,arg2) = dest_pair te		 	           
			           val (arg1',vl1) = termFromHol strList arg1
				   val (arg2',vl2) = termFromHol strList arg2
			           val varL        = MoreList.nub (vl1 @ vl2)
 			      in 
			          (ExprDD.Tuple(arg1',arg2'), varL) 
			      end  
    else if (is_var te) then let val (nm, ty') = dest_var te
	 		     in   (ExprDD.Ident (nm, typeFromHolSem ty'),strList) 
    (* no need to check casting operator, it would be handled in getOperator *)
			     end
    else if (is_const te) then let val (nm, ty') = dest_const te
			       in   if (nm="T" orelse nm="F") 
				    then (ExprDD.Lit (nm, typeFromHolSem ty'),strList)  
				    else (ExprDD.Ident (nm, typeFromHolSem ty'),strList)  
			       end
    else if (is_comb te)  then let val (arg1,arg2) = dest_comb te
		 	           val (oper,ty',argl) = getOperator arg1
			           val expvarL  = (List.map (termFromHol strList) (argl @ [arg2]))
			           val expL     = List.map fst expvarL
			           val varL     = (snd o List.last) expvarL
			   	   val oper'    = if (MoreList.elem (oper,ty') varL) 
					          then semConst.STATEVAR
					          else oper
			      in 
			          (semConst.exprConst (oper',ty') expL varL,varL) 
			      end
    else if (is_abs te ) then let val (lam,bod) = dest_abs te;
				  val (lnm,lty) = getLambda lam;				  
				  val strList'  = (lnm,lty)::strList
			          
			      in
					termFromHol strList' bod
			      end 

    else raise PredFail ("ExprHolSem.termFromHol: unrecognized term",te)

;

(* ============================================================
(*DOC

<ITEM> 
<TYPE>
<CALL>

<DESC> Reconstruct a term predicate in Hol into 
our internal representation of expression (parse tree).
Flag is used to choose whether the J (invariant) need to be 
unfolded or not  

DOC*)
============================================================ *)

fun predFromHol et = fst (termFromHol [] et) 




end (* end local *)
end (* end struct *)





