structure ExprPP :> ExprPP = struct

local

open PP ExprDD 

in

fun ppVar tyFlag pps (x,ty)
	=
	if tyFlag then (add_string pps ("(" ^ x ^ ":")	;
			TypePP.ppType pps ty		;
			add_string pps ")"		)
		  else add_string pps x

fun ppVarList tyFlag pps [v]	 = ppVar tyFlag pps v
  | ppVarList tyFlag pps (v::vs) 
	=
	(ppVar tyFlag pps v 				;
	 add_string pps ", "				;
	 ppVarList tyFlag pps vs			)
 

fun ppExpr tyFlag pps expression = case expression of

	  Ident v 	=> ppVar tyFlag pps v
		
	| Lit x  	=> ppVar tyFlag pps x

(*
	| ArrayAccess (a,i) => 
			(begin_block pps INCONSISTENT 0 ;
			 ppExpr tyFlag pps a		;
			 add_break pps (0,3)		;
			 add_string pps "[" 		;
			 ppExpr tyFlag pps i 		;
			 add_string pps "]"		;
			 end_block pps			)

*)
	| ArrayAccess (a,i) => 
			(ppExpr tyFlag pps a		;
			 add_string pps "#" 		;
			 ppExpr tyFlag pps i 		)

	| App (f,x) => 
			(begin_block pps INCONSISTENT 0	;
			 add_string pps "("		;
			 ppExpr tyFlag pps f		;
			 add_break pps (1,3)		;
(*			 add_string pps ">> "		; *)
			 ppExpr tyFlag pps x 		;
			 add_string pps ")"		;
			 end_block pps			)


	| Unary (opr,x) =>
			(begin_block pps INCONSISTENT 0	;
			 ppVar tyFlag pps opr		;
			 add_break pps (1,3)		;
			 ppExpr tyFlag pps x 		;
			 end_block pps			)
	
	| Binary (opr,x,y) =>
			(begin_block pps CONSISTENT 0 		;
		         add_string pps "("			;
			 ppExpr tyFlag pps x 			;  
			 add_break pps (1,3) 			;
			 ppVar tyFlag pps opr			;
			 add_break pps (1,3) 			;
			 ppExpr tyFlag pps y			; 
			 add_string pps ")"			;
			 end_block pps 				)


	| Quantor (qtr,vs,e,f) => 
			(begin_block pps CONSISTENT 0 		;
         		 add_string pps "(" 			;
			 ppVar false pps qtr			;
			 ppVarList tyFlag pps vs		;
			 add_string pps ":"			;
	 		 add_break pps (1,3) 			;
	 		 ppExpr tyFlag pps e			;
			 add_string pps ":"			;
	 		 add_break pps (1,3) 			;
			 ppExpr tyFlag pps f			;
			 add_string pps ")"			;
			 end_block pps 				)


	| Enum ((enr,ty),es) => 
		let
		val (LeftBrac,RightBrac) = exConst.getEnumBrackets enr	;
		in
			(begin_block pps INCONSISTENT 0 	;
			 if tyFlag then add_string pps "(" else () ;
         		 add_string pps LeftBrac		;
			 ppExprList tyFlag pps es		;
			 add_string pps RightBrac		;
			 if tyFlag 
				then (add_string pps ")"   	;
				      TypePP.ppType pps ty 	)
				else () 			;
			 end_block pps 				)
		end
	| Tuple (e1,e2) => 
			(begin_block pps INCONSISTENT 0	;
			 add_string pps "("		;
			 ppExpr tyFlag pps e1		;
			 add_break pps (1,3)		;
			 add_string pps ", "		; 
			 ppExpr tyFlag pps e2 		;
			 add_string pps ")"		;
			 end_block pps			)



    and

    ppExprList tyFlag pps [] 		= ()
  | ppExprList tyFlag pps (e::es) 	=
			(ppExpr tyFlag pps e 			;
			 add_string pps ","			;
			 add_break pps (1,5)			;
			 ppExprList tyFlag pps es		)

fun toString n x = PP.pp_to_string n (ppExpr true) x 		;

 
end
end
