structure MoreList = struct

(*====================================================================
(*DOC

<MODULE>MoreList
<AUTHOR>underdarkPrime
<ADDRESS>underdarkPrime@yahoo@com
<DATE>august 2001

<DESC>Provide some additional list functions.

DOC*)
====================================================================*)

(*DOC
<ITEM>nub
<TYPE>nub : 'a list -> 'list
<DESC><tt>nub s</tt> removes duplicate elements from the list s.
DOC*)

fun nub [] = []
  | nub [x] = [x]
  | nub (x::s) = x :: nub (List.filter (fn y=> y<>x) s)

(*DOC
<ITEM>elem
<TYPE>elem : 'a -> 'a list -> bool
<DESC><tt>elem x s</tt> tests if x is an element of the list s.
DOC*)

fun elem x s = List.find (fn y=> x=y) s <> NONE

(*DOC
<ITEM>takeWhile
<TYPE>takeWhile : ('a->bool)->'a list->'a list
<DESC><tt>takeWhile p s</tt> returns the longest prefix of s whose elements satisfies p.
DOC*)

fun takeWhile p [] = []
  | takeWhile p (x::s) 
	= 
	if p x 
	then x :: takeWhile p s 
	else []
(*DOC
<ITEM>dropWhile
<TYPE>dropWhile : ('a->bool)->'a list->'a list

<DESC><tt>dropWhile p s</tt> returns the rest of the list after the
prefix of s returned by <tt>takeWhile p s</tt> is dropped

DOC*)

fun dropWhile p [] = []
  | dropWhile p (s as (x::t))
	=
	if p x 
	then dropWhile p t
	else s

(*DOC
<ITEM>split
<TYPE>split : ('a->bool)->'a list->('a list * 'a list)

<DESC><tt>split p s</tt> returns the pair <tt>(dropWhile p s, takeWhile p s)</tt>.

DOC*)

fun split p [] = ([],[])
  | split p (s as (x::t)) 
	=
	if p x
	then let
	     val (u,v) = split p t
	     in
	     (x::u, v)
	     end
	else ([],s)
(*DOC

<ITEM>intersect
<TYPE>intersect : 'a list -> 'a list -> 'a list 
<DESC><tt>intersect s t</tt> returns the list of all elements which are both in s and in t. Duplicates are removes.

DOC*)

fun intersect s t =
	let
	fun p x = elem x t
	in
	nub (List.filter p s)
	end
	
end

