structure PLGADD = struct

(* ============================================================
(*DOC

<MODULE>PLGADD
<AUTHOR>underdarkPrime
<ADRESS>underdarkPrime@yahoo.com
<DATE>august 2001

<DESC> This module provides the abstract representation of PLGA
programs and specifications. <b>PLGA</b> is an abbreviation of
<i>Programming Logic for Guarded Actrons</i>. Action is executed in a
distributed environment. The difference between ordinary statements in
the sequential setup is that an action blocks (suspends) itself as
long as its guard is false. <p>

The language of PLGA consists of the language of programs, which is
used to express or write a program, and a specification language which
is used to express a specification of a program. The programming
language is C-like; it is a superset of the programming language part
of PLSEQ.  It also has much of the flavour of a language called
Promela. In the future we hope to make a better connection with
Promela because Promela enjoys the support of a sophisticated model
checker called Spin for verification. <p>

The specification language is a simple Hoare triple language. <p>

DOC*)
============================================================ *)

local 

open ExprDD PLSEQDD

in

datatype BlockingFlag = ElseBlock | ElseExit

datatype 'info PLGA_Stmt =
     Send			of (Expr * string * Expr) * 'info
   | Rec			of (Expr * string * string) * 'info
   | Goto			of (Expr * string) * 'info
   | Atomic			of (Expr * Stmt) * 'info
   | Block			of ('info PLGA_Stmt list) * 'info
   | Alt			of ('info PLGA_Stmt list * BlockingFlag) * 'info
   | Loop			of ('info PLGA_Stmt list * BlockingFlag) * 'info

datatype LabelCond = ALL | LABELS of string list

type LabelExpr = (LabelCond * Expr) list

datatype PLGA_Spec =
     tempBinop	of string * LabelExpr * LabelExpr
(*
   | wpOP	of string * LabelExpr * LabelExpr * LabelExpr * Expr     
*)


end
end
