structure PLGAPP  = struct


(* ============================================================
(*DOC

<MODULE> PLSEQPP
<AUTHOR>underdarkprime & ade 
<ADRESS>underdarkPrime@yahoo.com & ade@cs.uu.nl
<DATE> 9 August 2001

<DESC>Provide pretty printing for PLGA structure.

DOC*)
============================================================ *)

local

open PP PLGADD PLSEQPP ExprPP ExprDD

in

fun add_semicolon pps               = add_string pps ";" 

val ppExprF = ExprPP.ppExpr false

fun iftrue (Lit("T",_)) = true
  | iftrue _            = false 

and ppInfo pps info = if (info="") then ()
                                   else add_string pps ("["^info^"] : ") 

and ppGuard pps e0 info = (ppInfo pps info                           ;
                           if (iftrue e0) 
	                               then ()
                                       else (ppExprF pps e0          ;
                                             add_break pps (1,5)     ;
	                                     add_string pps "->"     ))

and ppBlockFlag_ pps ElseBlock = add_string pps "else block"
  | ppBlockFlag_ pps ElseExit = add_string pps "else exit"
and ppBlockFlag pps bf = (begin_block pps CONSISTENT ; 
                          ppBlockFlag_ pps bf        ;
                          end_block pps              )

and ppAlt pps [s]     = (add_string pps "::"                    ;
                         add_break pps (1,3)                    ;
                         ppPLGA_Stmt pps s                      ;
                         add_newline pps                        )
  | ppAlt pps (s::ss) = (ppAlt pps [s] ; ppAlt pps ss )


and ppBlock pps [s]     = (ppPLGA_Stmt pps s; add_string pps ";")
  | ppBlock pps (s::ss) = (ppBlock pps [s]  ; ppBlock pps ss)

and ppPLGA_Stmt pps statement = 
       (begin_block pps INCONSISTENT                   ;
                
        case statement of
	     Send ((e0,c,e1),info) => (ppGuard pps e0 info    ;
                                       add_string pps (c^"!") ;
	                               ppExprF pps e1         )
	   | Rec  ((e0,c,v),info)  => (ppGuard pps e0 info    ;
                                       add_string pps (c^"?") ;
	                               add_string pps v       )
	   | Goto ((e0,st),info)   => (ppGuard pps e0 info    ;
                                       add_string pps ("goto "^st))
	   | Atomic ((e0,st),info) => (ppGuard pps e0 info    ;
                                       ppStmt false pps st    )
	   | Block (l,info)        => (ppInfo pps info        ;
                                       add_string pps "{"     ;
	                               add_break pps (0,3)    ;
	                               ppBlock pps l          ;
	                               add_newline pps        ;
	                               add_string pps "}"     )
	   | Alt ((l,bf), info)    => (ppInfo pps info        ;
                                       add_string pps "if"    ;
	                               add_break pps (0,3)    ;
	                               ppAlt pps l            ;
	                               ppBlockFlag pps bf     ;     
	                               add_string pps "fi"    )           
	   | Loop ((l,bf),info)    => (ppInfo pps info        ;
	                               add_string pps "do"    ;
	                               add_break pps (0,3)    ;
	                               ppAlt pps l            ;
	                               ppBlockFlag pps bf     ;     
	                               add_string pps "od"    )      
	   ;
        end_block pps)

         
end
end

(*

val ppstrm = mk_ppstream {consumer  = fn s => TextIO.output(TextIO.stdOut, s),
                          linewidth = 80,
                          flush     = 
	                  fn () => TextIO.flushOut TextIO.stdOut} ;

fun pp e = (PLGAPP.ppPLGA_Stmt  ppstrm e ; flush_ppstream ppstrm ; print "\n")  ;

*)
