local
in
datatype token =
    AND
  | ARRAYACCESS
  | ATOMIC
  | BLOCK_TOK
  | BOOL
  | CASE
  | COLON
  | COMA
  | CONS
  | CONSTANT
  | DEFAULT
  | DIV
  | DIVIDE
  | DO
  | ELEM
  | ELSE
  | EOF
  | EQUAL
  | EXISTS
  | EXIT_TOK
  | FI
  | FOR
  | FORALL
  | FUNAPP
  | GOTO
  | GT
  | GTE
  | IDENT of string
  | IF
  | IMPLIES
  | IN
  | INSERT
  | INT
  | INTERSECT
  | INV
  | IS_FROM
  | LACOL
  | LHOABRAC
  | LIT_EMPTYLIST
  | LIT_EMPTYSET
  | LIT_FALSE
  | LIT_I of string
  | LIT_TRUE
  | LLISTBRAC
  | LPAR
  | LSBRAC
  | LSETBRAC
  | LT
  | LTE
  | MAX
  | MIN
  | MINMIN
  | MINUS
  | MOD
  | NOT
  | NTH
  | OD
  | OR
  | PLUS
  | PLUSPLUS
  | POWER
  | RACOL
  | RHOABRAC
  | RIGHTARROW
  | RLISTBRAC
  | RPAR
  | RSBRAC
  | RSETBRAC
  | SEMI
  | SET
  | SKIP
  | SWITCH
  | THEN
  | TIMES
  | TUPLE_RULE
  | UNION
  | WHILE
end;

open Obj Parsing;
prim_val vector_ : int -> 'a -> 'a Vector.vector = 2 "make_vect";
prim_val update_ : 'a Vector.vector -> int -> 'a -> unit = 3 "set_vect_item";


open TypeDD ExprDD PLSEQDD PLGADD

val type_a	= TyVar  "a"
val type_int	= TyCons ("int", [])
val type_bool	= TyCons ("bool", [])
val type_string	= TyCons ("string", [])

fun mkUnary opr e    = Unary  ((opr, type_a), e)
fun mkBinary opr e f = Binary ((opr, type_a), e, f)
fun mkQuantor qtr vs e f = Quantor ((qtr, type_a),vs,e,f)
fun mkEnum enr es = Enum ((enr, type_a), es)

val mk_T = Lit ("T", type_bool)

fun addLabel lab stmt = case stmt of
	  Send (z,_)		=> Send (z,lab)
	| Rec (z,_)		=> Rec (z,lab)
	| Goto (z,_)		=> Goto (z,lab)
	| Atomic (z,_)		=> Atomic (z,lab)
	| Block (z,_)		=> Block (z,lab)
	| Alt (z,_)		=> Alt (z,lab)
	| Loop (z,_)		=> Loop (z,lab)


(* Line 31, file PLGAParser.sml *)
val yytransl = #[
  257 (* AND *),
  258 (* ARRAYACCESS *),
  259 (* ATOMIC *),
  260 (* BLOCK_TOK *),
  261 (* BOOL *),
  262 (* CASE *),
  263 (* COLON *),
  264 (* COMA *),
  265 (* CONS *),
  266 (* CONSTANT *),
  267 (* DEFAULT *),
  268 (* DIV *),
  269 (* DIVIDE *),
  270 (* DO *),
  271 (* ELEM *),
  272 (* ELSE *),
  273 (* EOF *),
  274 (* EQUAL *),
  275 (* EXISTS *),
  276 (* EXIT_TOK *),
  277 (* FI *),
  278 (* FOR *),
  279 (* FORALL *),
  280 (* FUNAPP *),
  281 (* GOTO *),
  282 (* GT *),
  283 (* GTE *),
  284 (* IDENT *),
  285 (* IF *),
  286 (* IMPLIES *),
  287 (* IN *),
  288 (* INSERT *),
  289 (* INT *),
  290 (* INTERSECT *),
  291 (* INV *),
  292 (* IS_FROM *),
  293 (* LACOL *),
  294 (* LHOABRAC *),
  295 (* LIT_EMPTYLIST *),
  296 (* LIT_EMPTYSET *),
  297 (* LIT_FALSE *),
  298 (* LIT_I *),
  299 (* LIT_TRUE *),
  300 (* LLISTBRAC *),
  301 (* LPAR *),
  302 (* LSBRAC *),
  303 (* LSETBRAC *),
  304 (* LT *),
  305 (* LTE *),
  306 (* MAX *),
  307 (* MIN *),
  308 (* MINMIN *),
  309 (* MINUS *),
  310 (* MOD *),
  311 (* NOT *),
  312 (* NTH *),
  313 (* OD *),
  314 (* OR *),
  315 (* PLUS *),
  316 (* PLUSPLUS *),
  317 (* POWER *),
  318 (* RACOL *),
  319 (* RHOABRAC *),
  320 (* RIGHTARROW *),
  321 (* RLISTBRAC *),
  322 (* RPAR *),
  323 (* RSBRAC *),
  324 (* RSETBRAC *),
  325 (* SEMI *),
  326 (* SET *),
  327 (* SKIP *),
  328 (* SWITCH *),
  329 (* THEN *),
  330 (* TIMES *),
  331 (* TUPLE_RULE *),
  332 (* UNION *),
  333 (* WHILE *),
    0];

val yylhs = "\255\255\
\\001\000\012\000\012\000\012\000\012\000\012\000\012\000\012\000\
\\012\000\012\000\012\000\012\000\012\000\012\000\012\000\012\000\
\\012\000\012\000\012\000\012\000\012\000\012\000\012\000\012\000\
\\012\000\012\000\012\000\012\000\012\000\012\000\012\000\012\000\
\\012\000\012\000\012\000\012\000\012\000\012\000\012\000\012\000\
\\012\000\012\000\014\000\014\000\016\000\016\000\015\000\015\000\
\\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\\008\000\008\000\009\000\011\000\011\000\010\000\010\000\002\000\
\\002\000\003\000\003\000\003\000\003\000\005\000\005\000\006\000\
\\006\000\007\000\007\000\004\000\004\000\004\000\004\000\004\000\
\\004\000\013\000\013\000\000\000";

val yylen = "\002\000\
\\002\000\001\000\003\000\001\000\001\000\001\000\001\000\001\000\
\\003\000\003\000\003\000\003\000\002\000\003\000\003\000\003\000\
\\008\000\008\000\003\000\003\000\003\000\003\000\003\000\003\000\
\\003\000\003\000\003\000\003\000\003\000\003\000\005\000\003\000\
\\003\000\003\000\003\000\003\000\003\000\003\000\003\000\008\000\
\\003\000\005\000\001\000\003\000\001\000\003\000\001\000\003\000\
\\002\000\002\000\003\000\003\000\003\000\006\000\008\000\008\000\
\\007\000\013\000\003\000\000\000\005\000\002\000\003\000\005\000\
\\001\000\001\000\003\000\006\000\006\000\002\000\003\000\002\000\
\\003\000\001\000\001\000\003\000\002\000\004\000\004\000\004\000\
\\003\000\000\000\004\000\002\000";

val yydefred = "\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\084\000\
\\000\000\065\000\066\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\002\000\004\000\005\000\008\000\006\000\007\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\001\000\000\000\000\000\
\\000\000\077\000\000\000\000\000\000\000\000\000\067\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\076\000\081\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\071\000\003\000\000\000\035\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\011\000\041\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\083\000\000\000\000\000\000\000\000\000\
\\000\000\050\000\049\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\080\000\000\000\073\000\074\000\075\000\000\000\000\000\
\\048\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\064\000\000\000\000\000\000\000\000\000\000\000\000\000\052\000\
\\000\000\069\000\068\000\046\000\000\000\000\000\000\000\000\000\
\\042\000\031\000\000\000\000\000\000\000\063\000\000\000\000\000\
\\000\000\000\000\044\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\017\000\
\\018\000\040\000\000\000\000\000\057\000\000\000\000\000\000\000\
\\055\000\000\000\000\000\000\000\056\000\000\000\000\000\059\000\
\\000\000\061\000\000\000\000\000\058\000";

val yydgoto = "\002\000\
\\008\000\035\000\010\000\011\000\016\000\036\000\143\000\134\000\
\\200\000\135\000\191\000\041\000\012\000\151\000\042\000\094\000";

val yysindex = "\008\000\
\\212\255\000\000\002\255\011\255\212\255\003\006\003\255\000\000\
\\016\255\000\000\000\000\075\255\212\255\212\255\225\254\233\254\
\\012\255\000\000\000\000\000\000\000\000\000\000\000\000\003\006\
\\196\005\003\006\003\006\199\005\231\254\000\000\194\255\046\255\
\\255\254\000\000\077\255\079\255\081\255\212\255\000\000\084\255\
\\006\006\034\255\076\255\076\255\076\255\136\005\039\255\005\255\
\\003\006\003\006\003\006\003\006\003\006\003\006\003\006\003\006\
\\003\006\003\006\003\006\003\006\003\006\003\006\003\006\003\006\
\\003\006\003\006\003\006\003\006\003\006\003\006\003\006\045\255\
\\003\006\003\006\103\255\065\255\068\255\003\006\194\255\091\255\
\\000\000\000\000\003\006\093\255\003\006\212\255\004\255\004\255\
\\000\000\000\000\003\006\000\000\111\255\117\255\133\255\137\255\
\\003\006\003\006\000\000\000\000\084\010\000\000\216\003\078\255\
\\246\009\000\000\078\255\078\255\246\009\078\255\084\010\008\255\
\\078\255\078\255\072\003\072\003\008\255\216\003\074\255\053\010\
\\008\255\074\255\005\255\000\000\010\255\074\255\162\255\003\006\
\\003\006\000\000\000\000\003\006\212\002\080\255\083\255\003\006\
\\183\009\000\000\183\009\000\000\000\000\000\000\098\255\126\255\
\\000\000\076\255\003\006\003\006\003\006\069\006\092\255\132\006\
\\000\000\183\009\183\009\195\006\105\255\114\255\194\255\000\000\
\\002\007\000\000\000\000\000\000\065\007\128\007\191\007\003\006\
\\000\000\000\000\095\255\135\255\003\006\000\000\127\255\003\006\
\\003\006\003\006\000\000\194\255\147\255\254\007\163\255\061\008\
\\124\008\187\008\157\255\003\006\194\255\003\006\166\255\000\000\
\\000\000\000\000\194\255\250\008\000\000\057\009\172\255\123\255\
\\000\000\003\006\194\255\194\255\000\000\120\009\163\255\000\000\
\\194\255\000\000\120\255\194\255\000\000";

val yyrindex = "\000\000\
\\086\255\000\000\000\000\000\000\086\255\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\086\255\086\255\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\153\255\000\000\000\000\
\\204\254\000\000\000\000\000\000\000\000\000\000\000\000\079\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\090\255\000\000\000\000\
\\000\000\000\000\000\000\000\000\182\255\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\052\004\186\255\020\003\070\004\
\\114\010\007\000\142\004\160\004\019\255\232\004\250\004\039\001\
\\066\005\084\005\092\003\164\003\111\001\236\003\255\001\145\010\
\\183\001\071\002\151\000\000\000\223\000\143\002\086\255\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\253\254\000\000\006\255\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\124\255\000\000\000\000\
\\000\000\171\002\109\005\000\000\000\000\000\000\138\255\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\195\255\000\000\
\\000\000\000\000\053\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\195\255\000\000\
\\000\000\000\000\000\000\000\000\000\000";

val yygindex = "\000\000\
\\000\000\115\000\078\000\000\000\171\000\243\255\123\000\227\255\
\\000\000\055\000\012\000\250\255\000\000\057\000\235\255\215\255";

val YYTABLESIZE = 3038;
val yytable = "\028\000\
\\037\000\081\000\095\000\096\000\047\000\078\000\050\000\141\000\
\\001\000\050\000\013\000\050\000\047\000\078\000\079\000\047\000\
\\083\000\084\000\046\000\014\000\048\000\085\000\079\000\142\000\
\\016\000\016\000\016\000\016\000\054\000\016\000\029\000\054\000\
\\030\000\054\000\016\000\016\000\016\000\038\000\039\000\040\000\
\\016\000\075\000\101\000\102\000\103\000\104\000\105\000\106\000\
\\107\000\108\000\109\000\110\000\111\000\112\000\113\000\114\000\
\\115\000\116\000\117\000\118\000\119\000\120\000\121\000\122\000\
\\123\000\078\000\125\000\126\000\071\000\145\000\071\000\133\000\
\\140\000\082\000\079\000\050\000\137\000\031\000\139\000\050\000\
\\016\000\073\000\128\000\016\000\016\000\086\000\016\000\016\000\
\\082\000\051\000\150\000\152\000\082\000\090\000\087\000\016\000\
\\088\000\054\000\092\000\032\000\129\000\054\000\033\000\093\000\
\\164\000\072\000\100\000\060\000\124\000\127\000\082\000\060\000\
\\132\000\082\000\082\000\009\000\130\000\082\000\146\000\015\000\
\\138\000\154\000\155\000\147\000\131\000\156\000\065\000\063\000\
\\064\000\161\000\065\000\066\000\069\000\067\000\071\000\136\000\
\\069\000\070\000\071\000\148\000\165\000\166\000\167\000\149\000\
\\160\000\034\000\163\000\073\000\159\000\172\000\187\000\073\000\
\\015\000\074\000\162\000\082\000\082\000\169\000\173\000\197\000\
\\082\000\150\000\181\000\183\000\188\000\201\000\182\000\180\000\
\\190\000\184\000\185\000\186\000\195\000\207\000\208\000\003\000\
\\199\000\082\000\204\000\211\000\082\000\196\000\213\000\198\000\
\\205\000\212\000\009\000\009\000\045\000\043\000\004\000\009\000\
\\009\000\009\000\009\000\206\000\009\000\009\000\005\000\062\000\
\\009\000\009\000\009\000\009\000\153\000\060\000\006\000\009\000\
\\089\000\009\000\144\000\009\000\009\000\174\000\070\000\009\000\
\\009\000\009\000\210\000\009\000\000\000\076\000\077\000\082\000\
\\179\000\003\000\000\000\000\000\078\000\000\000\079\000\000\000\
\\000\000\009\000\009\000\009\000\009\000\000\000\009\000\009\000\
\\004\000\009\000\000\000\009\000\009\000\009\000\009\000\009\000\
\\005\000\000\000\009\000\009\000\000\000\009\000\009\000\000\000\
\\006\000\007\000\000\000\009\000\000\000\009\000\009\000\010\000\
\\010\000\080\000\000\000\000\000\010\000\010\000\010\000\010\000\
\\000\000\010\000\010\000\000\000\000\000\010\000\010\000\010\000\
\\010\000\000\000\000\000\000\000\010\000\000\000\010\000\000\000\
\\010\000\010\000\000\000\000\000\010\000\010\000\010\000\000\000\
\\010\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\010\000\010\000\
\\010\000\010\000\054\000\010\000\010\000\054\000\010\000\054\000\
\\010\000\010\000\010\000\010\000\010\000\054\000\000\000\010\000\
\\010\000\000\000\010\000\010\000\000\000\000\000\000\000\013\000\
\\010\000\000\000\010\000\010\000\013\000\013\000\013\000\013\000\
\\000\000\013\000\013\000\000\000\000\000\013\000\013\000\013\000\
\\013\000\000\000\000\000\000\000\013\000\000\000\000\000\000\000\
\\013\000\013\000\000\000\000\000\013\000\013\000\013\000\000\000\
\\013\000\000\000\054\000\000\000\000\000\000\000\054\000\000\000\
\\000\000\054\000\000\000\000\000\000\000\000\000\013\000\013\000\
\\013\000\013\000\000\000\013\000\013\000\000\000\013\000\000\000\
\\013\000\013\000\013\000\013\000\013\000\000\000\000\000\013\000\
\\013\000\000\000\013\000\013\000\000\000\000\000\000\000\028\000\
\\013\000\000\000\013\000\013\000\028\000\028\000\028\000\028\000\
\\000\000\028\000\028\000\000\000\000\000\028\000\028\000\028\000\
\\028\000\000\000\000\000\000\000\028\000\000\000\000\000\000\000\
\\028\000\028\000\000\000\000\000\028\000\028\000\028\000\000\000\
\\028\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\028\000\028\000\
\\028\000\028\000\000\000\028\000\028\000\000\000\028\000\000\000\
\\028\000\028\000\028\000\028\000\028\000\000\000\000\000\028\000\
\\028\000\000\000\028\000\028\000\000\000\000\000\000\000\026\000\
\\028\000\000\000\028\000\028\000\026\000\026\000\026\000\026\000\
\\000\000\026\000\026\000\000\000\000\000\026\000\026\000\026\000\
\\026\000\000\000\000\000\000\000\026\000\000\000\000\000\000\000\
\\026\000\026\000\000\000\000\000\026\000\026\000\026\000\000\000\
\\026\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\026\000\026\000\
\\026\000\026\000\000\000\026\000\026\000\000\000\026\000\000\000\
\\026\000\026\000\026\000\000\000\026\000\000\000\000\000\026\000\
\\026\000\000\000\026\000\026\000\000\000\000\000\000\000\038\000\
\\026\000\000\000\026\000\026\000\038\000\038\000\038\000\038\000\
\\000\000\038\000\038\000\000\000\000\000\038\000\038\000\038\000\
\\038\000\000\000\000\000\000\000\038\000\000\000\000\000\000\000\
\\038\000\038\000\000\000\000\000\038\000\038\000\038\000\000\000\
\\038\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\038\000\038\000\
\\038\000\038\000\000\000\038\000\038\000\000\000\038\000\000\000\
\\038\000\038\000\038\000\000\000\038\000\000\000\000\000\038\000\
\\038\000\000\000\038\000\038\000\000\000\000\000\000\000\027\000\
\\000\000\000\000\038\000\038\000\027\000\027\000\027\000\027\000\
\\000\000\027\000\027\000\000\000\000\000\027\000\027\000\027\000\
\\027\000\000\000\000\000\000\000\027\000\000\000\000\000\000\000\
\\027\000\027\000\000\000\000\000\027\000\027\000\027\000\000\000\
\\027\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\027\000\027\000\
\\027\000\027\000\000\000\027\000\027\000\000\000\027\000\000\000\
\\027\000\027\000\027\000\000\000\027\000\000\000\000\000\027\000\
\\027\000\000\000\027\000\027\000\000\000\000\000\000\000\025\000\
\\000\000\000\000\027\000\027\000\025\000\025\000\025\000\025\000\
\\000\000\025\000\025\000\000\000\000\000\025\000\025\000\025\000\
\\025\000\000\000\000\000\000\000\025\000\000\000\000\000\000\000\
\\025\000\025\000\000\000\000\000\025\000\025\000\025\000\000\000\
\\025\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\025\000\025\000\
\\025\000\025\000\000\000\025\000\025\000\000\000\025\000\000\000\
\\025\000\025\000\025\000\000\000\025\000\000\000\000\000\025\000\
\\025\000\000\000\025\000\025\000\000\000\000\000\000\000\034\000\
\\000\000\000\000\025\000\025\000\034\000\034\000\034\000\034\000\
\\000\000\034\000\034\000\000\000\000\000\034\000\034\000\034\000\
\\034\000\000\000\000\000\000\000\034\000\000\000\000\000\000\000\
\\034\000\034\000\000\000\000\000\034\000\034\000\034\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\034\000\034\000\
\\034\000\034\000\000\000\000\000\034\000\000\000\034\000\000\000\
\\034\000\000\000\034\000\000\000\034\000\000\000\000\000\034\000\
\\034\000\000\000\034\000\034\000\000\000\000\000\000\000\033\000\
\\000\000\000\000\034\000\034\000\033\000\033\000\033\000\033\000\
\\000\000\033\000\033\000\000\000\000\000\033\000\033\000\033\000\
\\033\000\000\000\000\000\000\000\033\000\000\000\000\000\000\000\
\\033\000\033\000\000\000\000\000\033\000\033\000\033\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\033\000\033\000\
\\033\000\033\000\000\000\000\000\033\000\000\000\033\000\000\000\
\\033\000\000\000\033\000\000\000\033\000\000\000\000\000\033\000\
\\033\000\000\000\033\000\033\000\000\000\000\000\000\000\037\000\
\\000\000\000\000\033\000\033\000\037\000\037\000\037\000\037\000\
\\000\000\037\000\037\000\000\000\000\000\037\000\037\000\037\000\
\\037\000\000\000\000\000\000\000\037\000\000\000\000\000\000\000\
\\037\000\037\000\000\000\000\000\037\000\037\000\037\000\000\000\
\\051\000\000\000\000\000\051\000\000\000\051\000\000\000\000\000\
\\000\000\000\000\051\000\051\000\000\000\000\000\037\000\037\000\
\\037\000\037\000\000\000\000\000\037\000\000\000\037\000\000\000\
\\037\000\000\000\037\000\000\000\037\000\000\000\000\000\037\000\
\\037\000\000\000\037\000\037\000\049\000\050\000\000\000\000\000\
\\000\000\000\000\037\000\037\000\000\000\000\000\000\000\051\000\
\\000\000\000\000\052\000\000\000\000\000\053\000\000\000\000\000\
\\051\000\157\000\000\000\054\000\051\000\055\000\056\000\051\000\
\\000\000\057\000\058\000\059\000\000\000\060\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\061\000\062\000\063\000\064\000\000\000\
\\065\000\066\000\000\000\067\000\000\000\068\000\069\000\070\000\
\\071\000\000\000\000\000\000\000\030\000\000\000\000\000\000\000\
\\000\000\030\000\030\000\030\000\030\000\073\000\030\000\074\000\
\\158\000\000\000\030\000\030\000\030\000\030\000\000\000\000\000\
\\000\000\030\000\000\000\000\000\000\000\030\000\030\000\000\000\
\\000\000\030\000\030\000\030\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\030\000\030\000\030\000\030\000\000\000\
\\000\000\050\000\000\000\000\000\000\000\030\000\000\000\000\000\
\\000\000\030\000\000\000\051\000\030\000\030\000\000\000\030\000\
\\030\000\000\000\000\000\000\000\023\000\000\000\000\000\054\000\
\\030\000\023\000\023\000\023\000\023\000\000\000\023\000\000\000\
\\000\000\060\000\023\000\023\000\023\000\023\000\000\000\000\000\
\\000\000\023\000\000\000\000\000\000\000\023\000\023\000\000\000\
\\000\000\023\000\023\000\023\000\065\000\066\000\000\000\067\000\
\\000\000\000\000\069\000\070\000\071\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\023\000\023\000\023\000\023\000\000\000\
\\000\000\073\000\000\000\074\000\000\000\023\000\000\000\000\000\
\\000\000\023\000\000\000\000\000\023\000\023\000\000\000\023\000\
\\023\000\000\000\000\000\000\000\024\000\000\000\000\000\000\000\
\\023\000\024\000\024\000\024\000\024\000\000\000\024\000\000\000\
\\000\000\000\000\024\000\024\000\024\000\024\000\000\000\000\000\
\\000\000\024\000\000\000\000\000\000\000\024\000\024\000\000\000\
\\000\000\024\000\024\000\024\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\024\000\024\000\024\000\024\000\000\000\
\\000\000\050\000\000\000\000\000\000\000\024\000\000\000\000\000\
\\000\000\024\000\000\000\000\000\024\000\024\000\000\000\024\000\
\\024\000\000\000\000\000\000\000\029\000\000\000\000\000\054\000\
\\024\000\029\000\029\000\029\000\029\000\000\000\029\000\000\000\
\\000\000\060\000\029\000\029\000\029\000\029\000\000\000\000\000\
\\000\000\029\000\000\000\000\000\000\000\029\000\029\000\000\000\
\\000\000\029\000\029\000\029\000\065\000\000\000\000\000\067\000\
\\000\000\000\000\069\000\070\000\071\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\029\000\029\000\029\000\029\000\000\000\
\\000\000\073\000\000\000\074\000\000\000\029\000\000\000\000\000\
\\000\000\029\000\000\000\000\000\029\000\029\000\000\000\029\000\
\\029\000\000\000\000\000\000\000\014\000\000\000\000\000\000\000\
\\029\000\014\000\014\000\014\000\014\000\000\000\014\000\000\000\
\\000\000\000\000\000\000\014\000\014\000\014\000\032\000\000\000\
\\000\000\014\000\000\000\032\000\032\000\032\000\032\000\000\000\
\\032\000\014\000\000\000\014\000\000\000\032\000\032\000\032\000\
\\000\000\000\000\000\000\032\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\032\000\000\000\032\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\014\000\000\000\000\000\
\\000\000\014\000\000\000\000\000\014\000\014\000\000\000\014\000\
\\014\000\000\000\000\000\000\000\000\000\000\000\000\000\032\000\
\\014\000\000\000\000\000\032\000\000\000\000\000\032\000\032\000\
\\000\000\032\000\032\000\000\000\000\000\000\000\021\000\000\000\
\\000\000\000\000\032\000\021\000\021\000\021\000\021\000\000\000\
\\021\000\000\000\000\000\000\000\000\000\021\000\021\000\021\000\
\\022\000\000\000\000\000\021\000\000\000\022\000\022\000\022\000\
\\022\000\000\000\022\000\021\000\000\000\021\000\000\000\022\000\
\\022\000\022\000\000\000\000\000\000\000\022\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\022\000\000\000\022\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\021\000\
\\000\000\000\000\000\000\021\000\000\000\000\000\021\000\021\000\
\\000\000\021\000\021\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\022\000\021\000\000\000\000\000\022\000\000\000\000\000\
\\022\000\022\000\000\000\022\000\022\000\000\000\000\000\000\000\
\\036\000\000\000\000\000\000\000\022\000\036\000\036\000\036\000\
\\036\000\000\000\036\000\000\000\000\000\000\000\000\000\036\000\
\\036\000\036\000\039\000\000\000\000\000\036\000\000\000\039\000\
\\039\000\039\000\039\000\000\000\039\000\036\000\000\000\036\000\
\\000\000\039\000\039\000\039\000\000\000\000\000\000\000\039\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\039\000\
\\000\000\039\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\036\000\000\000\000\000\000\000\036\000\000\000\000\000\
\\036\000\036\000\000\000\036\000\036\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\039\000\036\000\000\000\000\000\039\000\
\\000\000\000\000\039\000\039\000\000\000\039\000\039\000\000\000\
\\000\000\000\000\019\000\000\000\000\000\000\000\039\000\019\000\
\\019\000\019\000\019\000\000\000\019\000\000\000\000\000\000\000\
\\000\000\019\000\019\000\019\000\020\000\000\000\000\000\019\000\
\\000\000\020\000\020\000\020\000\020\000\000\000\020\000\019\000\
\\000\000\019\000\000\000\020\000\020\000\020\000\000\000\000\000\
\\000\000\020\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\020\000\053\000\020\000\000\000\053\000\000\000\053\000\
\\000\000\000\000\000\000\019\000\053\000\053\000\000\000\019\000\
\\000\000\000\000\019\000\019\000\000\000\019\000\019\000\000\000\
\\049\000\050\000\000\000\000\000\000\000\020\000\019\000\097\000\
\\098\000\020\000\000\000\051\000\020\000\020\000\052\000\020\000\
\\020\000\053\000\000\000\000\000\000\000\000\000\000\000\054\000\
\\020\000\055\000\056\000\000\000\000\000\057\000\058\000\059\000\
\\000\000\060\000\053\000\000\000\000\000\000\000\053\000\000\000\
\\000\000\053\000\000\000\000\000\000\000\000\000\000\000\061\000\
\\062\000\063\000\064\000\000\000\065\000\066\000\000\000\067\000\
\\000\000\068\000\069\000\070\000\071\000\000\000\000\000\049\000\
\\050\000\099\000\000\000\000\000\000\000\017\000\000\000\000\000\
\\000\000\073\000\051\000\074\000\000\000\052\000\043\000\000\000\
\\053\000\000\000\044\000\000\000\000\000\000\000\054\000\018\000\
\\055\000\056\000\000\000\000\000\057\000\058\000\059\000\000\000\
\\060\000\000\000\019\000\020\000\021\000\022\000\023\000\024\000\
\\025\000\000\000\026\000\000\000\000\000\000\000\061\000\062\000\
\\063\000\064\000\027\000\065\000\066\000\000\000\067\000\000\000\
\\068\000\069\000\070\000\071\000\000\000\000\000\049\000\050\000\
\\072\000\045\000\000\000\000\000\017\000\091\000\000\000\000\000\
\\073\000\051\000\074\000\000\000\052\000\000\000\000\000\053\000\
\\000\000\000\000\000\000\000\000\000\000\054\000\018\000\055\000\
\\056\000\000\000\000\000\057\000\058\000\059\000\000\000\060\000\
\\000\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\\000\000\026\000\000\000\000\000\000\000\061\000\062\000\063\000\
\\064\000\027\000\065\000\066\000\000\000\067\000\000\000\068\000\
\\069\000\070\000\071\000\000\000\000\000\049\000\050\000\000\000\
\\000\000\000\000\000\000\000\000\168\000\000\000\000\000\073\000\
\\051\000\074\000\000\000\052\000\000\000\000\000\053\000\000\000\
\\000\000\000\000\000\000\000\000\054\000\000\000\055\000\056\000\
\\000\000\000\000\057\000\058\000\059\000\000\000\060\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\061\000\062\000\063\000\064\000\
\\000\000\065\000\066\000\000\000\067\000\000\000\068\000\069\000\
\\070\000\071\000\000\000\000\000\049\000\050\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\073\000\051\000\
\\074\000\000\000\052\000\000\000\000\000\053\000\000\000\000\000\
\\000\000\000\000\000\000\054\000\000\000\055\000\056\000\000\000\
\\000\000\057\000\058\000\059\000\000\000\060\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\061\000\062\000\063\000\064\000\000\000\
\\065\000\066\000\000\000\067\000\000\000\068\000\069\000\070\000\
\\071\000\000\000\000\000\049\000\050\000\170\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\073\000\051\000\074\000\
\\000\000\052\000\000\000\000\000\053\000\000\000\000\000\000\000\
\\000\000\000\000\054\000\000\000\055\000\056\000\000\000\000\000\
\\057\000\058\000\059\000\000\000\060\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\061\000\062\000\063\000\064\000\000\000\065\000\
\\066\000\000\000\067\000\000\000\068\000\069\000\070\000\071\000\
\\000\000\000\000\049\000\050\000\171\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\073\000\051\000\074\000\000\000\
\\052\000\000\000\000\000\053\000\000\000\000\000\000\000\000\000\
\\000\000\054\000\000\000\055\000\056\000\000\000\000\000\057\000\
\\058\000\059\000\000\000\060\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\061\000\062\000\063\000\064\000\000\000\065\000\066\000\
\\000\000\067\000\000\000\068\000\069\000\070\000\071\000\000\000\
\\000\000\049\000\050\000\175\000\000\000\000\000\000\000\176\000\
\\000\000\000\000\000\000\073\000\051\000\074\000\000\000\052\000\
\\000\000\000\000\053\000\000\000\000\000\000\000\000\000\000\000\
\\054\000\000\000\055\000\056\000\000\000\000\000\057\000\058\000\
\\059\000\000\000\060\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\061\000\062\000\063\000\064\000\000\000\065\000\066\000\000\000\
\\067\000\000\000\068\000\069\000\070\000\071\000\000\000\000\000\
\\049\000\050\000\000\000\000\000\000\000\000\000\177\000\000\000\
\\000\000\000\000\073\000\051\000\074\000\000\000\052\000\000\000\
\\000\000\053\000\000\000\000\000\000\000\000\000\000\000\054\000\
\\000\000\055\000\056\000\000\000\000\000\057\000\058\000\059\000\
\\000\000\060\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\061\000\
\\062\000\063\000\064\000\000\000\065\000\066\000\000\000\067\000\
\\000\000\068\000\069\000\070\000\071\000\000\000\000\000\049\000\
\\050\000\000\000\000\000\000\000\000\000\178\000\000\000\000\000\
\\000\000\073\000\051\000\074\000\000\000\052\000\000\000\000\000\
\\053\000\000\000\000\000\000\000\000\000\000\000\054\000\000\000\
\\055\000\056\000\000\000\000\000\057\000\058\000\059\000\000\000\
\\060\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\061\000\062\000\
\\063\000\064\000\000\000\065\000\066\000\000\000\067\000\000\000\
\\068\000\069\000\070\000\071\000\000\000\000\000\049\000\050\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\073\000\051\000\074\000\000\000\052\000\000\000\000\000\053\000\
\\000\000\000\000\000\000\000\000\000\000\054\000\000\000\055\000\
\\056\000\000\000\000\000\057\000\058\000\059\000\000\000\060\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\061\000\062\000\063\000\
\\064\000\000\000\065\000\066\000\000\000\067\000\000\000\068\000\
\\069\000\070\000\071\000\000\000\000\000\049\000\050\000\189\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\073\000\
\\051\000\074\000\000\000\052\000\000\000\000\000\053\000\000\000\
\\000\000\000\000\000\000\000\000\054\000\000\000\055\000\056\000\
\\000\000\000\000\057\000\058\000\059\000\000\000\060\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\061\000\062\000\063\000\064\000\
\\000\000\065\000\066\000\000\000\067\000\000\000\068\000\069\000\
\\070\000\071\000\000\000\000\000\049\000\050\000\192\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\073\000\051\000\
\\074\000\000\000\052\000\000\000\000\000\053\000\000\000\000\000\
\\000\000\000\000\000\000\054\000\000\000\055\000\056\000\000\000\
\\000\000\057\000\058\000\059\000\000\000\060\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\061\000\062\000\063\000\064\000\000\000\
\\065\000\066\000\000\000\067\000\000\000\068\000\069\000\070\000\
\\071\000\000\000\000\000\049\000\050\000\193\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\073\000\051\000\074\000\
\\000\000\052\000\000\000\000\000\053\000\000\000\000\000\000\000\
\\000\000\000\000\054\000\000\000\055\000\056\000\000\000\000\000\
\\057\000\058\000\059\000\000\000\060\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\061\000\062\000\063\000\064\000\000\000\065\000\
\\066\000\000\000\067\000\000\000\068\000\069\000\070\000\071\000\
\\000\000\000\000\049\000\050\000\194\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\073\000\051\000\074\000\000\000\
\\052\000\000\000\000\000\053\000\000\000\000\000\000\000\000\000\
\\000\000\054\000\000\000\055\000\056\000\000\000\000\000\057\000\
\\058\000\059\000\000\000\060\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\061\000\062\000\063\000\064\000\000\000\065\000\066\000\
\\000\000\067\000\000\000\068\000\069\000\070\000\071\000\000\000\
\\000\000\049\000\050\000\000\000\000\000\000\000\202\000\203\000\
\\000\000\000\000\000\000\073\000\051\000\074\000\000\000\052\000\
\\000\000\000\000\053\000\000\000\000\000\000\000\000\000\000\000\
\\054\000\000\000\055\000\056\000\000\000\000\000\057\000\058\000\
\\059\000\000\000\060\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\061\000\062\000\063\000\064\000\000\000\065\000\066\000\000\000\
\\067\000\000\000\068\000\069\000\070\000\071\000\000\000\000\000\
\\049\000\050\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\073\000\051\000\074\000\000\000\052\000\000\000\
\\000\000\053\000\000\000\000\000\000\000\000\000\000\000\054\000\
\\000\000\055\000\056\000\000\000\000\000\057\000\058\000\059\000\
\\000\000\060\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\061\000\
\\062\000\063\000\064\000\000\000\065\000\066\000\000\000\067\000\
\\000\000\068\000\069\000\070\000\071\000\000\000\000\000\049\000\
\\050\000\000\000\000\000\000\000\209\000\000\000\000\000\000\000\
\\000\000\073\000\051\000\074\000\000\000\052\000\000\000\000\000\
\\053\000\000\000\000\000\000\000\000\000\000\000\054\000\000\000\
\\055\000\056\000\000\000\000\000\057\000\058\000\059\000\000\000\
\\060\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\061\000\062\000\
\\063\000\064\000\000\000\065\000\066\000\000\000\067\000\000\000\
\\068\000\069\000\070\000\071\000\000\000\000\000\049\000\050\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\073\000\051\000\074\000\000\000\052\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\054\000\000\000\055\000\
\\056\000\000\000\000\000\057\000\058\000\059\000\000\000\060\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\061\000\062\000\063\000\
\\064\000\000\000\065\000\066\000\000\000\067\000\000\000\068\000\
\\069\000\070\000\071\000\000\000\000\000\049\000\050\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\073\000\
\\051\000\074\000\000\000\052\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\054\000\000\000\055\000\056\000\
\\000\000\000\000\000\000\058\000\059\000\050\000\060\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\051\000\
\\000\000\000\000\052\000\000\000\061\000\062\000\063\000\064\000\
\\000\000\065\000\066\000\054\000\067\000\055\000\056\000\069\000\
\\070\000\071\000\058\000\000\000\000\000\060\000\000\000\012\000\
\\012\000\012\000\012\000\000\000\012\000\000\000\073\000\000\000\
\\074\000\012\000\012\000\061\000\062\000\063\000\064\000\012\000\
\\065\000\066\000\000\000\067\000\000\000\000\000\069\000\070\000\
\\071\000\000\000\000\000\000\000\000\000\000\000\015\000\015\000\
\\015\000\015\000\000\000\015\000\000\000\073\000\000\000\074\000\
\\015\000\015\000\015\000\000\000\000\000\000\000\015\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\015\000\012\000\
\\000\000\000\000\012\000\012\000\000\000\012\000\012\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\012\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\015\000\000\000\000\000\000\000\015\000\000\000\
\\000\000\015\000\015\000\000\000\015\000\015\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\015\000";

val yycheck = "\006\000\
\\014\000\031\000\044\000\045\000\026\000\009\001\002\001\004\001\
\\001\000\002\001\009\001\002\001\065\001\017\001\009\001\068\001\
\\018\001\019\001\025\000\009\001\027\000\023\001\017\001\020\001\
\\006\001\007\001\008\001\009\001\024\001\011\001\028\001\024\001\
\\017\001\024\001\016\001\017\001\018\001\069\001\062\001\028\001\
\\022\001\067\001\049\000\050\000\051\000\052\000\053\000\054\000\
\\055\000\056\000\057\000\058\000\059\000\060\000\061\000\062\000\
\\063\000\064\000\065\000\066\000\067\000\068\000\069\000\070\000\
\\071\000\069\001\073\000\074\000\061\001\091\000\061\001\078\000\
\\086\000\028\001\069\001\002\001\083\000\003\001\085\000\002\001\
\\062\001\074\001\018\001\065\001\066\001\009\001\068\001\069\001\
\\003\001\012\001\097\000\098\000\003\001\010\001\016\001\077\001\
\\016\001\024\001\065\001\025\001\036\001\024\001\028\001\028\001\
\\146\000\016\001\068\001\034\001\064\001\007\001\025\001\034\001\
\\045\001\028\001\025\001\001\000\052\001\028\001\008\001\005\000\
\\028\001\128\000\129\000\007\001\060\001\132\000\053\001\050\001\
\\051\001\136\000\053\001\054\001\059\001\056\001\061\001\045\001\
\\059\001\060\001\061\001\007\001\147\000\148\000\149\000\007\001\
\\062\001\071\001\021\001\074\001\069\001\045\001\180\000\074\001\
\\038\000\076\001\057\001\003\001\071\001\066\001\045\001\189\000\
\\071\001\168\000\028\001\037\001\018\001\195\000\173\000\073\001\
\\006\001\176\000\177\000\178\000\016\001\203\000\204\000\014\001\
\\011\001\025\001\007\001\209\000\028\001\188\000\212\000\190\000\
\\062\001\066\001\001\001\002\001\007\001\066\001\029\001\006\001\
\\007\001\008\001\009\001\202\000\011\001\012\001\037\001\062\001\
\\015\001\016\001\017\001\018\001\127\000\011\001\045\001\022\001\
\\038\000\024\001\088\000\026\001\027\001\159\000\062\001\030\001\
\\031\001\032\001\207\000\034\001\255\255\028\001\029\001\071\001\
\\168\000\014\001\255\255\255\255\035\001\255\255\037\001\255\255\
\\255\255\048\001\049\001\050\001\051\001\255\255\053\001\054\001\
\\029\001\056\001\255\255\058\001\059\001\060\001\061\001\062\001\
\\037\001\255\255\065\001\066\001\255\255\068\001\069\001\255\255\
\\045\001\046\001\255\255\074\001\255\255\076\001\077\001\001\001\
\\002\001\072\001\255\255\255\255\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\024\001\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\006\001\053\001\054\001\009\001\056\001\011\001\
\\058\001\059\001\060\001\061\001\062\001\017\001\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\074\001\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\062\001\255\255\255\255\255\255\066\001\255\255\
\\255\255\069\001\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\061\001\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\074\001\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\061\001\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\074\001\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\255\255\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\074\001\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\255\255\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\255\255\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\255\255\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\255\255\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\255\255\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\255\255\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\255\255\054\001\255\255\056\001\255\255\
\\058\001\255\255\060\001\255\255\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\255\255\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\255\255\054\001\255\255\056\001\255\255\
\\058\001\255\255\060\001\255\255\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\255\255\255\255\255\255\001\001\
\\255\255\255\255\076\001\077\001\006\001\007\001\008\001\009\001\
\\255\255\011\001\012\001\255\255\255\255\015\001\016\001\017\001\
\\018\001\255\255\255\255\255\255\022\001\255\255\255\255\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\006\001\255\255\255\255\009\001\255\255\011\001\255\255\255\255\
\\255\255\255\255\016\001\017\001\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\255\255\054\001\255\255\056\001\255\255\
\\058\001\255\255\060\001\255\255\062\001\255\255\255\255\065\001\
\\066\001\255\255\068\001\069\001\001\001\002\001\255\255\255\255\
\\255\255\255\255\076\001\077\001\255\255\255\255\255\255\012\001\
\\255\255\255\255\015\001\255\255\255\255\018\001\255\255\255\255\
\\062\001\022\001\255\255\024\001\066\001\026\001\027\001\069\001\
\\255\255\030\001\031\001\032\001\255\255\034\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\053\001\054\001\255\255\056\001\255\255\058\001\059\001\060\001\
\\061\001\255\255\255\255\255\255\001\001\255\255\255\255\255\255\
\\255\255\006\001\007\001\008\001\009\001\074\001\011\001\076\001\
\\077\001\255\255\015\001\016\001\017\001\018\001\255\255\255\255\
\\255\255\022\001\255\255\255\255\255\255\026\001\027\001\255\255\
\\255\255\030\001\031\001\032\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\255\255\002\001\255\255\255\255\255\255\058\001\255\255\255\255\
\\255\255\062\001\255\255\012\001\065\001\066\001\255\255\068\001\
\\069\001\255\255\255\255\255\255\001\001\255\255\255\255\024\001\
\\077\001\006\001\007\001\008\001\009\001\255\255\011\001\255\255\
\\255\255\034\001\015\001\016\001\017\001\018\001\255\255\255\255\
\\255\255\022\001\255\255\255\255\255\255\026\001\027\001\255\255\
\\255\255\030\001\031\001\032\001\053\001\054\001\255\255\056\001\
\\255\255\255\255\059\001\060\001\061\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\255\255\074\001\255\255\076\001\255\255\058\001\255\255\255\255\
\\255\255\062\001\255\255\255\255\065\001\066\001\255\255\068\001\
\\069\001\255\255\255\255\255\255\001\001\255\255\255\255\255\255\
\\077\001\006\001\007\001\008\001\009\001\255\255\011\001\255\255\
\\255\255\255\255\015\001\016\001\017\001\018\001\255\255\255\255\
\\255\255\022\001\255\255\255\255\255\255\026\001\027\001\255\255\
\\255\255\030\001\031\001\032\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\255\255\002\001\255\255\255\255\255\255\058\001\255\255\255\255\
\\255\255\062\001\255\255\255\255\065\001\066\001\255\255\068\001\
\\069\001\255\255\255\255\255\255\001\001\255\255\255\255\024\001\
\\077\001\006\001\007\001\008\001\009\001\255\255\011\001\255\255\
\\255\255\034\001\015\001\016\001\017\001\018\001\255\255\255\255\
\\255\255\022\001\255\255\255\255\255\255\026\001\027\001\255\255\
\\255\255\030\001\031\001\032\001\053\001\255\255\255\255\056\001\
\\255\255\255\255\059\001\060\001\061\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\255\255\074\001\255\255\076\001\255\255\058\001\255\255\255\255\
\\255\255\062\001\255\255\255\255\065\001\066\001\255\255\068\001\
\\069\001\255\255\255\255\255\255\001\001\255\255\255\255\255\255\
\\077\001\006\001\007\001\008\001\009\001\255\255\011\001\255\255\
\\255\255\255\255\255\255\016\001\017\001\018\001\001\001\255\255\
\\255\255\022\001\255\255\006\001\007\001\008\001\009\001\255\255\
\\011\001\030\001\255\255\032\001\255\255\016\001\017\001\018\001\
\\255\255\255\255\255\255\022\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\030\001\255\255\032\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\058\001\255\255\255\255\
\\255\255\062\001\255\255\255\255\065\001\066\001\255\255\068\001\
\\069\001\255\255\255\255\255\255\255\255\255\255\255\255\058\001\
\\077\001\255\255\255\255\062\001\255\255\255\255\065\001\066\001\
\\255\255\068\001\069\001\255\255\255\255\255\255\001\001\255\255\
\\255\255\255\255\077\001\006\001\007\001\008\001\009\001\255\255\
\\011\001\255\255\255\255\255\255\255\255\016\001\017\001\018\001\
\\001\001\255\255\255\255\022\001\255\255\006\001\007\001\008\001\
\\009\001\255\255\011\001\030\001\255\255\032\001\255\255\016\001\
\\017\001\018\001\255\255\255\255\255\255\022\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\030\001\255\255\032\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\058\001\
\\255\255\255\255\255\255\062\001\255\255\255\255\065\001\066\001\
\\255\255\068\001\069\001\255\255\255\255\255\255\255\255\255\255\
\\255\255\058\001\077\001\255\255\255\255\062\001\255\255\255\255\
\\065\001\066\001\255\255\068\001\069\001\255\255\255\255\255\255\
\\001\001\255\255\255\255\255\255\077\001\006\001\007\001\008\001\
\\009\001\255\255\011\001\255\255\255\255\255\255\255\255\016\001\
\\017\001\018\001\001\001\255\255\255\255\022\001\255\255\006\001\
\\007\001\008\001\009\001\255\255\011\001\030\001\255\255\032\001\
\\255\255\016\001\017\001\018\001\255\255\255\255\255\255\022\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\030\001\
\\255\255\032\001\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\058\001\255\255\255\255\255\255\062\001\255\255\255\255\
\\065\001\066\001\255\255\068\001\069\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\058\001\077\001\255\255\255\255\062\001\
\\255\255\255\255\065\001\066\001\255\255\068\001\069\001\255\255\
\\255\255\255\255\001\001\255\255\255\255\255\255\077\001\006\001\
\\007\001\008\001\009\001\255\255\011\001\255\255\255\255\255\255\
\\255\255\016\001\017\001\018\001\001\001\255\255\255\255\022\001\
\\255\255\006\001\007\001\008\001\009\001\255\255\011\001\030\001\
\\255\255\032\001\255\255\016\001\017\001\018\001\255\255\255\255\
\\255\255\022\001\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\030\001\006\001\032\001\255\255\009\001\255\255\011\001\
\\255\255\255\255\255\255\058\001\016\001\017\001\255\255\062\001\
\\255\255\255\255\065\001\066\001\255\255\068\001\069\001\255\255\
\\001\001\002\001\255\255\255\255\255\255\058\001\077\001\008\001\
\\009\001\062\001\255\255\012\001\065\001\066\001\015\001\068\001\
\\069\001\018\001\255\255\255\255\255\255\255\255\255\255\024\001\
\\077\001\026\001\027\001\255\255\255\255\030\001\031\001\032\001\
\\255\255\034\001\062\001\255\255\255\255\255\255\066\001\255\255\
\\255\255\069\001\255\255\255\255\255\255\255\255\255\255\048\001\
\\049\001\050\001\051\001\255\255\053\001\054\001\255\255\056\001\
\\255\255\058\001\059\001\060\001\061\001\255\255\255\255\001\001\
\\002\001\066\001\255\255\255\255\255\255\010\001\255\255\255\255\
\\255\255\074\001\012\001\076\001\255\255\015\001\019\001\255\255\
\\018\001\255\255\023\001\255\255\255\255\255\255\024\001\028\001\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\055\001\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\061\001\255\255\255\255\001\001\002\001\
\\066\001\070\001\255\255\255\255\010\001\008\001\255\255\255\255\
\\074\001\012\001\076\001\255\255\015\001\255\255\255\255\018\001\
\\255\255\255\255\255\255\255\255\255\255\024\001\028\001\026\001\
\\027\001\255\255\255\255\030\001\031\001\032\001\255\255\034\001\
\\255\255\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\\255\255\047\001\255\255\255\255\255\255\048\001\049\001\050\001\
\\051\001\055\001\053\001\054\001\255\255\056\001\255\255\058\001\
\\059\001\060\001\061\001\255\255\255\255\001\001\002\001\255\255\
\\255\255\255\255\255\255\255\255\008\001\255\255\255\255\074\001\
\\012\001\076\001\255\255\015\001\255\255\255\255\018\001\255\255\
\\255\255\255\255\255\255\255\255\024\001\255\255\026\001\027\001\
\\255\255\255\255\030\001\031\001\032\001\255\255\034\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\048\001\049\001\050\001\051\001\
\\255\255\053\001\054\001\255\255\056\001\255\255\058\001\059\001\
\\060\001\061\001\255\255\255\255\001\001\002\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\074\001\012\001\
\\076\001\255\255\015\001\255\255\255\255\018\001\255\255\255\255\
\\255\255\255\255\255\255\024\001\255\255\026\001\027\001\255\255\
\\255\255\030\001\031\001\032\001\255\255\034\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\053\001\054\001\255\255\056\001\255\255\058\001\059\001\060\001\
\\061\001\255\255\255\255\001\001\002\001\066\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\074\001\012\001\076\001\
\\255\255\015\001\255\255\255\255\018\001\255\255\255\255\255\255\
\\255\255\255\255\024\001\255\255\026\001\027\001\255\255\255\255\
\\030\001\031\001\032\001\255\255\034\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\048\001\049\001\050\001\051\001\255\255\053\001\
\\054\001\255\255\056\001\255\255\058\001\059\001\060\001\061\001\
\\255\255\255\255\001\001\002\001\066\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\074\001\012\001\076\001\255\255\
\\015\001\255\255\255\255\018\001\255\255\255\255\255\255\255\255\
\\255\255\024\001\255\255\026\001\027\001\255\255\255\255\030\001\
\\031\001\032\001\255\255\034\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\048\001\049\001\050\001\051\001\255\255\053\001\054\001\
\\255\255\056\001\255\255\058\001\059\001\060\001\061\001\255\255\
\\255\255\001\001\002\001\066\001\255\255\255\255\255\255\007\001\
\\255\255\255\255\255\255\074\001\012\001\076\001\255\255\015\001\
\\255\255\255\255\018\001\255\255\255\255\255\255\255\255\255\255\
\\024\001\255\255\026\001\027\001\255\255\255\255\030\001\031\001\
\\032\001\255\255\034\001\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\048\001\049\001\050\001\051\001\255\255\053\001\054\001\255\255\
\\056\001\255\255\058\001\059\001\060\001\061\001\255\255\255\255\
\\001\001\002\001\255\255\255\255\255\255\255\255\007\001\255\255\
\\255\255\255\255\074\001\012\001\076\001\255\255\015\001\255\255\
\\255\255\018\001\255\255\255\255\255\255\255\255\255\255\024\001\
\\255\255\026\001\027\001\255\255\255\255\030\001\031\001\032\001\
\\255\255\034\001\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\048\001\
\\049\001\050\001\051\001\255\255\053\001\054\001\255\255\056\001\
\\255\255\058\001\059\001\060\001\061\001\255\255\255\255\001\001\
\\002\001\255\255\255\255\255\255\255\255\007\001\255\255\255\255\
\\255\255\074\001\012\001\076\001\255\255\015\001\255\255\255\255\
\\018\001\255\255\255\255\255\255\255\255\255\255\024\001\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\061\001\255\255\255\255\001\001\002\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\074\001\012\001\076\001\255\255\015\001\255\255\255\255\018\001\
\\255\255\255\255\255\255\255\255\255\255\024\001\255\255\026\001\
\\027\001\255\255\255\255\030\001\031\001\032\001\255\255\034\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\048\001\049\001\050\001\
\\051\001\255\255\053\001\054\001\255\255\056\001\255\255\058\001\
\\059\001\060\001\061\001\255\255\255\255\001\001\002\001\066\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\074\001\
\\012\001\076\001\255\255\015\001\255\255\255\255\018\001\255\255\
\\255\255\255\255\255\255\255\255\024\001\255\255\026\001\027\001\
\\255\255\255\255\030\001\031\001\032\001\255\255\034\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\048\001\049\001\050\001\051\001\
\\255\255\053\001\054\001\255\255\056\001\255\255\058\001\059\001\
\\060\001\061\001\255\255\255\255\001\001\002\001\066\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\074\001\012\001\
\\076\001\255\255\015\001\255\255\255\255\018\001\255\255\255\255\
\\255\255\255\255\255\255\024\001\255\255\026\001\027\001\255\255\
\\255\255\030\001\031\001\032\001\255\255\034\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\053\001\054\001\255\255\056\001\255\255\058\001\059\001\060\001\
\\061\001\255\255\255\255\001\001\002\001\066\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\074\001\012\001\076\001\
\\255\255\015\001\255\255\255\255\018\001\255\255\255\255\255\255\
\\255\255\255\255\024\001\255\255\026\001\027\001\255\255\255\255\
\\030\001\031\001\032\001\255\255\034\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\048\001\049\001\050\001\051\001\255\255\053\001\
\\054\001\255\255\056\001\255\255\058\001\059\001\060\001\061\001\
\\255\255\255\255\001\001\002\001\066\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\074\001\012\001\076\001\255\255\
\\015\001\255\255\255\255\018\001\255\255\255\255\255\255\255\255\
\\255\255\024\001\255\255\026\001\027\001\255\255\255\255\030\001\
\\031\001\032\001\255\255\034\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\048\001\049\001\050\001\051\001\255\255\053\001\054\001\
\\255\255\056\001\255\255\058\001\059\001\060\001\061\001\255\255\
\\255\255\001\001\002\001\255\255\255\255\255\255\069\001\007\001\
\\255\255\255\255\255\255\074\001\012\001\076\001\255\255\015\001\
\\255\255\255\255\018\001\255\255\255\255\255\255\255\255\255\255\
\\024\001\255\255\026\001\027\001\255\255\255\255\030\001\031\001\
\\032\001\255\255\034\001\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\048\001\049\001\050\001\051\001\255\255\053\001\054\001\255\255\
\\056\001\255\255\058\001\059\001\060\001\061\001\255\255\255\255\
\\001\001\002\001\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\074\001\012\001\076\001\255\255\015\001\255\255\
\\255\255\018\001\255\255\255\255\255\255\255\255\255\255\024\001\
\\255\255\026\001\027\001\255\255\255\255\030\001\031\001\032\001\
\\255\255\034\001\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\048\001\
\\049\001\050\001\051\001\255\255\053\001\054\001\255\255\056\001\
\\255\255\058\001\059\001\060\001\061\001\255\255\255\255\001\001\
\\002\001\255\255\255\255\255\255\069\001\255\255\255\255\255\255\
\\255\255\074\001\012\001\076\001\255\255\015\001\255\255\255\255\
\\018\001\255\255\255\255\255\255\255\255\255\255\024\001\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\058\001\059\001\060\001\061\001\255\255\255\255\001\001\002\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\074\001\012\001\076\001\255\255\015\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\024\001\255\255\026\001\
\\027\001\255\255\255\255\030\001\031\001\032\001\255\255\034\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\048\001\049\001\050\001\
\\051\001\255\255\053\001\054\001\255\255\056\001\255\255\058\001\
\\059\001\060\001\061\001\255\255\255\255\001\001\002\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\074\001\
\\012\001\076\001\255\255\015\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\024\001\255\255\026\001\027\001\
\\255\255\255\255\255\255\031\001\032\001\002\001\034\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\012\001\
\\255\255\255\255\015\001\255\255\048\001\049\001\050\001\051\001\
\\255\255\053\001\054\001\024\001\056\001\026\001\027\001\059\001\
\\060\001\061\001\031\001\255\255\255\255\034\001\255\255\006\001\
\\007\001\008\001\009\001\255\255\011\001\255\255\074\001\255\255\
\\076\001\016\001\017\001\048\001\049\001\050\001\051\001\022\001\
\\053\001\054\001\255\255\056\001\255\255\255\255\059\001\060\001\
\\061\001\255\255\255\255\255\255\255\255\255\255\006\001\007\001\
\\008\001\009\001\255\255\011\001\255\255\074\001\255\255\076\001\
\\016\001\017\001\018\001\255\255\255\255\255\255\022\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\030\001\062\001\
\\255\255\255\255\065\001\066\001\255\255\068\001\069\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\077\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\058\001\255\255\255\255\255\255\062\001\255\255\
\\255\255\065\001\066\001\255\255\068\001\069\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\077\001";

val yyact = vector_ 85 (fn () => ((raise Fail "parser") : obj));
(* Rule 1, file PLGAParser.grm, line 146 *)
val _ = update_ yyact 1
(fn () => repr(let
val d__1__ = peekVal 1 : string PLGADD.PLGA_Stmt
in
( (d__1__) ) end : string PLGADD.PLGA_Stmt))
;
(* Rule 2, file PLGAParser.grm, line 149 *)
val _ = update_ yyact 2
(fn () => repr(let
val d__1__ = peekVal 0 : string
in
( Ident ((d__1__), type_a) 	  ) end : ExprDD.Expr))
;
(* Rule 3, file PLGAParser.grm, line 150 *)
val _ = update_ yyact 3
(fn () => repr(let
val d__2__ = peekVal 1 : string
in
( Ident ((d__2__), type_string) ) end : ExprDD.Expr))
;
(* Rule 4, file PLGAParser.grm, line 152 *)
val _ = update_ yyact 4
(fn () => repr(let
in
( Lit ("-[]-", type_a) 	) end : ExprDD.Expr))
;
(* Rule 5, file PLGAParser.grm, line 153 *)
val _ = update_ yyact 5
(fn () => repr(let
in
( Lit ("-{}-", type_a) 	) end : ExprDD.Expr))
;
(* Rule 6, file PLGAParser.grm, line 154 *)
val _ = update_ yyact 6
(fn () => repr(let
val d__1__ = peekVal 0 : string
in
( Lit ((d__1__), type_int)	) end : ExprDD.Expr))
;
(* Rule 7, file PLGAParser.grm, line 155 *)
val _ = update_ yyact 7
(fn () => repr(let
in
( Lit ("T", type_bool)	) end : ExprDD.Expr))
;
(* Rule 8, file PLGAParser.grm, line 156 *)
val _ = update_ yyact 8
(fn () => repr(let
in
( Lit ("F", type_bool)	) end : ExprDD.Expr))
;
(* Rule 9, file PLGAParser.grm, line 158 *)
val _ = update_ yyact 9
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( ArrayAccess ((d__1__),(d__3__)) ) end : ExprDD.Expr))
;
(* Rule 10, file PLGAParser.grm, line 160 *)
val _ = update_ yyact 10
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( App ((d__1__),(d__3__)) ) end : ExprDD.Expr))
;
(* Rule 11, file PLGAParser.grm, line 162 *)
val _ = update_ yyact 11
(fn () => repr(let
val d__2__ = peekVal 1 : ExprDD.Expr
in
( (d__2__) ) end : ExprDD.Expr))
;
(* Rule 12, file PLGAParser.grm, line 164 *)
val _ = update_ yyact 12
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "=" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 13, file PLGAParser.grm, line 166 *)
val _ = update_ yyact 13
(fn () => repr(let
val d__2__ = peekVal 0 : ExprDD.Expr
in
( mkUnary "~" (d__2__) ) end : ExprDD.Expr))
;
(* Rule 14, file PLGAParser.grm, line 167 *)
val _ = update_ yyact 14
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "/\\" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 15, file PLGAParser.grm, line 168 *)
val _ = update_ yyact 15
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "\\/" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 16, file PLGAParser.grm, line 169 *)
val _ = update_ yyact 16
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "==>" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 17, file PLGAParser.grm, line 171 *)
val _ = update_ yyact 17
(fn () => repr(let
val d__3__ = peekVal 5 : (string * TypeDD.Type) list
val d__5__ = peekVal 3 : ExprDD.Expr
val d__7__ = peekVal 1 : ExprDD.Expr
in
( mkQuantor "?" (d__3__) (d__5__) (d__7__) ) end : ExprDD.Expr))
;
(* Rule 18, file PLGAParser.grm, line 173 *)
val _ = update_ yyact 18
(fn () => repr(let
val d__3__ = peekVal 5 : (string * TypeDD.Type) list
val d__5__ = peekVal 3 : ExprDD.Expr
val d__7__ = peekVal 1 : ExprDD.Expr
in
( mkQuantor "!" (d__3__) (d__5__) (d__7__) ) end : ExprDD.Expr))
;
(* Rule 19, file PLGAParser.grm, line 176 *)
val _ = update_ yyact 19
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "<" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 20, file PLGAParser.grm, line 177 *)
val _ = update_ yyact 20
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "<=" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 21, file PLGAParser.grm, line 178 *)
val _ = update_ yyact 21
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary ">" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 22, file PLGAParser.grm, line 179 *)
val _ = update_ yyact 22
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary ">=" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 23, file PLGAParser.grm, line 180 *)
val _ = update_ yyact 23
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "max" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 24, file PLGAParser.grm, line 181 *)
val _ = update_ yyact 24
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "min" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 25, file PLGAParser.grm, line 183 *)
val _ = update_ yyact 25
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "+" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 26, file PLGAParser.grm, line 184 *)
val _ = update_ yyact 26
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "*" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 27, file PLGAParser.grm, line 185 *)
val _ = update_ yyact 27
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "-" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 28, file PLGAParser.grm, line 186 *)
val _ = update_ yyact 28
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "^" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 29, file PLGAParser.grm, line 187 *)
val _ = update_ yyact 29
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "mod" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 30, file PLGAParser.grm, line 188 *)
val _ = update_ yyact 30
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "div" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 31, file PLGAParser.grm, line 189 *)
val _ = update_ yyact 31
(fn () => repr(let
val d__2__ = peekVal 3 : ExprDD.Expr
val d__4__ = peekVal 1 : ExprDD.Expr
in
( mkBinary "::" (d__2__) (d__4__) ) end : ExprDD.Expr))
;
(* Rule 32, file PLGAParser.grm, line 190 *)
val _ = update_ yyact 32
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "elem" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 33, file PLGAParser.grm, line 191 *)
val _ = update_ yyact 33
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "++" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 34, file PLGAParser.grm, line 192 *)
val _ = update_ yyact 34
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "!!" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 35, file PLGAParser.grm, line 193 *)
val _ = update_ yyact 35
(fn () => repr(let
val d__2__ = peekVal 1 : ExprDD.Expr list
in
( mkEnum "-[.]-" (d__2__) ) end : ExprDD.Expr))
;
(* Rule 36, file PLGAParser.grm, line 195 *)
val _ = update_ yyact 36
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "IN" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 37, file PLGAParser.grm, line 196 *)
val _ = update_ yyact 37
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "|_|" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 38, file PLGAParser.grm, line 197 *)
val _ = update_ yyact 38
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "|^|" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 39, file PLGAParser.grm, line 198 *)
val _ = update_ yyact 39
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "<+" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 40, file PLGAParser.grm, line 200 *)
val _ = update_ yyact 40
(fn () => repr(let
val d__3__ = peekVal 5 : (string * TypeDD.Type) list
val d__5__ = peekVal 3 : ExprDD.Expr
val d__7__ = peekVal 1 : ExprDD.Expr
in
( mkQuantor "SET" (d__3__) (d__5__) (d__7__) ) end : ExprDD.Expr))
;
(* Rule 41, file PLGAParser.grm, line 201 *)
val _ = update_ yyact 41
(fn () => repr(let
val d__2__ = peekVal 1 : ExprDD.Expr list
in
( mkEnum "-{.}-" (d__2__) ) end : ExprDD.Expr))
;
(* Rule 42, file PLGAParser.grm, line 203 *)
val _ = update_ yyact 42
(fn () => repr(let
val d__2__ = peekVal 3 : ExprDD.Expr
val d__4__ = peekVal 1 : ExprDD.Expr
in
( Tuple ((d__2__),(d__4__))     ) end : ExprDD.Expr))
;
(* Rule 43, file PLGAParser.grm, line 206 *)
val _ = update_ yyact 43
(fn () => repr(let
val d__1__ = peekVal 0 : ExprDD.Expr
in
( (d__1__)                ) end : ExprDD.Expr))
;
(* Rule 44, file PLGAParser.grm, line 208 *)
val _ = update_ yyact 44
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( Tuple ((d__1__),(d__3__))     ) end : ExprDD.Expr))
;
(* Rule 45, file PLGAParser.grm, line 212 *)
val _ = update_ yyact 45
(fn () => repr(let
val d__1__ = peekVal 0 : string
in
( [((d__1__), type_a)] ) end : (string * TypeDD.Type) list))
;
(* Rule 46, file PLGAParser.grm, line 213 *)
val _ = update_ yyact 46
(fn () => repr(let
val d__1__ = peekVal 2 : string
val d__3__ = peekVal 0 : (string * TypeDD.Type) list
in
( ((d__1__), type_a) :: (d__3__) ) end : (string * TypeDD.Type) list))
;
(* Rule 47, file PLGAParser.grm, line 216 *)
val _ = update_ yyact 47
(fn () => repr(let
val d__1__ = peekVal 0 : ExprDD.Expr
in
( [(d__1__)]	   ) end : ExprDD.Expr list))
;
(* Rule 48, file PLGAParser.grm, line 217 *)
val _ = update_ yyact 48
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr list
in
( (d__1__) :: (d__3__) ) end : ExprDD.Expr list))
;
(* Rule 49, file PLGAParser.grm, line 220 *)
val _ = update_ yyact 49
(fn () => repr(let
val d__1__ = peekVal 1 : string
in
( Inc (d__1__)			) end : PLSEQDD.Stmt))
;
(* Rule 50, file PLGAParser.grm, line 221 *)
val _ = update_ yyact 50
(fn () => repr(let
val d__1__ = peekVal 1 : string
in
( Dec (d__1__)			) end : PLSEQDD.Stmt))
;
(* Rule 51, file PLGAParser.grm, line 222 *)
val _ = update_ yyact 51
(fn () => repr(let
val d__1__ = peekVal 2 : string
val d__3__ = peekVal 0 : ExprDD.Expr
in
( Asg ((d__1__),(d__3__)) 			) end : PLSEQDD.Stmt))
;
(* Rule 52, file PLGAParser.grm, line 223 *)
val _ = update_ yyact 52
(fn () => repr(let
val d__2__ = peekVal 1 : PLSEQDD.Stmt list
in
( Seq (d__2__)			) end : PLSEQDD.Stmt))
;
(* Rule 53, file PLGAParser.grm, line 226 *)
val _ = update_ yyact 53
(fn () => repr(let
val d__1__ = peekVal 2 : string
val d__3__ = peekVal 0 : ExprDD.Expr
in
( Relation ((d__1__),(d__3__))		) end : PLSEQDD.Stmt))
;
(* Rule 54, file PLGAParser.grm, line 229 *)
val _ = update_ yyact 54
(fn () => repr(let
val d__3__ = peekVal 3 : ExprDD.Expr
val d__6__ = peekVal 0 : PLSEQDD.Stmt
in
( IfThen ((d__3__),(d__6__))		) end : PLSEQDD.Stmt))
;
(* Rule 55, file PLGAParser.grm, line 231 *)
val _ = update_ yyact 55
(fn () => repr(let
val d__3__ = peekVal 5 : ExprDD.Expr
val d__6__ = peekVal 2 : PLSEQDD.Stmt
val d__8__ = peekVal 0 : PLSEQDD.Stmt
in
( IfElse ((d__3__),(d__6__),(d__8__))		) end : PLSEQDD.Stmt))
;
(* Rule 56, file PLGAParser.grm, line 236 *)
val _ = update_ yyact 56
(fn () => repr(let
val d__3__ = peekVal 5 : ExprDD.Expr
val d__6__ = peekVal 2 : (ExprDD.Expr * PLSEQDD.Stmt) list
val d__7__ = peekVal 1 : PLSEQDD.Stmt
in
( let
					  val cs = (d__6__)
					  fun f (g,s) = (mkBinary "=" (d__3__) g, s)
					  val cs' = map f cs
					  in
					  Case (cs',(d__7__))
					  end				) end : PLSEQDD.Stmt))
;
(* Rule 57, file PLGAParser.grm, line 244 *)
val _ = update_ yyact 57
(fn () => repr(let
val d__2__ = peekVal 5 : ExprDD.Expr
val d__5__ = peekVal 2 : ExprDD.Expr
val d__7__ = peekVal 0 : PLSEQDD.Stmt
in
( While ((d__2__),(d__5__),(d__7__))		) end : PLSEQDD.Stmt))
;
(* Rule 58, file PLGAParser.grm, line 252 *)
val _ = update_ yyact 58
(fn () => repr(let
val d__2__ = peekVal 11 : ExprDD.Expr
val d__5__ = peekVal 8 : string
val d__7__ = peekVal 6 : ExprDD.Expr
val d__9__ = peekVal 4 : ExprDD.Expr
val d__11__ = peekVal 2 : PLSEQDD.Stmt
val d__13__ = peekVal 0 : PLSEQDD.Stmt
in
( ForLoop ((d__2__),(d__5__),(d__7__),(d__9__),(d__11__),(d__13__))	) end : PLSEQDD.Stmt))
;
(* Rule 59, file PLGAParser.grm, line 255 *)
val _ = update_ yyact 59
(fn () => repr(let
val d__3__ = peekVal 0 : PLSEQDD.Stmt
in
( (d__3__) 				) end : PLSEQDD.Stmt))
;
(* Rule 60, file PLGAParser.grm, line 258 *)
val _ = update_ yyact 60
(fn () => repr(let
in
( []				) end : (ExprDD.Expr * PLSEQDD.Stmt) list))
;
(* Rule 61, file PLGAParser.grm, line 259 *)
val _ = update_ yyact 61
(fn () => repr(let
val d__2__ = peekVal 3 : ExprDD.Expr
val d__4__ = peekVal 1 : PLSEQDD.Stmt
val d__5__ = peekVal 0 : (ExprDD.Expr * PLSEQDD.Stmt) list
in
( ((d__2__),(d__4__)) :: (d__5__)			) end : (ExprDD.Expr * PLSEQDD.Stmt) list))
;
(* Rule 62, file PLGAParser.grm, line 262 *)
val _ = update_ yyact 62
(fn () => repr(let
val d__1__ = peekVal 1 : PLSEQDD.Stmt
in
( [(d__1__)]				) end : PLSEQDD.Stmt list))
;
(* Rule 63, file PLGAParser.grm, line 263 *)
val _ = update_ yyact 63
(fn () => repr(let
val d__1__ = peekVal 2 : PLSEQDD.Stmt
val d__3__ = peekVal 0 : PLSEQDD.Stmt list
in
( (d__1__) :: (d__3__)			) end : PLSEQDD.Stmt list))
;
(* Rule 64, file PLGAParser.grm, line 273 *)
val _ = update_ yyact 64
(fn () => repr(let
val d__2__ = peekVal 3 : string
val d__5__ = peekVal 0 : string PLGADD.PLGA_Stmt
in
( addLabel (d__2__) (d__5__)		) end : string PLGADD.PLGA_Stmt))
;
(* Rule 65, file PLGAParser.grm, line 274 *)
val _ = update_ yyact 65
(fn () => repr(let
val d__1__ = peekVal 0 : string PLGADD.PLGA_Stmt
in
( (d__1__)				) end : string PLGADD.PLGA_Stmt))
;
(* Rule 66, file PLGAParser.grm, line 277 *)
val _ = update_ yyact 66
(fn () => repr(let
val d__1__ = peekVal 0 : string PLGADD.PLGA_Stmt
in
( (d__1__)				) end : string PLGADD.PLGA_Stmt))
;
(* Rule 67, file PLGAParser.grm, line 278 *)
val _ = update_ yyact 67
(fn () => repr(let
val d__2__ = peekVal 1 : string PLGADD.PLGA_Stmt list
in
( Block ((d__2__),"")			) end : string PLGADD.PLGA_Stmt))
;
(* Rule 68, file PLGAParser.grm, line 282 *)
val _ = update_ yyact 68
(fn () => repr(let
val d__3__ = peekVal 3 : string PLGADD.PLGA_Stmt list
val d__5__ = peekVal 1 : PLGADD.BlockingFlag
in
( Alt (((d__3__),(d__5__)),"")		) end : string PLGADD.PLGA_Stmt))
;
(* Rule 69, file PLGAParser.grm, line 286 *)
val _ = update_ yyact 69
(fn () => repr(let
val d__3__ = peekVal 3 : string PLGADD.PLGA_Stmt list
val d__5__ = peekVal 1 : PLGADD.BlockingFlag
in
( Loop (((d__3__),(d__5__)),"")		) end : string PLGADD.PLGA_Stmt))
;
(* Rule 70, file PLGAParser.grm, line 289 *)
val _ = update_ yyact 70
(fn () => repr(let
val d__1__ = peekVal 1 : string PLGADD.PLGA_Stmt
in
( [(d__1__)]				) end : string PLGADD.PLGA_Stmt list))
;
(* Rule 71, file PLGAParser.grm, line 290 *)
val _ = update_ yyact 71
(fn () => repr(let
val d__1__ = peekVal 2 : string PLGADD.PLGA_Stmt
val d__3__ = peekVal 0 : string PLGADD.PLGA_Stmt list
in
( (d__1__) :: (d__3__)			) end : string PLGADD.PLGA_Stmt list))
;
(* Rule 72, file PLGAParser.grm, line 293 *)
val _ = update_ yyact 72
(fn () => repr(let
val d__1__ = peekVal 1 : string PLGADD.PLGA_Stmt
in
( [(d__1__)]				) end : string PLGADD.PLGA_Stmt list))
;
(* Rule 73, file PLGAParser.grm, line 294 *)
val _ = update_ yyact 73
(fn () => repr(let
val d__1__ = peekVal 2 : string PLGADD.PLGA_Stmt
val d__3__ = peekVal 0 : string PLGADD.PLGA_Stmt list
in
( (d__1__) :: (d__3__)			) end : string PLGADD.PLGA_Stmt list))
;
(* Rule 74, file PLGAParser.grm, line 297 *)
val _ = update_ yyact 74
(fn () => repr(let
in
( ElseBlock			) end : PLGADD.BlockingFlag))
;
(* Rule 75, file PLGAParser.grm, line 298 *)
val _ = update_ yyact 75
(fn () => repr(let
in
( ElseExit			) end : PLGADD.BlockingFlag))
;
(* Rule 76, file PLGAParser.grm, line 301 *)
val _ = update_ yyact 76
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : PLSEQDD.Stmt
in
( Atomic (((d__1__),(d__3__)),"")		) end : string PLGADD.PLGA_Stmt))
;
(* Rule 77, file PLGAParser.grm, line 302 *)
val _ = update_ yyact 77
(fn () => repr(let
val d__1__ = peekVal 1 : ExprDD.Expr
in
( Atomic (((d__1__),Skip),"")		) end : string PLGADD.PLGA_Stmt))
;
(* Rule 78, file PLGAParser.grm, line 303 *)
val _ = update_ yyact 78
(fn () => repr(let
val d__1__ = peekVal 3 : ExprDD.Expr
val d__2__ = peekVal 2 : string
val d__4__ = peekVal 0 : ExprDD.Expr
in
( Atomic (((d__1__),Asg((d__2__),(d__4__))),"")	) end : string PLGADD.PLGA_Stmt))
;
(* Rule 79, file PLGAParser.grm, line 304 *)
val _ = update_ yyact 79
(fn () => repr(let
val d__1__ = peekVal 3 : ExprDD.Expr
val d__2__ = peekVal 2 : string
val d__4__ = peekVal 0 : ExprDD.Expr
in
( Send   (((d__1__),(d__2__),(d__4__)),"")	) end : string PLGADD.PLGA_Stmt))
;
(* Rule 80, file PLGAParser.grm, line 305 *)
val _ = update_ yyact 80
(fn () => repr(let
val d__1__ = peekVal 3 : ExprDD.Expr
val d__2__ = peekVal 2 : string
val d__4__ = peekVal 0 : string
in
( Rec    (((d__1__),(d__2__),(d__4__)),"")	) end : string PLGADD.PLGA_Stmt))
;
(* Rule 81, file PLGAParser.grm, line 306 *)
val _ = update_ yyact 81
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : string
in
( Goto   (((d__1__),(d__3__)),"")		) end : string PLGADD.PLGA_Stmt))
;
(* Rule 82, file PLGAParser.grm, line 309 *)
val _ = update_ yyact 82
(fn () => repr(let
in
( mk_T				) end : ExprDD.Expr))
;
(* Rule 83, file PLGAParser.grm, line 310 *)
val _ = update_ yyact 83
(fn () => repr(let
val d__2__ = peekVal 2 : ExprDD.Expr
in
( (d__2__)				) end : ExprDD.Expr))
;
(* Entry START *)
val _ = update_ yyact 84 (fn () => raise yyexit (peekVal 0));
val yytables : parseTables =
  ( yyact,
    yytransl,
    yylhs,
    yylen,
    yydefred,
    yydgoto,
    yysindex,
    yyrindex,
    yygindex,
    YYTABLESIZE,
    yytable,
    yycheck );
fun START lexer lexbuf = yyparse yytables 1 lexer lexbuf;
