structure PLGARules = struct

local

open PLSEQDD ExprDD TypeDD 

fun fst (x,_) = x
fun snd (_,y) = y

val tybool 	= TyCons ("bool",[])

fun tyfun a b	= TyCons ("fun", [a,b]) 

val tybool_binop = tyfun tybool (tyfun tybool tybool)

val mk_T		= Lit ("T", tybool)
val mk_F		= Lit ("F", tybool)

fun mk_and (p,q) 	= Binary (("/\\", tybool_binop), p, q)
fun mk_or (p,q) 	= Binary (("\\/", tybool_binop), p, q)
fun mk_not p 		= Unary (("~", tyfun tybool tybool), p)
fun mk_imp (p,q) 	= Binary (("==>", tybool_binop), p, q)
in

(* Given a PLGA atomic action a starting at location sl and
terminating at location el, this function generates the verification
condition for a Hoare triple of the form:

	{p} g --> a {q}

in which p==>q.

*)


fun genAction_vc labs_table preC postC (Skip,_,_)	= []

  | genAction_vc labs_table preC postC (a,g,(_,sl,el)) 
	=
	let

	fun get_eqv_labels lab = map fst (List.filter (fn (_,z)=> z=lab) labs_table)

	val preC'  = LabelRules.labelReductionRule_with_labRemoval labs_table sl preC
	val postC' = LabelRules.labelReductionRule_with_labRemoval labs_table el postC
		
	in
	(* if the labelReduction of preC' is false, it means
	   in that state the action is disabled. Therefor,
	   for ensures it means false
	   for unless  it means true
	   thefore the result would be [], which the bottom value for each
	*)
	if (preC' = mk_F )	 
		then []
		else [Hoa (mk_and(g,preC'), a, postC')]
		(* if the labelReduction of postC' is false,
		   it means :
			there is no enabled action from pre to post state
			Therefor:
			for ensures, it means false, no action, no progress
			for unless, it means true, remains in previous state.

		   but there is a possibility that the false of postC'
		   is due to the false of postC, which means
		   there is an action that give progress, but to the wrong state
		   Therefor :
		   for ensures : the action should be disabled.
				 it means we have to prove not preC
				 showing that on that label the expr disabling the action.
				 (although the label  match)
		   for unless  : ditto,
		   
		*)
(*		notes : Jan 22, 2002. 
		some thing wrong here !!!! but so far, enough with short cut.
		this simplification can be ignore, 
		but later for big cases we might need to correct the bugs here.
		it will give some performance improvement.

		if (postC' = mk_F)
			then if ((LabelRules.reduceExprOnly postC)=mk_F) 
				then [Every (mk_not preC)]   (* label information is needed *)
				else []
			else [Hoa (mk_and(g,preC'), a, postC')]
*)
(*
	if (preC' = mk_F) orelse (postC' = mk_F)
		then []
		else [Hoa (mk_and(g,preC'), a, postC')]
*)
	end

fun validReductionRule labs_table atomics validExpr
	=
	List.concat (map (genAction_vc labs_table mk_T  validExpr) atomics)
	

fun unlessReductionRule labs_table atomics P Q
	=
	let
	val preC   = mk_and (P, mk_not Q)
	val postC  = mk_or (P,Q)
	in
	List.concat (map (genAction_vc labs_table preC postC) atomics)
	end

(* P |-- p ensures q 
   the semantic is :
   p unless q /\  (?a. a in P : {p} a {q})

*) 


fun mk_orSeq (a,b) = [PLSEQDD.Disj (a,b)]

fun ensuresReductionRule labs_table atomics P Q
	=
	let
	val unless_vcs = unlessReductionRule labs_table atomics P Q
	val preC       = mk_and (P, mk_not Q)
	val postC      = Q
	val isSubset   = PLSEQDD.Every (mk_imp (P, Q)) 
	val ens_vcs    = List.concat (map (genAction_vc labs_table preC postC) atomics)
	in
	(unless_vcs, isSubset::ens_vcs )
	end

fun stableReductionRule labs_table atomics J
	=
	List.concat (map (genAction_vc labs_table J J) atomics)




(*

how to verify {P} a {P \/ Q}, for a given action a?


P has the form: (l1,l2,.. /\ p1) \/ (k1,k2,... /\ p2) \/ ...
Q .. ditto

we assume no label expression in p_i's

(1) extract P's and Q's label guards.
(2) filter P to get parts which are guarded by
    labels whose intersection with a's start label
    is non-empty.
    Call the disjuntcion of these parts P'.
    P' should be already stripped from guarding label expression.

(3) ditto for Q'

(4) convert a to statement (PLSEQ). Strip label info. Goto becomes skip.
    call this a'.

(5) verify {P'} a' {Q'}

*)



end
end

