structure PLPCHol  = struct
 

(* ============================================================
(*DOC

<MODULE>PLPCRules
<AUTHOR>underdarkprime & ade 
<ADRESS>underdarkPrime@yahoo.com & ade@cs.uu.nl
<DATE>September 2001

<DESC> This module provides the transformastion 

of PLPC specification into HOL term. This is needed in order 
to make use of some unity theory, (perhaps other theory) to 
resolve some decomposition specification.

<REQUIRED> UNITY99Theory

DOC*)
============================================================ *)



(* Assuming all string name  occurs on the left hand side of the symbol |==,
   is considered as process class name, except for the J, would be considered
   as invariant.
   A unity specification which consists of more than 1 process name, 
   considered as composed specification.  

*)


local

open HolKernel Psyntax;

open MoreList ;

open ExprHolSem;

in

(* task ?? ... 

   Send composed specification to Unity in hol 


fun procSpecInHol (PLPCDD.DNF expl)   = list_mk_disj (List.map ExprHol.exprInHol expl)
  | procSpecInHol (PLPCDD.VALID (expl,exp)) 
                               = mk_imp(list_mk_conj (List.map ExprHol.exprInHol expl),
	                                ExprHol.exprInHol exp)
  | procSpecInHol (PLPCDD.UNITYREL spec) 
                               = 
*)



(* ============================================================
(*DOC

<ITEM> unfoldInvariant 
<TYPE> unfoldInvariant :  Speclist -> ExprDD.Expr list -> ExprDD.Expr list

<CALL> unfoldInvariant spList inList 

<DESC> Unfolding the invariant in the specification.

DOC*)
============================================================ *)

fun unfoldInvariant (specList:PLPCDD.SpecList) (invList:ExprDD.Expr list) = 
    let

        fun getDesc spList inv = 
             let fun inv_eq inv (_,PLPCDD.INVARIANT (x,desc)) = (inv = x)
                   | inv_eq inv _                             = false
                 fun getDesc_ (PLPCDD.INVARIANT (x,desc)) = desc
                   | getDesc_ _  = raise Fail "PLPCHol.unfoldInvariant: ??? "
             in   
                 case (List.find (inv_eq inv) spList) of 
                   NONE           => inv
                 | SOME (nm,spec) => getDesc_ spec
             end
        in
            List.map (getDesc specList) invList
        end


(* ============================================================
(*DOC

<ITEM> unityInHol 
<TYPE> unityInHol : boolean * spec list -> (ExprDD.Expr list      * 
                                            ExprDD.Identifier     *
                                            ExprDD.Expr           *
                                            ExprDD.Expr           * 
                                            ExprDD.Identifier list) 
                                                                    -> Term.term 
<CALL> unityInHol flag specList unityArg
flag = true  => encapsulate/fold the invariant with its name.
     = false => unfold the invariant with its definition.

<DESC> Generate Unity specification in Hol Term.

DOC*)
============================================================ *)
(* should only be used for unity spec only *)
fun unityInHol flag spList (PLPCDD.UNITYREL (asml,(oper,ty),p,q,varList)) = 
    let 
    (* val getInvNm = fn : ProcSpec -> Expr; *)
    fun getInvNm (PLPCDD.INVARIANT (i,_)) = i
      | getInvNm _                        = raise Fail "PLPCRules.decomposeUnity: ill formed invariant" 
    val inExprTable: ExprDD.Expr list = List.map (getInvNm o Lib.snd)
                        (List.filter (fn(x,y) => (x="invariant")) spList)
    fun invariantCheck   i = List.exists (fn (x)=> (x=i)) inExprTable
    fun processNameCheck p = List.all (fn (x)=> not(x=p)) inExprTable
    val pcList: ExprDD.Expr list  = List.filter processNameCheck asml
    val inList: ExprDD.Expr list  = List.filter invariantCheck asml

    fun buildPrg []      = raise Fail "buildProcPar: process list should not be empty"
      | buildPrg [p]     = mk_var (ExprLib.getNmIdent p,semConst.prgTy)
      | buildPrg (p::ps) = 
	list_mk_comb(mk_const("OR",semConst.prgBinTy),[buildPrg [p],buildPrg ps])

   (* buildTerm pcList *) 
    val procsTerm  = buildPrg pcList;
					(* mk_var("PRG",TypeHol.typeInHol (
  				TypePara.parseInLine "(((var -> val) -> (var -> val) -> bool) -> bool)"));
   					*)

    fun buildPred []      = raise Fail "buildProcPar: process list should not be empty"
      | buildPred [p]     = ExprHolSem.predInHol p (* exConst.TermS (ExprLib.toString p) *) 
      | buildPred (p::ps) = mk_comb(mk_comb(semConst.TermB_ "OR",buildPred [p]),buildPred ps)


    val invarTerm  = if (flag) 
		     then (buildPred inList) 
		     else (buildPred (unfoldInvariant spList inList))
    (* is allowed to have different instantiation for OR, 
       one for process and other for predicate ?           *)    

    val operTerm      = semConst.unityTerm ((implode o (map Char.toUpper) o explode) oper)

    val (pTerm,qTerm) = (ExprHolSem.predInHol p, ExprHolSem.predInHol q)

    val varTerm       = mk_var ("VARLIST", TypeHol.typeInHol (TypePara.parseInLine "(var -> bool)"));

    in
	(("VARLIST",varList),
         ("PRG",pcList),
         list_mk_comb (operTerm,[procsTerm,varTerm,invarTerm,pTerm,qTerm])
        )
    end
  | unityInHol flag spList _ =
    raise Fail "PLPCHol.unityInHol: Not a unity specification." 
;

(* ============================================================
(*DOC

<ITEM> specInHol
<TYPE> specInHol PLPCDD.SpecList -> Term.term
<CALL> specInHol specList

<DESC> Transform process specification list to hol term.

DOC*)
============================================================ *)
(*
fun specInHol spList = 
    let val (nmList,specList) = ListPair.unzip spList
        fun chooseFun (PLPCDD.Valid x) = ?
           
    in
    
    end
*)

(* ============================================================
(*DOC

<ITEM> unityFromHol 
<TYPE> unityFromHol : 'a list -> Term.term -> PLPCDD.ProcSpecs
<CALL> unityFromHol context unityTerm 

<DESC> Parse Unity specification in Hol to ML representation.

DOC*)
============================================================ *)
(* val unityFromHol : 'a list -> Term.term -> PLPCDD.ProcSpecs; *)


fun unityFromHol context unityTerm = let
    fun destAll_comb te = 
        if (is_comb te) 
	then (let val (te0,te1) = dest_comb te
              in  (destAll_comb te0) @ [te1]
              end)
        else [te]
          
    val termList  = destAll_comb unityTerm
    val operTerm  = List.nth (termList, 0)
    val ProcsTerm = List.nth (termList, 1)
    val varTerm   = List.nth (termList, 2)
    val invarTerm = List.nth (termList, 3)
    val pTerm     = List.nth (termList, 4)
    val qTerm     = List.nth (termList, 5)


    in
       List.map ExprHolSem.predFromHol termList
    end

end

end (* of local *)

