
(* ============================================================
(*DOC

<MODULE> PLPCLib

<AUTHOR>underdarkprime & ade 
<ADRESS>underdarkPrime@yahoo.com & ade@cs.uu.nl

<DATE> September 2001

<DESC>Provide utilities to work on PLPC program.

DOC*)
============================================================ *)
structure PLPCLib = struct


(* getVarTypeList:PLPCDD.VarDeclList -> (string * TypeDD.Type) list) *)
fun getVarTypeList varDecls = 
    let 
       fun get_ (PLPCDD.NOINIT (_,ty,strl),b)  = (List.map (fn (x)=> (x,ty)) strl) @ b
         | get_ (PLPCDD.INIT   (_,ty,str,_),b) = (str,ty)::b
    in
        List.foldr get_ [] varDecls
    end 

fun getContextInfo (procRep:PLPCDD.ProcClass) = 
    let val (_,extDecl,intDecl,_,_) = procRep
        val extContext    = getVarTypeList extDecl 
        val intContext    = getVarTypeList intDecl
    in 
        intContext @ extContext
    end

(* 
a quick fix type checker for UNITY PLGA specs... We should have a
neater checker in the future versions 
by : Wishnu
*)

val ty_bool	= TypeDD.TyCons ("bool",[]) 		;

fun specTypeChecker typeContext (PLPCDD.INVARIANT (J,e))
                =
                let
                val (e',_) = ExprLib.tiInferX typeContext ty_bool e
                in
                PLPCDD.INVARIANT (J,e')
                end 
  | specTypeChecker typeContext (PLPCDD.UNITYREL (PJ,rel,p,q,V))
                =
                let
                val (p',_) = ExprLib.tiInferX typeContext ty_bool p
                val (q',_) = ExprLib.tiInferX typeContext ty_bool q
                in
                PLPCDD.UNITYREL (PJ,rel,p',q',V)
                end
  | specTypeChecker typeContext (PLPCDD.VALID ([],e))
                =
                let
                val (e',_) = ExprLib.tiInferX typeContext ty_bool e
                in
                PLPCDD.VALID ([],e')
                end  
  | specTypeChecker typeContext (PLPCDD.STABLE (asml,p))
                =
                let
                val asml'  = List.map (Lib.fst o (ExprLib.tiInferX typeContext ty_bool)) asml
		val (p',_) = ExprLib.tiInferX typeContext ty_bool p
                in
                PLPCDD.STABLE (asml',p')
                end  
;

fun specListTypeCheck typeContext specList = 
    let fun tyCheck (nm,sp) = (nm,specTypeChecker typeContext sp) 
    in
      List.map tyCheck specList
    end


fun getPLGA procRep = 
     let val (_,_,_,_,plgaStmts) = procRep
     in plgaStmts
     end

(* function to unfold the invariant with it definition *)


fun asmlPreprocessing (specList:PLPCDD.SpecList) (asmList:ExprDD.Expr list) = 
    let

        fun getDesc spList (inv,invL) = 
             let fun inv_eq inv (_,PLPCDD.INVARIANT (x,desc)) = (inv = x)
                   | inv_eq inv _                             = false
                 fun getDesc_ (PLPCDD.INVARIANT (x,desc)) = desc
                   | getDesc_ _  = raise Fail "PLPCHol.unfoldInvariant: ??? "
             in   
                 case (List.find (inv_eq inv) spList) of 
                   NONE           => invL
                 | SOME (nm,spec) => (getDesc_ spec)::invL
             end

        in
            List.foldr (getDesc specList) [] asmList
        end


fun isUnitySpec (PLPCDD.UNITYREL x) = true
  | isUnitySpec _                   = false


