
structure PLPCRules = struct

local 

open PLPCHol;

in
(* ============================================================
(*DOC

<MODULE>PLPCRules

<AUTHOR>underdarkprime & ade 
<ADRESS>underdarkPrime@yahoo.com & ade@cs.uu.nl
<DATE>September 2001

<DESC> This module provides the proof obligation generator
of PLPC program and specification. <B> PLPC <B> is an abbreviation of
<i> Programming Logic for Process Class </i>. 

The language of PLPC consists of the language of programs, which is
used to express or write program as one process, and a specification language which
is used to express a specification of a program. The programming
language is Promela-like. <p>

The specification language can be written in UNITY-kind of language,
or simple predicate logic.

Both the programming and specification languages share an expression
language. We will used the expression language defined by ExprDD and
ExprParser. It is a very rich expression language, and with it we can
easily express complicated specifications (think for example a sorting
program; the program itself may only use an array, but its
specification is complicated). <p>

To be more precise, PLPC is actually not a logic for a complete
programs. It is a logic of processes, it construct a complete
program from smaller logic such as PLGA and PLSEQ. 
It parses the program processing the process correlation and 
variable use in the program; and extracts the PLGA program
and PLGA specification. In other word it decomposes the specification
and composes proof obligation of the program. 

DOC*)
============================================================ *)

(* mechanisme *)

(* TO DO *)
(* [=] 1. Extract variable name and its type put it in a list of (name,type) list *)

(* [=] 2. Create labs_table *)

(* [=] 3. Identified specification type, whether it's unless,ensures, of simple prop *)

(* [a] 4. Identified varible constraint, read and write, ignoring variable that would not
          be used *)

(* [-] 5. Identified any process that might change the sensitive variable, 
          merge those processes.
          omit this, it would bie handled in unity. 
*)

(* [a] 6. Identified labeled proposition that might not be reach, remove it *)

(* [=] 7. Generate hoa specification to be proven.  *)

(* legend : a -> advanced  (second phase) *)

(* task 3 *)

(* having the list of specification
   
   execute the appropriate VCG (verification condition generator) 
   
   first identified the operator of the unity spec ;
*)

(* task 5, identified and progapate the necessarily process class, to be included
   it doesn't have to... 
 *)

(* methods: 

   Check the variable use list. 
   for all variable in  the formula which is not in the list.
   make sure that the variable remain insensitive to the formula.
   postponed...

   for a while just apply the compositional rule of unity,
   and define preserves property.

*)



(* help function to prepare the input *)


local 

fun getVarDecl (_,varDecl1, varDecl2, _, _) = (varDecl1 @ varDecl2);

fun mkVarList []       = []
  | mkVarList (v::dl)  = (mkVarList dl) @ (
                        case v of
                        PLPCDD.NOINIT (_, ty, strl) => map (fn (x)=> (x,ty)) strl

                      | PLPCDD.INIT   (_, ty, str,_ ) => [(str,ty)])
in
fun getVarList pDecl = mkVarList (getVarDecl pDecl)
end

fun getName (nm,_,_,_,_) = nm;

fun getLabelizePLGA (nm,_,_,_,ga) = PLGALib.labelize nm ga ;

fun addPname nm lns = map (fn (x,y)=> ("SYSLAB."^nm^"."^x,y)) lns


(* decomposition function *)


(* ============================================================
(*DOC

<ITEM>decomposeUnity 
<TYPE>decomposeUnity : spec List -> PLPCDD.ProcSpec -> PLPCDD.ProcSpec list
<CALL>decomposeUnity flag spList spec

<DESC> decomposing the composite unity specification
(a specification which its program input contain a parrarel operator.) 

DOC*)
============================================================ *)

fun decomposeUnity spList (PLPCDD.UNITYREL (exprl, (operator,ty), p, q, varList)) =
    let 
    fun getInvNm (PLPCDD.INVARIANT (e,_)) = e
      | getInvNm _                        = raise Fail "PLPCRules.decomposeUnity: ill formed invariant" 

    val inExprTable = List.map (getInvNm o Lib.snd)
                      (List.filter 
                            (fn(x,y) => (x="invariant") 
                           			     ) spList)

    fun invariantCheck   e = List.exists (fn (x)=> (x=e)) inExprTable
    fun processNameCheck p = List.all (fn (x)=> not(x=p)) inExprTable

    val pcList  = List.filter processNameCheck exprl
    val inList  = List.filter invariantCheck exprl

    fun mkUnless p q v asml = PLPCDD.UNITYREL (asml::inList,("unless",TypeDD.TyVar "a"),p,q,v)
    in
     case operator of 
      "unless"  => List.map (mkUnless p q varList) pcList
(*
    | "ensures" => (unityFromHol o applyHol) (unityInHol spList (exprl, (operator,ty), p, q, varList))
    | "leadsto" => (unityFromHol o applyHol) (unityInHol spList (exprl, (operator,ty), p, q, varList))
*)
    | _        => raise Fail "PLPCRules.decomposeUnity: unimplemented operator decomposition"

    end
  | decomposeUnity spList (PLPCDD.INVARIANT _) = []
  | decomposeUnity spList x = [x] 
; 

fun decomposeSpec spL (nm,spec) = let
     val decomposed    =  (decomposeUnity spL spec)

     fun naming nm n [] = [] 
       | naming nm n (a::b) = (nm^"#"^(Int.toString n),a)::(naming nm (n+1) b)

     in
     if (List.length decomposed = 1) then [(nm,spec)]
     else 
	naming nm 0 decomposed           
     end


(* unfold the use of fold to make it more efisien *)
fun compDetect spList (PLPCDD.UNITYREL (expl,_,_,_,_)) 
	   = let 

    fun getInvNm (PLPCDD.INVARIANT (e,_)) = e
      | getInvNm _                        = raise Fail "PLPCRules.compDetect: ill formed invariant" 

    val inExprTable = List.map (getInvNm o Lib.snd)
                      (List.filter 
                            (fn(x,y) => (x="invariant") 
                           			     ) spList)

    fun processNameCheck p = List.all (fn (x)=> not(x=p)) inExprTable

    val pcList  = List.filter processNameCheck expl
    val result  = List.length pcList
	     in 
	         if (result>1) then true else false
	     end 
  | compDetect _ _                     
	   = false 
;

(* task 7, VCG *)

fun mk_goal_tuple asl hyp = List.map (fn (x)=> (asl,x)) hyp ;

fun VCGspec labs_table atomic (PLPCDD.VALID (asl,exp)) = 
       let
          val hyp = PLGARules.validReductionRule labs_table atomic exp
       in
          (asl, hyp,[])
       end
  | VCGspec labs_table atomic (PLPCDD.UNITYREL (asl,oper,p,q,var)) = 
      (case oper of
         ("unless",_) 
                  => let val hyp = PLGARules.unlessReductionRule labs_table atomic p q
                     in (asl, hyp, [])
                     end
       | ("ensures",_) 
                  => let val (hyp0,hyp1) = PLGARules.ensuresReductionRule labs_table atomic p q
                     in (asl, hyp0, hyp1) 
                     end
       |  _       => raise Fail ("VCG for: "^ (Lib.fst oper) ^ " is under construction"))
  | VCGspec labs_table atomic (PLPCDD.STABLE (asl,p) ) = 
                     let val hyp = PLGARules.stableReductionRule labs_table atomic p 
                     in (asl, hyp, [])
                     end
  | VCGspec labs_table atomic (PLPCDD.INVARIANT (_,J)) = 
	             let val hyp = PLGARules.stableReductionRule labs_table atomic J 
                     in ([], hyp, [])
                     end
  | VCGspec labs_table atomic ( _ ) =  raise Fail ("VCG: is under construction")  

;



(* function to generate the proof obligation, 
   for independent process and its specification 
  
   Before call this function make sure, the top reduce allready
   decompose any composed specifications.

   TODO:
   
   [ ] checking for dependency to other process
       checking the absence of others processClass name in it's assumption list. 
*)


fun reduceLocalSpec nm = 
    let
       (* naming convention *)
       val specFile   = nm^".spc";
       val progFile   = nm^".pc";

       (* parsing all the input, including basic library (in exConst) *)
       val sp_        = PLPCPara.parseS specFile;
       val pc0        = PLPCPara.parse progFile;
       val allSibling = let val (_,_,_,procDecl,_) = pc0
                            fun getName (PLPCDD.ARRAY  (nm,_,_,_,_)) = nm
                              | getName (PLPCDD.SINGLE (nm,_,_)) = nm
                            fun inExpr x = ExprDD.Ident (x,TypeDD.TyVar "a")
                        in 
	                   List.map (inExpr o getName) procDecl
                        end
       fun is_system (ExprDD.Ident ("System",_)) = true
         | is_system _ = false

       fun subst_ []      = []
         | subst_ (a::ps) = if (is_system a) then (allSibling @ subst_ ps)
	                    else (a::(subst_ ps))

       fun substSystem (x,y) = (x, case y of
	                       PLPCDD.UNITYREL (asml,ope,p,q,varlist) 	=>
	                              PLPCDD.UNITYREL (subst_ asml,ope,p,q,varlist)
	                     | PLPCDD.VALID (asml,p) 			=> 
	                              PLPCDD.VALID (subst_ asml,p)
                             | PLPCDD.PRESERVES (asml,proc,p,var,q) 	=>
	                              PLPCDD.PRESERVES (subst_ asml,proc,p,var,q)
	                     | PLPCDD.INVARIANT z  			=> 
				      PLPCDD.INVARIANT z
	                     | PLPCDD.DNF z        			=> 
				      PLPCDD.DNF z  
			     | PLPCDD.STABLE (asml,p)     		=> 
				      PLPCDD.STABLE (subst_ asml,p)	
				)

   
       val sp0        =  List.map substSystem sp_
       val sc0 =
	let
            fun f (v,t,_,_) = (v, TypePara.parseInLine t)
	    in 
	        map f exConst.context
	    end 

       (* decompose specification *) 
       val spDecomL  = List.concat (List.map (decomposeSpec sp0) sp0)

       (* extract some fields from the PC and environment: 
          name, actions, label tabel, variable list *)

       val nm0        = getName pc0;
       val ga         = getLabelizePLGA pc0;
       val localsc    = getVarList pc0;
       val atomics    = PLGALib.spitAtomics (localsc @ sc0) ga;
       val labs_table = addPname nm (PLGALib.mk_label_tab ga);

       (* generator *)
       val generator  = VCGspec labs_table atomics;
       fun applyGen (nm,spec) = (nm,generator spec)
    in 
       List.map applyGen spDecomL
    end

end (* end local open *)
end (* end structure *)

