

load "xMECHlogo" ;

load "TypeDD" ;			
load "PLSEQDD" ;
load "ExprDD" ;

load "TypePP" ;
load "ExprPP" ;
load "ExprLib" ;
load "ExprHol" ;

load "PLSEQLib" ;
load "PLSEQPara" ;
load "PLSEQRules" ;
load "exConst" ;

load "bossLib";
load "intLib";

open bossLib intLib ;

(* installing pretty printer ... switch the flag in ppExpr to true if
you want to make the typing of the expressions to be visible *)

installPP TypePP.ppType ;
installPP (ExprPP.ppExpr false) ;

val ty_bool 	  = TypeDD.TyCons ("bool",[]) ;
val ty_int	  = TypeDD.TyCons ("int",[]) ;
fun ty_array a	  = TypeDD.TyCons ("array",[a]) ;

(* 
Import the info on the types of all known Expr-constants. This info
is specified in the module exConst 
*)

val level1_StaticContext =
	let
	fun f (v,t,_,_) = (v, TypePara.parseInLine t)
	in 
	map f exConst.context
	end ;


(*

The following function read a PLSEQ program from a file, and also type
check it using the static context information and varContext_of DemoProgram.

 In addition of checking the type correctness of the program
(and its pre-post specification), the type checker also properly
decorates all expressions with type info. We need the type info to on
a later stage translate them to HOL.

The type checking/inferencing isn't as general as it can be. For
example, no type-unification info from the type checking of the
precondition is carried through the type checking of the program and
its post condition. With some programming we can make it more general,
but I guess for now this will do.

*)

fun parseProgram varContext_ofProgram fname 
	=
	let
	(*
	The entire type context is the level1 static context plus the demo
	program's type context above.
	*)
	
	val total_typeContext = level1_StaticContext @ varContext_ofProgram ;

	val PLSEQDD.Hoa (pre,stmt,post) = PLSEQPara.parse fname
	val (pre',_)  = ExprLib.tiInferX total_typeContext ty_bool pre
	val (post',_) = ExprLib.tiInferX total_typeContext ty_bool post
	val stmt'     = PLSEQLib.typeCheck total_typeContext stmt
	in
	PLSEQDD.Hoa (pre',stmt',post')
	end ;


val genVerificationConditions = PLSEQRules.topReduce ;


(* a function to translate to HOL *)

fun translate2HOL vcs 
	= 
	foldr mk_conj (--`T`--) (map ExprHol.exprInHol vcs) ;


val UNDISCH_ALL_TAC 
	=
	let
	fun thm_tac asm = UNDISCH_TAC (concl asm)
	in
	EVERY_ASSUM thm_tac
	end ;

(* Manually defining the ARRAYREAD operator *)

val ARRAYREAD_def 
	= 
	new_definition("ARRAYREAD_def",
	--`ARRAYREAD i a = a i`--) ;


print xMECHlogo.xMECHlogo ;

print "PLSEQ enviroment loaded... you can now continue with the interactive demo.\n\n" ;


