(* 
File name : verySimpleDemo.sml
 
Demo file for proving Linear Search with Break example 
to be used in interactive session.
*)

(* some users may wish to run these first four lines  manually *) 


val xmech_sigobj_loc 	= "../../..";
val env_loc 		= "../";

loadPath := xmech_sigobj_loc :: !loadPath ;
use (env_loc^"PLSEQ_environment.sml");


(* 

Manually construct the info on the type of variables used in the
demo-program. In a real application this info should of course be
constructed automatically by the parser. As it is now, PLSEQ does not
have a declaration section. It is intended to be a part of a larger
language which does have a declaration section. That's the reason why
we now have to construct the typing context by hand.

*)

val typeContext_ofDemoProgram =
	let
	val p = TypePara.parseInLine;
	in
	[("a", p "bool"), 
	 ("x", p "int"), 
	 ("y", p "int"), 
	 ("z", p "int")] 

	end


(*
The entire type context is the level1 static context plus the demo
program's type context above.
*)

val total_typeContext = level1_StaticContext @ typeContext_ofDemoProgram ;

(*

The following function read a PLSEQ program from a file, and also type
check it. In addition of checking the type correctness of the program
(and its pre-post specification), the type checker also properly
decorates all expressions with type info. We need the type info to on
a later stage translate them to HOL.

The type checking/inferencing isn't as general as it can be. For
example, no type-unification info from the type checking of the
precondition is carried through the type checking of the program and
its post condition. With some programming we can make it more general,
but I guess for now this will do.

*)

fun parseProgram fname 
	=
	let
	val PLSEQDD.Hoa (pre,stmt,post) = PLSEQPara.parse fname
	val (pre',_)  = ExprLib.tiInferX total_typeContext ty_bool pre
	val (post',_) = ExprLib.tiInferX total_typeContext ty_bool post
	val stmt'     = PLSEQLib.typeCheck total_typeContext stmt
	in
	PLSEQDD.Hoa (pre',stmt',post')
	end ;

val genVerificationConditions = PLSEQRules.topReduce ;

print xMECHlogo.xMECHlogo ;

print "Enviroment loaded... you can now continue with the interactive demo.\n\n" ;


(*

(* reading the program now.... *)

val theProgram = parseProgram "verySimple.plseq" ;

(* generating the verification conditions *)

val generatedVCs = genVerificationConditions theProgram ;

(* a function to translate to HOL *)

fun translate2HOL vcs 
	= 
	foldr mk_conj (--`T`--) (map ExprHol.exprInHol vcs) ;


val UNDISCH_ALL_TAC 
	=
	let
	fun thm_tac asm = UNDISCH_TAC (concl asm)
	in
	EVERY_ASSUM thm_tac
	end ;

(* Starting interactive HOL proof now ... *)

set_goal([], translate2HOL generatedVCs) ;

(* try to simplify the expression *)

e (RW_TAC std_ss []) ;

(* results in two goals... this corresponds to the two cases
introduced by the conditional in the demo program *)

(* first sub goal ... using COOPER_TAC *)

e (UNDISCH_TAC (--`(x:int)>0`--) THEN COOPER_TAC);

(* second sub goal... the same *)

e (UNDISCH_TAC (--`(x:int)>0`--) THEN COOPER_TAC);

(* NOTE: would be nicer if we can simply do UNDISCH_ALL then
COOPER... but this fails because COOPER refuses to accept the a and ~a
term, which is not an arithmatic term. *)

*)






