structure PLSEQHOL  = struct


(* ============================================================
(*DOC

<MODULE> PLSEQHOL
<AUTHOR> underdarkPrime & ade
<ADDRESS> underdarkPrime@yahoo.com & ade@cs.uu.nl

<DATE> 13 August 2001

<DESC>Provide transformation from PLSEQ structure into HOL term
(value of type PLSEQDD.Stmt and PLSEQDD.SEQSpec). 

DOC*)
============================================================ *)

open PLSEQTheory

local

open PP PLSEQDD ExprHol TypeHol 

in




fun mk_seq [st]       = PLSEQInHol s
  | mk_seq (st::sts)  = mk_comb(mk_comb(Term`$SEQ`, PLSEQInHol st), 
                                mk_seq sts)

and mk_case ([],dst)            = PLSEQInHol dst
  | mk_case (((g,st)::ess),dst) = PLSEQInHol (IfElse (g,st,mk_case (ess,dst)))

and PLSEQInHol stmt = case stmt of

             Skip         => Term`SKIP`     
           | Asg (v,e)    => mk_comb(mk_comb(Term`ASG`, mk_var(v,Type`:string`)),
                                     exprInHol e)
                          
           | Inc  v       => let 
                                val vt = mk_var (v,Type`:string`)
                             in
                                Term`ASG ^vt (\x. num_val (val_num (x ^vt) + 1))`
                             end

           | Dec  v       => let 
                                val vt = mk_var (v,Type`:string`)
                             in
                                Term`ASG ^vt (\x. num_val (val_num (x ^vt) - 1))`
                             end

           | Seq  sl      => mk_seq sl

           | IfThen (g,s) => let 
                                val (gt,st) = (exprInHol g,PLSEQInHol s)
                             in
                                Term`IFTHEN ^gt ^st`
                             end
                                  
           | IfElse (g,s,t) => 
                             let 
                                val (gt,st,tt) = (exprInHol g,PLSEQInHol s,PLSEQInHol t)
                             in
                                Term`IFTHENELSE ^gt ^st ^tt`
                             end

           | Case (ess,st)  => mk_case (ess,st)


           | While (i,g,s) =>let 
                                val (it,gt,st) = (exprInHol i, exprInHol g, PLSEQInHol s)
                             in
                                Term`WHILEINV ^gt ^it ^st`
                             end 

(* Need some conventions about the guard, correlation which Verification generator    *)

           | ForLoop (I,i,lb,up,inc,body) => 
                             let 
                                val (it,gt,st) = (exprInHol i, exprInHol g, PLSEQInHol s)
                             in
                                Term`FORLOOP `
                             end 


and SEQSpecInHol spec = case spec of 
    EVERY e0          => ExprInHol e0
  | Hoa  (e1,stmt,e2) => let 
                            val stmth = PLSEQInHol stmt
                            val e1h   = ExprInHol e1
                            val e2h   = ExprInHol e2
                         in 
                         mk_comb(mk_comb(mk_comb(Term`HOA`,stmth),e1h),e2h) 
                         end

end
end
