local open Obj Lexing in


 open Lexing PLSEQParser;

 exception LexicalError of string * int * int (* (message, loc1, loc2) *)

 fun lexerError lexbuf s = 
     raise LexicalError (s, getLexemeStart lexbuf, getLexemeEnd lexbuf);

 val commentStart = ref 0;  (* Start of outermost comment being scanned *)
 
 fun commentNotClosed lexbuf =
     raise LexicalError ("Comment not terminated", 
                         !commentStart, getLexemeEnd lexbuf);
     
val commentDepth = ref 0;  (* Current comment nesting *)

 (* Scan keywords as identifiers and use this function to distinguish them. *)
 (* If the set of keywords is large, use an auxiliary hashtable.            *)

fun keyword s =
     case s of
         "T"            => LIT_TRUE
       | "F"            => LIT_FALSE
       | "int"		=> INT
       | "bool"		=> BOOL
       | "max"		=> MAX
       | "min"		=> MIN
       | "div"          => DIV
       | "mod"          => MOD
       | "elem"         => ELEM
       | "IN"           => IN
       | "SET"		=> SET
       | "if"		=> IF
       | "else"		=> ELSE
       | "switch"	=> SWITCH
       | "case"		=> CASE
       | "default"	=> DEFAULT
       | "while"	=> WHILE
       | "inv"		=> INV
       | "for"		=> FOR
       | _              => IDENT s

fun special s = case s of
	  "="		=> EQUAL
	| "~"		=> NOT
	| "/\\"		=> AND
	| "\\/"		=> OR
	| "==>"		=> IMPLIES
	| "?"		=> EXISTS
	| "!"		=> FORALL
	| "<"		=> LT
	| "<="		=> LTE
	| ">"		=> GT
	| ">="		=> GTE
	| "+"		=> PLUS
	| "-"		=> MINUS
	| "*"		=> TIMES
	| "^"		=> POWER
	| "/"		=> DIVIDE
	| "::"		=> CONS
	| "++"		=> PLUSPLUS
	| "--"		=> MINMIN
	| "!!"		=> NTH
	| "|_|"		=> UNION
	| "|^|"		=> INTERSECT
	| "<+"		=> INSERT
	| "#"		=> ARRAYACCESS	
	| ">>"		=> FUNAPP
(* added 24 october *) 
        | "<-"          => IS_FROM 

	| _             => IDENT s
 
fun action_27 lexbuf = (
 lexerError lexbuf "Illegal symbol in input" )
and action_26 lexbuf = (
 EOF )
and action_25 lexbuf = (
 COLON )
and action_24 lexbuf = (
 COMA )
and action_23 lexbuf = (
 SEMI )
and action_22 lexbuf = (
 RACOL )
and action_21 lexbuf = (
 LACOL )
and action_20 lexbuf = (
 RSBRAC )
and action_19 lexbuf = (
 LSBRAC )
and action_18 lexbuf = (
 RSETBRAC )
and action_17 lexbuf = (
 LSETBRAC )
and action_16 lexbuf = (
 RHOABRAC )
and action_15 lexbuf = (
 LHOABRAC )
and action_14 lexbuf = (
 RLISTBRAC )
and action_13 lexbuf = (
 LLISTBRAC )
and action_12 lexbuf = (
 LIT_EMPTYLIST )
and action_11 lexbuf = (
 LIT_EMPTYSET )
and action_10 lexbuf = (
 RPAR )
and action_9 lexbuf = (
 LPAR )
and action_8 lexbuf = (
 special (getLexeme lexbuf) 			)
and action_7 lexbuf = (
 keyword (getLexeme lexbuf) 			)
and action_6 lexbuf = (
 LIT_I (getLexeme lexbuf)			)
and action_5 lexbuf = (
 commentStart := getLexemeStart lexbuf;
                          commentDepth := 1; 
                          SkipComment lexbuf; Token lexbuf 		)
and action_4 lexbuf = (
 Token lexbuf 					)
and action_3 lexbuf = (
 SkipComment lexbuf )
and action_2 lexbuf = (
 commentNotClosed lexbuf )
and action_1 lexbuf = (
 commentDepth := !commentDepth + 1; 
                          SkipComment lexbuf )
and action_0 lexbuf = (
 commentDepth := !commentDepth - 1;  
                          if !commentDepth = 0 then ()
                          else SkipComment lexbuf 
                        )
and state_0 lexbuf = (
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"*" => state_37 lexbuf
 |  #"(" => state_36 lexbuf
 |  #"\^Z" => action_2 lexbuf
 |  #"\^@" => action_2 lexbuf
 |  _ => action_3 lexbuf
 end)
and state_1 lexbuf = (
 let val currChar = getNextChar lexbuf in
 if currChar >= #"A" andalso currChar <= #"Z" then  state_14 lexbuf
 else if currChar >= #"a" andalso currChar <= #"z" then  state_14 lexbuf
 else if currChar >= #"0" andalso currChar <= #"9" then  state_10 lexbuf
 else case currChar of
    #"!" => state_5 lexbuf
 |  #"#" => state_5 lexbuf
 |  #"+" => state_5 lexbuf
 |  #"*" => state_5 lexbuf
 |  #"/" => state_5 lexbuf
 |  #"<" => state_5 lexbuf
 |  #"?" => state_5 lexbuf
 |  #">" => state_5 lexbuf
 |  #"\\" => state_5 lexbuf
 |  #"_" => state_5 lexbuf
 |  #"^" => state_5 lexbuf
 |  #"|" => state_5 lexbuf
 |  #"~" => state_5 lexbuf
 |  #"\n" => action_4 lexbuf
 |  #"\t" => action_4 lexbuf
 |  #"\r" => action_4 lexbuf
 |  #" " => action_4 lexbuf
 |  #"}" => state_18 lexbuf
 |  #"{" => state_17 lexbuf
 |  #"]" => state_16 lexbuf
 |  #"[" => action_19 lexbuf
 |  #"=" => state_13 lexbuf
 |  #";" => action_23 lexbuf
 |  #":" => action_25 lexbuf
 |  #"-" => state_9 lexbuf
 |  #"," => action_24 lexbuf
 |  #")" => action_10 lexbuf
 |  #"(" => state_6 lexbuf
 |  #"\^@" => action_26 lexbuf
 |  _ => action_27 lexbuf
 end)
and state_5 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_8);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"!" => state_23 lexbuf
 |  #"#" => state_23 lexbuf
 |  #"+" => state_23 lexbuf
 |  #"*" => state_23 lexbuf
 |  #"-" => state_23 lexbuf
 |  #"/" => state_23 lexbuf
 |  #"?" => state_23 lexbuf
 |  #">" => state_23 lexbuf
 |  #"=" => state_23 lexbuf
 |  #"<" => state_23 lexbuf
 |  #"\\" => state_23 lexbuf
 |  #"_" => state_23 lexbuf
 |  #"^" => state_23 lexbuf
 |  #"|" => state_23 lexbuf
 |  #"~" => state_23 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_6 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_9);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"*" => action_5 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_9 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_8);
 let val currChar = getNextChar lexbuf in
 if currChar >= #"0" andalso currChar <= #"9" then  state_25 lexbuf
 else case currChar of
    #"!" => state_23 lexbuf
 |  #"#" => state_23 lexbuf
 |  #"+" => state_23 lexbuf
 |  #"*" => state_23 lexbuf
 |  #"-" => state_23 lexbuf
 |  #"/" => state_23 lexbuf
 |  #"?" => state_23 lexbuf
 |  #">" => state_23 lexbuf
 |  #"=" => state_23 lexbuf
 |  #"<" => state_23 lexbuf
 |  #"\\" => state_23 lexbuf
 |  #"_" => state_23 lexbuf
 |  #"^" => state_23 lexbuf
 |  #"|" => state_23 lexbuf
 |  #"~" => state_23 lexbuf
 |  #"{" => state_27 lexbuf
 |  #"[" => state_26 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_10 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_6);
 let val currChar = getNextChar lexbuf in
 if currChar >= #"0" andalso currChar <= #"9" then  state_25 lexbuf
 else backtrack lexbuf
 end)
and state_13 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_8);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"!" => state_23 lexbuf
 |  #"#" => state_23 lexbuf
 |  #"+" => state_23 lexbuf
 |  #"*" => state_23 lexbuf
 |  #"-" => state_23 lexbuf
 |  #"/" => state_23 lexbuf
 |  #"?" => state_23 lexbuf
 |  #">" => state_23 lexbuf
 |  #"=" => state_23 lexbuf
 |  #"<" => state_23 lexbuf
 |  #"\\" => state_23 lexbuf
 |  #"_" => state_23 lexbuf
 |  #"^" => state_23 lexbuf
 |  #"|" => state_23 lexbuf
 |  #"~" => state_23 lexbuf
 |  #"}" => action_16 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_14 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_7);
 let val currChar = getNextChar lexbuf in
 if currChar >= #"0" andalso currChar <= #"9" then  state_22 lexbuf
 else if currChar >= #"A" andalso currChar <= #"Z" then  state_22 lexbuf
 else if currChar >= #"a" andalso currChar <= #"z" then  state_22 lexbuf
 else case currChar of
    #"'" => state_22 lexbuf
 |  #"." => state_22 lexbuf
 |  #"_" => state_22 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_16 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_20);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"-" => action_14 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_17 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_21);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"=" => action_15 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_18 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_22);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"-" => action_18 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_22 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_7);
 let val currChar = getNextChar lexbuf in
 if currChar >= #"0" andalso currChar <= #"9" then  state_22 lexbuf
 else if currChar >= #"A" andalso currChar <= #"Z" then  state_22 lexbuf
 else if currChar >= #"a" andalso currChar <= #"z" then  state_22 lexbuf
 else case currChar of
    #"'" => state_22 lexbuf
 |  #"." => state_22 lexbuf
 |  #"_" => state_22 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_23 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_8);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"!" => state_23 lexbuf
 |  #"#" => state_23 lexbuf
 |  #"+" => state_23 lexbuf
 |  #"*" => state_23 lexbuf
 |  #"-" => state_23 lexbuf
 |  #"/" => state_23 lexbuf
 |  #"?" => state_23 lexbuf
 |  #">" => state_23 lexbuf
 |  #"=" => state_23 lexbuf
 |  #"<" => state_23 lexbuf
 |  #"\\" => state_23 lexbuf
 |  #"_" => state_23 lexbuf
 |  #"^" => state_23 lexbuf
 |  #"|" => state_23 lexbuf
 |  #"~" => state_23 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_25 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_6);
 let val currChar = getNextChar lexbuf in
 if currChar >= #"0" andalso currChar <= #"9" then  state_25 lexbuf
 else backtrack lexbuf
 end)
and state_26 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_13);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"]" => state_30 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_27 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_17);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"}" => state_28 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_28 lexbuf = (
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"-" => action_11 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_30 lexbuf = (
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"-" => action_12 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_36 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_3);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"*" => action_1 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_37 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_3);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #")" => action_0 lexbuf
 |  _ => backtrack lexbuf
 end)
and Token lexbuf =
  (setLexLastAction lexbuf (magic dummyAction);
   setLexStartPos lexbuf (getLexCurrPos lexbuf);
   state_1 lexbuf)

and SkipComment lexbuf =
  (setLexLastAction lexbuf (magic dummyAction);
   setLexStartPos lexbuf (getLexCurrPos lexbuf);
   state_0 lexbuf)

(* The following checks type consistency of actions *)
val _ = fn _ => [action_27, action_26, action_25, action_24, action_23, action_22, action_21, action_20, action_19, action_18, action_17, action_16, action_15, action_14, action_13, action_12, action_11, action_10, action_9, action_8, action_7, action_6, action_5, action_4];
val _ = fn _ => [action_3, action_2, action_1, action_0];

end
