structure PLSEQLib = struct

exception PLSEQ_Static_Error of string

local
open TypeDD PLSEQDD ExprLib 

fun fst (x,_) = x
fun snd (_,y) = y

val ty_bool 	= TyCons ("bool",[])
val ty_int 	= TyCons ("int",[])

fun type_of sc x = case List.find x sc of
	  SOME (_,ty) => ty
	| NONE	      => raise PLSEQ_Static_Error ("Variable " ^ x ^ " is used but undeclared.")

in



fun typeCheck sc stmt 
	= 
	let
	fun worker stmt = case stmt of

	  Skip		=> Skip

	| Asg (x,e)	=>
			let
			val ty_x      = type_of sc x
			val (e',_)   = tiInferX sc ty_x e 
			in
			Asg (x,e')
			end

	| Inc x		=>
			if type_of sc x = ty_int
			then stmt
			else raise PLSEQ_Static_Error ("Inc " ^ x ^ " on not integer variable.")

	| Dec x		=>
			if type_of sc x = ty_int
			then stmt
			else raise PLSEQ_Static_Error ("Inc " ^ x ^ " on not integer variable.")

	| Seq ss	=> Seq (map worker ss)

	| IfThen (g,s)	=> 
			let
			val (g',_) = tiInferX sc ty_bool g
			in
			IfThen (g', worker s)
			end

	| IfElse (g,s,t)	=> 
			let
			val (g',_) = tiInferX sc ty_bool g
			in
			IfElse (g', worker s, worker t)
			end

	| Case (cases,es)	=>
			let
			fun foo (g,s) =
				let
				val (g',_) = tiInferX sc ty_bool g
				in
				(g', worker s)
				end
			in
			Case (map foo cases, worker es)
			end


	| While (inv,g,s)	=> 
			let
			val (inv',_) = tiInferX sc ty_bool inv
			val (g',_) = tiInferX sc ty_bool g
			in
			While (inv',g',worker s)
			end



	| ForLoop (inv,i,lb,ub,body,inc)	=>
			(* the loop counter i has to be pre-declared *) 
			if type_of sc i <> ty_int
			then raise PLSEQ_Static_Error ("For-loop counter " ^ i ^ " has to be of type integer.")
			else 
			let
			val (inv',_) = tiInferX sc ty_bool inv
			val (lb',_) = tiInferX sc ty_int lb
			val (ub',_) = tiInferX sc ty_int ub
			in
			ForLoop (inv',i,lb',ub', worker body, worker inc)
			end
	| Relation (x,e)	=> 			
			let
			val ty_x   = type_of sc x
			val ty_l_x = TyCons ("list",[ty_x])
			val (e',_) = tiInferX sc ty_l_x e 
			in
			Relation (x,e)
			end


	in
	worker stmt
	end


end
end

