structure PLSEQPP :> PLSEQPP = struct


(* ============================================================
(*DOC
<AUTHOR> underdarkPrime & ade
<ADDRESS> underdarkPrime@yahoo.com & ade@cs.uu.nl
<MODULE> PLSEQPP

<DATE> 9 August 2001

<DESC>Provide pretty printing for PLSEQ structure (value of type
PLSEQDD.Stmt and PLSEQDD.SEQSpec). 

DOC*)
============================================================ *)

local

open PP PLSEQDD ExprPP 

in

fun add_semicolon pps               = add_string pps ";" 

fun leftSide ((ExprDD.Binary(i,e1,e2),_)::es) = e1
  | leftSide _  = raise Fail "Expression should have binary constructor"

fun rightSide (ExprDD.Binary(i,e1,e2)) = e2
  | rightSide _  = raise Fail "Expression should have binary constructor"

fun ppCase tyFlag pps [(e,s)]   = (add_string pps "case "          ;
                                   add_break pps (1,2)             ; 
                                   ppExpr tyFlag pps (rightSide e) ;
                                   add_break pps (1,6)             ;
                                   add_string pps ":"              ;
                                   add_break pps (1,6)             ;
                                   ppStmt0 tyFlag pps s            )

 
  | ppCase tyFlag pps (es::ess) = (ppCase tyFlag pps [es]          ;
                                   add_newline pps                 ;
                                   ppCase tyFlag pps ess           )

and ppStmtList tyFlag pps []        = add_string pps "}"  
  | ppStmtList tyFlag pps (st::sts) = (ppStmt0 tyFlag pps st       ;
                                       add_semicolon pps          ;
                                       add_newline pps            ;
                                       ppStmtList tyFlag pps sts  )

and ppStmt0 tyFlag pps statement = 

        case statement of
             Skip         => add_string pps "skip"
           | Asg (v,e)    => (add_string pps v            ;
                              add_string pps "="          ;
                              ppExpr tyFlag pps e         )
                          
           | Inc  v       => add_string pps (v^"++")
           | Dec  v       => add_string pps (v^"--")
           | Seq  sl      => (add_string pps "{"             ;
                              begin_block pps INCONSISTENT 0 ;
                              add_newline pps                ;
                              ppStmtList tyFlag pps sl       ;
                              end_block pps                  )

           | IfThen (g,s) => 
                             (add_string pps "if"         ;
                              add_string pps " ("         ;
                              ppExpr tyFlag pps g         ;
                              add_string pps ") "         ;
                              ppStmt0 tyFlag pps s         )
     
           | IfElse (g,s,t) => 
                             (add_string pps "if"         ;
                              add_string pps " ("         ;
                              ppExpr tyFlag pps g         ;
                              add_string pps ") "         ;
                              ppStmt0 tyFlag pps s         ;
                              add_string pps " else "      ;
                              ppStmt0 tyFlag pps t         )

           | Case (ess,st)  => 
              (add_string pps "switch ("                      ;
               ppExpr tyFlag pps (leftSide ess)               ;
               add_string pps ") {"                           ;
               begin_block pps INCONSISTENT 0	              ;
               add_newline pps                                ;
               ppCase tyFlag pps ess                          ;
               add_newline pps                                ;
               add_string pps "default :"                     ;
               ppStmt0 tyFlag pps st                          ;
               add_newline pps                                ;
               add_string pps "}"                             ;
               end_block pps                                  )

           | While (i,g,s) => 
                  (add_string pps "inv "               ;
                   ppExpr tyFlag pps i                 ;
                   begin_block pps INCONSISTENT 0      ;
                   add_newline pps                     ;
                   add_string pps " while"             ;
                   add_break pps (1,6)                 ;
                   add_string pps "("                  ;
                   ppExpr tyFlag pps g                 ;
                   add_string pps ")"                  ;
                   add_break pps (1,5)                 ;
                   begin_block pps INCONSISTENT 0      ;
                   ppStmt0 tyFlag pps s                ;
                   end_block pps                       ;
                   end_block pps                       )

           | ForLoop (I,i,lb,up,inc,body) => 
                  (add_string pps "inv "               ;
                   ppExpr tyFlag pps I                 ;
                   begin_block pps INCONSISTENT 0      ;
                   add_newline pps                     ;
                   add_string pps "for"                ;
                   add_break pps (1,5)                 ;
                   add_string pps "("                  ;
                   add_string pps (i^"=")              ;
                   ppExpr tyFlag pps lb                ;
                   add_string pps ";"                  ;
		   add_break pps (1,5)                 ;
		   add_string pps (i^"<=")             ;
                   ppExpr tyFlag pps lb                ;
                   add_string pps ";"                  ;
                   add_break pps (1,5)                 ;
		   ppStmt0 tyFlag pps inc              ;
		   add_string pps ")"                  ;
                   add_break pps (1,5)                 ;
                   begin_block pps INCONSISTENT 0      ; 
                   ppStmt0 tyFlag pps body             ;
                   end_block pps                       ;   
                   end_block pps                       )


(* ============================================================
(*DOC

<ITEM>ppStmt
<TYPE>ppStmt : bool -> ppstream  -> PLSEQDD.Stmt
<CALL>ppStmt tyFlag pps stmt 

<DESC>Pretty-print stmt using pps. If tyFlag is true, type information
will be displayed.  

DOC*)
============================================================ *)

fun ppStmt tyFlag pps stmt = 
		  (begin_block pps INCONSISTENT 0       ;
		   ppStmt0 tyFlag pps stmt              ;
		   end_block pps                        )


(* ============================================================
(*DOC

<ITEM>ppSEQSpec
<TYPE>ppSEQSpec : bool -> ppstream  -> PLSEQDD.SEQSpec
<CALL>ppSEQSpec tyFlag pps spec

<DESC>Pretty-print spec using pps. If tyFlag is true, type information
will be displayed.  


DOC*)
============================================================ *)

fun ppSEQSpec_  tyFlag pps spec = case spec of 
              Every e     => (add_string pps "|== "         ;
                              ppExpr tyFlag pps e           )

            | Hoa (p,a,q) => (add_string pps "{="           ;
                              ppExpr tyFlag pps p           ;
                              add_string pps "=}"           ;
                              begin_block pps CONSISTENT 0  ;
                              ppStmt tyFlag pps a           ;
                              end_block pps                 ;
                              add_newline pps               ;
                              add_string pps "{="           ;
                              ppExpr tyFlag pps q           ;
                              add_string pps "=}"           )
   
fun ppSEQSpec  tyFlag pps spec = 
	  (begin_block pps INCONSISTENT 0       ;
	   ppSEQSpec_  tyFlag pps spec          ;
	   end_block pps                        )

end
end

(* example *)

(*
val expr0 = Lit ("0", TyCons ("int",[]));
val expr1 = Lit ("123", TyCons ("int",[]));
val expr2 = Lit ("T", TyCons ("bool",[]));

val expr3 = Binary(("==",TyCons ("bool",[TyCons ("bool",[]),TyCons ("bool",[])])),
                   expr0  ,
                   expr1  );
val expr4 = Binary(("==",TyCons ("bool",[TyCons ("bool",[]),TyCons ("bool",[])])),
                   expr0,
                   expr2);

val asg0 = Asg("v", expr1);
val ifthen0 = IfThen (expr2,Inc "v");
val ifelse0 = IfElse (expr2,Inc "v",Dec "v");
val case0   = 
      Case ([(expr3,Inc "v"),
             (expr4,Dec "v")],
            asg0);

val while0 = While (expr3,expr2,asg0);
val forloop0 = 
      ForLoop (expr4,"v",expr0,expr1,Inc "v",asg0);

val seq0 = 
Seq [ asg0,
      ifthen0,
      ifelse0,
      case0,
      while0,
      forloop0
];


val hoa0 = Hoa (expr0,seq0,expr1);


load "ExprDD";load "TypeDD";open ExprDD;open TypeDD;
load "PLSEQDD";open PLSEQDD;
open PP;
load "PLSEQPP";

val ppstrm = mk_ppstream {consumer  = fn s => TextIO.output(TextIO.stdOut, s),
                          linewidth = 80,
                          flush     = 
	                  fn () => TextIO.flushOut TextIO.stdOut} ;

fun pp e = (PLSEQPP.ppStmt false ppstrm e ; flush_ppstream ppstrm ; print "\n")  ;

fun pp1 e = (PLSEQPP.ppSEQSpec false ppstrm e ; flush_ppstream ppstrm ; print "\n")  ;





*)
