structure PLSEQRules =  struct


local

open TypeDD ExprDD PLSEQDD

fun fst (x,_) = x
fun snd (_,y) = y

val ty_bool 	  = TyCons ("bool",[])
val ty_int	  = TyCons ("int",[])

val ty_bool_unop  = TyCons ("fun", [ty_bool, ty_bool])

val ty_bool_binop = TyCons ("fun", [ty_bool, ty_bool_unop])

val ty_int_binop = TyCons ("fun", [ty_int, TyCons ("fun", [ty_int, ty_int])])

fun mk_imp (p,q) = Binary (("==>",ty_bool_binop), p, q)

fun mk_and (p,q) = Binary (("/\\",ty_bool_binop), p, q)

fun mk_or (p,q) = Binary (("\\/",ty_bool_binop), p, q)

fun mk_not p   = Unary  (("~", ty_bool_unop), p)

val mk_T = Lit ("T", ty_bool)

fun mk_LT (p,q) = Binary (("<", ty_int_binop), p, q)

fun mk_plus (p,q) = Binary (("+", ty_int_binop), p, q)

fun mk_minus (p,q) = Binary (("-", ty_int_binop), p, q)

fun mk_intVar i = Ident (i, ty_int)

val int_1 = Lit ("1", ty_int) 
val tya   = TyVar "a"

fun mk_litVar nm = Ident (nm,tya)
fun mk_in x xl = Binary (("elem",TypePara.parseInLine "a->[a]->bool"),
			 mk_litVar x,xl)

in

fun normalizeStmt stmt = case stmt of

	  Skip		=> Skip

	| Asg _		=> stmt

	| Inc i		=> Asg (i, mk_plus (mk_intVar i, int_1))

	| Dec i		=> Asg (i, mk_minus (mk_intVar i, int_1))

	| Seq ss	=> Seq (map normalizeStmt ss)

	| IfThen (g,s)	=> Case ([(g, normalizeStmt s)], Skip)

	| IfElse (g,s,t)=> Case ([(g, normalizeStmt s)], normalizeStmt t)

	| Case (cs,t)	=> 
		let
		val cs' = map (fn (g,s)=> (g,normalizeStmt s)) cs
		val t'  = normalizeStmt t
		in
		Case (cs', t')
		end

	| While (inv,g,s)
		=> While (inv,g, normalizeStmt s)

	| ForLoop (inv,i,lb,ub,inc,s) 
		=>
		ForLoop	(inv,i,lb,ub, normalizeStmt inc, normalizeStmt s)

 	| Relation _ => stmt

fun wp stmt q = case stmt of
	  Skip		=> (q, [])

	| Asg (x,e)	=> (ExprLib.Subst x e q, [])

	| Seq []	=> (q, [])

	| Seq (s::ss)	=>
		let
	   	val (wp_ss, vc_ss) = wp (Seq ss) q
		val (wp_s , vc_s)  = wp s wp_ss

		in
		(wp_s ,vc_s @ vc_ss)
		end


        | Case (cs,t) 	=>
		let
		fun foo (guard,st) = 
			let
			val (wp_st, vc) = wp st q
			in
			(mk_imp (guard, wp_st), vc)
			end

		val (wps,vcs) 		= ListPair.unzip (map foo cs)

		val wp_cs     		= foldr mk_and mk_T wps

		fun opr ((guard,_),r) 	= mk_and (mk_not guard, r)

		val else_guard	   	= foldr opr mk_T cs

		val (wp_t, vc_t)   	= wp t q 

		val ver_conds 		= vc_t @ List.concat vcs 

		val wp_else		= mk_imp (else_guard, wp_t)

		in
		
		(mk_and (wp_cs, wp_else), ver_conds)

		end


	
	| While (i,g,s)	=> let
			   val (wps, vc_s) = wp s i
			   in
			   (i,
			      [	mk_imp (mk_and (g,i), wps),
				mk_imp (mk_and (mk_not g, i), q) ]
			      @
			      vc_s)
			   end

	| ForLoop (inv, i, lb, ub, inc, s) =>
		let
		val init  = Asg (i,lb)
		val guard = mk_LT (Ident (i,ty_int), ub)
		val rep = Seq [init,
			       While (inv, guard, Seq [s, inc]) ]
		in
		wp rep q
		end

	| Relation (x,F) =>
			(Quantor (("?",TyVar "a"),
				  [("alpha",TyVar "a")],
				  mk_in "alpha" F, 
				  ExprLib.Subst x (mk_litVar "alpha") q),
			 [])


fun topReduce (Hoa (p,s,q))
	=
	let
	val (w,vc)= wp (normalizeStmt s) q
	in
	mk_imp (p,w) :: vc
	end
  | topReduce (Every exp) = [exp]
end

end


