local
in
datatype token =
    AND
  | ARRAYACCESS
  | AT
  | ATOMIC
  | BLOCK_TOK
  | BOOL
  | CASE
  | COLON
  | COMA
  | CONS
  | DEFAULT
  | DIV
  | DIVIDE
  | DO
  | ELEM
  | ELSE
  | EOF
  | EQUAL
  | EXISTS
  | EXIT_TOK
  | FI
  | FOR
  | FORALL
  | FUNAPP
  | GOTO
  | GT
  | GTE
  | IDENT of string
  | IF
  | IMPLIES
  | IN
  | INSERT
  | INT
  | INTERSECT
  | INV
  | INVARIANT
  | LACOL
  | LHOABRAC
  | LIT_EMPTYLIST
  | LIT_EMPTYSET
  | LIT_FALSE
  | LIT_I of string
  | LIT_TRUE
  | LLISTBRAC
  | LPAR
  | LSBRAC
  | LSETBRAC
  | LT
  | LTE
  | MAX
  | MIN
  | MINMIN
  | MINUS
  | MOD
  | NOT
  | NTH
  | NUM of int
  | OD
  | OR
  | PLUS
  | PLUSPLUS
  | POWER
  | PRESERVES
  | PROVE
  | RACOL
  | RHOABRAC
  | RIGHTARROW
  | RLISTBRAC
  | RPAR
  | RSBRAC
  | RSETBRAC
  | SEMI
  | SET
  | SKIP
  | STABLE
  | STRING
  | STRVALUE
  | SWITCH
  | TIMES
  | UNION
  | USING
  | WHILE
end;

open Obj Parsing;
prim_val vector_ : int -> 'a -> 'a Vector.vector = 2 "make_vect";
prim_val update_ : 'a Vector.vector -> int -> 'a -> unit = 3 "set_vect_item";



open TypeDD ExprDD PLSEQDD PLGADD;

val type_a	  = TyVar  "a"
val type_int	  = TyCons ("int", [])
val type_bool	  = TyCons ("bool", [])
val type_string	  = TyCons ("string", []);
fun mkArray ty ln = TyCons("list",[ty]);
fun mkListString ty ln = TyCons("list",[type_string]);


fun mkUnary opr e        = Unary  ((opr, type_a), e)
fun mkBinary opr e f     = Binary ((opr, type_a), e, f)
fun mkQuantor qtr vs e f = Quantor ((qtr, type_a),vs,e,f)

fun mkEnum enr es        = Enum ((enr, type_a), es);

fun mkString nm = Ident(nm,type_string);

fun mkConstString nm = Lit("\""^nm^"\"",type_string);

val mk_T = Lit ("T", type_bool)


fun mkProcName ClassName InstantName = InstantName^"-"^ClassName ;

fun mkAccess i par = ArrayAccess (par,Ident(i,TyCons("int",[])));

fun mkProcArray cl0 nm 0   i cl pars = []
  | mkProcArray cl0 nm max i cl pars = 
	((mkProcName (nm^"["^Int.toString max^"]") cl0,
		cl,
		map (mkAccess i) pars)::
	(mkProcArray cl0 nm (max-1) i cl pars))
				    

fun stringToNum str = 
	let 
	val cl = List.rev(explode str)
	fun calc []      n = 0
	  | calc (d::ds) n = 
		if (Char.isDigit d) 
		then
			(n*(ord d - ord #"0") + calc ds (n*10))
		else raise Fail "stringToNum: illegal number"
	in		
		calc cl 1
	end
;
fun addConstr vc (PLPCDD.NOINIT (vcs,ty,nml)) = PLPCDD.NOINIT (vc@vcs,ty,nml)
  | addConstr vc (PLPCDD.INIT (vcs,ty,nm,ex)) = PLPCDD.INIT (vc@vcs,ty,nm,ex)
;


fun addLabel lab stmt = case stmt of
	  Send (z,_)		=> Send (z,lab)
	| Rec (z,_)		=> Rec (z,lab)
	| Goto (z,_)		=> Goto (z,lab)
	| Atomic (z,_)		=> Atomic (z,lab)
	| Block (z,_)		=> Block (z,lab)
	| Alt (z,_)		=> Alt (z,lab)
	| Loop (z,_)		=> Loop (z,lab)


(* Line 71, file SLPCParser.sml *)
val yytransl = #[
  257 (* AND *),
  258 (* ARRAYACCESS *),
  259 (* AT *),
  260 (* ATOMIC *),
  261 (* BLOCK_TOK *),
  262 (* BOOL *),
  263 (* CASE *),
  264 (* COLON *),
  265 (* COMA *),
  266 (* CONS *),
  267 (* DEFAULT *),
  268 (* DIV *),
  269 (* DIVIDE *),
  270 (* DO *),
  271 (* ELEM *),
  272 (* ELSE *),
  273 (* EOF *),
  274 (* EQUAL *),
  275 (* EXISTS *),
  276 (* EXIT_TOK *),
  277 (* FI *),
  278 (* FOR *),
  279 (* FORALL *),
  280 (* FUNAPP *),
  281 (* GOTO *),
  282 (* GT *),
  283 (* GTE *),
  284 (* IDENT *),
  285 (* IF *),
  286 (* IMPLIES *),
  287 (* IN *),
  288 (* INSERT *),
  289 (* INT *),
  290 (* INTERSECT *),
  291 (* INV *),
  292 (* INVARIANT *),
  293 (* LACOL *),
  294 (* LHOABRAC *),
  295 (* LIT_EMPTYLIST *),
  296 (* LIT_EMPTYSET *),
  297 (* LIT_FALSE *),
  298 (* LIT_I *),
  299 (* LIT_TRUE *),
  300 (* LLISTBRAC *),
  301 (* LPAR *),
  302 (* LSBRAC *),
  303 (* LSETBRAC *),
  304 (* LT *),
  305 (* LTE *),
  306 (* MAX *),
  307 (* MIN *),
  308 (* MINMIN *),
  309 (* MINUS *),
  310 (* MOD *),
  311 (* NOT *),
  312 (* NTH *),
  313 (* NUM *),
  314 (* OD *),
  315 (* OR *),
  316 (* PLUS *),
  317 (* PLUSPLUS *),
  318 (* POWER *),
  319 (* PRESERVES *),
  320 (* PROVE *),
  321 (* RACOL *),
  322 (* RHOABRAC *),
  323 (* RIGHTARROW *),
  324 (* RLISTBRAC *),
  325 (* RPAR *),
  326 (* RSBRAC *),
  327 (* RSETBRAC *),
  328 (* SEMI *),
  329 (* SET *),
  330 (* SKIP *),
  331 (* STABLE *),
  332 (* STRING *),
  333 (* STRVALUE *),
  334 (* SWITCH *),
  335 (* TIMES *),
  336 (* UNION *),
  337 (* USING *),
  338 (* WHILE *),
    0];

val yylhs = "\255\255\
\\001\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
\\005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
\\005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
\\005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
\\005\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
\\005\000\005\000\005\000\007\000\007\000\006\000\006\000\010\000\
\\010\000\009\000\009\000\008\000\008\000\002\000\003\000\003\000\
\\004\000\004\000\004\000\004\000\004\000\000\000";

val yylen = "\002\000\
\\002\000\001\000\003\000\001\000\001\000\001\000\001\000\001\000\
\\003\000\003\000\003\000\003\000\003\000\002\000\003\000\003\000\
\\003\000\008\000\008\000\003\000\003\000\003\000\003\000\003\000\
\\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\\008\000\003\000\005\000\001\000\003\000\002\000\002\000\001\000\
\\003\000\000\000\001\000\001\000\003\000\002\000\003\000\004\000\
\\003\000\004\000\009\000\001\000\011\000\002\000";

val yydefred = "\000\000\
\\000\000\000\000\000\000\062\000\000\000\000\000\000\000\001\000\
\\054\000\002\000\004\000\005\000\008\000\006\000\007\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\056\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\036\000\000\000\
\\000\000\000\000\000\000\000\000\012\000\000\000\011\000\000\000\
\\042\000\003\000\000\000\000\000\053\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\049\000\000\000\000\000\000\000\000\000\043\000\000\000\000\000\
\\000\000\000\000\000\000\045\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\018\000\019\000\041\000\000\000\000\000\
\\000\000\059\000\000\000\000\000";

val yydgoto = "\002\000\
\\004\000\005\000\006\000\021\000\022\000\030\000\109\000\023\000\
\\024\000\065\000";

val yysindex = "\006\000\
\\236\254\000\000\002\255\000\000\250\254\254\254\149\006\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\149\006\
\\210\009\149\006\149\006\244\254\236\254\026\006\000\000\247\254\
\\003\255\044\255\044\255\044\255\156\005\216\005\006\255\045\255\
\\252\254\000\000\149\006\149\006\149\006\149\006\149\006\149\006\
\\149\006\149\006\149\006\149\006\149\006\149\006\149\006\149\006\
\\149\006\149\006\149\006\149\006\149\006\149\006\149\006\149\006\
\\149\006\149\006\149\006\149\006\149\006\021\255\000\000\069\255\
\\071\255\072\255\074\255\149\006\000\000\081\008\000\000\081\008\
\\000\000\000\000\084\009\000\000\000\000\181\009\181\009\147\009\
\\143\008\000\000\147\009\147\009\143\008\147\009\084\009\050\255\
\\147\009\147\009\160\009\160\009\050\255\181\009\201\255\205\008\
\\050\255\201\255\045\255\051\255\201\255\149\006\219\005\044\255\
\\149\006\149\006\149\006\089\006\014\255\081\008\149\006\149\006\
\\000\000\152\006\215\006\022\007\149\006\000\000\085\007\203\003\
\\149\006\149\006\149\006\000\000\047\255\049\255\148\007\211\007\
\\018\008\044\255\044\255\000\000\000\000\000\000\022\255\026\255\
\\064\255\000\000\149\006\081\008";

val yyrindex = "\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\029\255\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\080\255\242\254\248\254\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\008\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\249\254\
\\000\000\000\000\000\000\000\000\000\000\023\006\000\000\086\006\
\\000\000\000\000\012\004\108\255\000\000\171\002\228\002\060\004\
\\111\009\189\255\108\004\156\004\024\009\204\004\252\004\233\000\
\\044\005\092\005\029\003\086\003\052\001\143\003\202\001\232\008\
\\127\001\021\002\083\000\158\000\096\002\000\000\082\255\000\000\
\\000\000\000\000\000\000\032\255\000\000\245\254\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\042\255";

val yygindex = "\000\000\
\\000\000\000\000\081\000\000\000\239\255\000\000\242\255\030\000\
\\000\000\233\255";

val YYTABLESIZE = 2847;
val yytable = "\029\000\
\\048\000\032\000\052\000\066\000\067\000\058\000\001\000\003\000\
\\060\000\007\000\008\000\070\000\072\000\052\000\009\000\033\000\
\\058\000\075\000\076\000\060\000\078\000\079\000\080\000\081\000\
\\082\000\083\000\084\000\085\000\086\000\087\000\088\000\089\000\
\\090\000\091\000\092\000\093\000\094\000\095\000\096\000\097\000\
\\098\000\099\000\100\000\101\000\103\000\025\000\036\000\031\000\
\\010\000\052\000\108\000\036\000\036\000\052\000\062\000\051\000\
\\052\000\048\000\061\000\011\000\012\000\013\000\014\000\015\000\
\\016\000\017\000\077\000\018\000\042\000\061\000\063\000\064\000\
\\074\000\042\000\042\000\019\000\073\000\104\000\105\000\106\000\
\\113\000\107\000\118\000\130\000\110\000\131\000\137\000\114\000\
\\115\000\116\000\138\000\139\000\050\000\119\000\120\000\102\000\
\\055\000\020\000\057\000\108\000\044\000\034\000\124\000\127\000\
\\128\000\129\000\135\000\136\000\009\000\009\000\009\000\059\000\
\\059\000\000\000\000\000\009\000\009\000\009\000\000\000\009\000\
\\000\000\140\000\009\000\000\000\009\000\009\000\000\000\000\000\
\\060\000\000\000\000\000\009\000\000\000\009\000\009\000\009\000\
\\000\000\009\000\009\000\009\000\000\000\009\000\000\000\000\000\
\\000\000\000\000\009\000\009\000\009\000\009\000\009\000\009\000\
\\009\000\000\000\009\000\009\000\009\000\009\000\009\000\000\000\
\\009\000\009\000\009\000\009\000\000\000\000\000\009\000\009\000\
\\009\000\009\000\009\000\009\000\000\000\000\000\000\000\009\000\
\\009\000\000\000\009\000\000\000\000\000\000\000\000\000\000\000\
\\009\000\000\000\009\000\009\000\009\000\010\000\010\000\010\000\
\\000\000\000\000\000\000\000\000\010\000\010\000\010\000\000\000\
\\010\000\000\000\036\000\010\000\000\000\010\000\010\000\000\000\
\\000\000\000\000\000\000\000\000\010\000\000\000\010\000\010\000\
\\010\000\000\000\010\000\010\000\010\000\000\000\010\000\000\000\
\\042\000\000\000\000\000\010\000\010\000\010\000\010\000\010\000\
\\010\000\010\000\048\000\010\000\010\000\010\000\010\000\010\000\
\\000\000\010\000\010\000\010\000\010\000\000\000\000\000\010\000\
\\010\000\010\000\010\000\010\000\010\000\053\000\000\000\000\000\
\\010\000\010\000\000\000\010\000\057\000\000\000\059\000\000\000\
\\014\000\010\000\014\000\010\000\010\000\010\000\000\000\014\000\
\\014\000\014\000\000\000\014\000\000\000\000\000\014\000\060\000\
\\014\000\014\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\014\000\014\000\014\000\000\000\014\000\014\000\014\000\
\\000\000\014\000\000\000\000\000\000\000\000\000\014\000\014\000\
\\014\000\014\000\014\000\014\000\014\000\000\000\014\000\014\000\
\\014\000\014\000\014\000\000\000\014\000\014\000\014\000\014\000\
\\000\000\000\000\014\000\014\000\014\000\014\000\014\000\014\000\
\\000\000\000\000\000\000\014\000\014\000\000\000\014\000\000\000\
\\000\000\000\000\000\000\029\000\014\000\029\000\014\000\014\000\
\\014\000\000\000\029\000\029\000\029\000\000\000\029\000\000\000\
\\000\000\029\000\000\000\029\000\029\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\029\000\029\000\029\000\000\000\
\\029\000\029\000\029\000\000\000\029\000\000\000\000\000\000\000\
\\000\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
\\000\000\029\000\029\000\029\000\029\000\029\000\000\000\029\000\
\\029\000\029\000\029\000\000\000\000\000\029\000\029\000\029\000\
\\029\000\029\000\029\000\000\000\000\000\000\000\029\000\029\000\
\\000\000\029\000\000\000\000\000\000\000\000\000\027\000\029\000\
\\027\000\029\000\029\000\029\000\000\000\027\000\027\000\027\000\
\\000\000\027\000\000\000\000\000\027\000\000\000\027\000\027\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\027\000\
\\027\000\027\000\000\000\027\000\027\000\027\000\000\000\027\000\
\\000\000\000\000\000\000\000\000\027\000\027\000\027\000\027\000\
\\027\000\027\000\027\000\000\000\027\000\027\000\027\000\027\000\
\\027\000\000\000\027\000\027\000\027\000\027\000\000\000\000\000\
\\027\000\027\000\027\000\000\000\027\000\027\000\000\000\000\000\
\\000\000\027\000\027\000\000\000\027\000\000\000\000\000\000\000\
\\000\000\039\000\027\000\039\000\027\000\027\000\027\000\000\000\
\\039\000\039\000\039\000\000\000\039\000\000\000\000\000\039\000\
\\000\000\039\000\039\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\039\000\039\000\039\000\000\000\039\000\039\000\
\\039\000\000\000\039\000\000\000\000\000\000\000\000\000\039\000\
\\039\000\039\000\039\000\039\000\039\000\039\000\000\000\039\000\
\\039\000\039\000\039\000\039\000\000\000\039\000\039\000\039\000\
\\039\000\000\000\000\000\039\000\039\000\039\000\000\000\039\000\
\\039\000\000\000\000\000\000\000\039\000\039\000\000\000\039\000\
\\000\000\000\000\000\000\000\000\028\000\039\000\028\000\000\000\
\\039\000\039\000\000\000\028\000\028\000\028\000\000\000\028\000\
\\000\000\000\000\028\000\000\000\028\000\028\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\028\000\028\000\028\000\
\\000\000\028\000\028\000\028\000\000\000\028\000\000\000\000\000\
\\000\000\000\000\028\000\028\000\028\000\028\000\028\000\028\000\
\\028\000\000\000\028\000\028\000\028\000\028\000\028\000\000\000\
\\028\000\028\000\028\000\028\000\000\000\000\000\028\000\028\000\
\\028\000\000\000\028\000\028\000\000\000\000\000\000\000\028\000\
\\028\000\000\000\028\000\000\000\000\000\000\000\000\000\026\000\
\\028\000\026\000\000\000\028\000\028\000\000\000\026\000\026\000\
\\026\000\000\000\026\000\000\000\000\000\026\000\000\000\026\000\
\\026\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\026\000\026\000\026\000\000\000\026\000\026\000\026\000\000\000\
\\026\000\000\000\000\000\000\000\000\000\026\000\026\000\026\000\
\\026\000\026\000\026\000\026\000\000\000\026\000\026\000\026\000\
\\026\000\026\000\000\000\026\000\026\000\026\000\026\000\000\000\
\\000\000\026\000\026\000\026\000\000\000\026\000\026\000\000\000\
\\000\000\000\000\026\000\026\000\000\000\026\000\000\000\000\000\
\\000\000\000\000\035\000\026\000\035\000\000\000\026\000\026\000\
\\000\000\035\000\035\000\035\000\000\000\035\000\000\000\000\000\
\\035\000\000\000\035\000\035\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\035\000\035\000\035\000\000\000\035\000\
\\035\000\035\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\035\000\035\000\035\000\035\000\035\000\035\000\035\000\000\000\
\\035\000\035\000\035\000\035\000\035\000\000\000\000\000\035\000\
\\035\000\035\000\000\000\000\000\035\000\000\000\035\000\000\000\
\\035\000\035\000\000\000\000\000\000\000\035\000\035\000\000\000\
\\035\000\000\000\000\000\000\000\000\000\034\000\035\000\034\000\
\\000\000\035\000\035\000\000\000\034\000\034\000\034\000\000\000\
\\034\000\000\000\000\000\034\000\000\000\034\000\034\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\034\000\034\000\
\\034\000\000\000\034\000\034\000\034\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\034\000\034\000\034\000\034\000\034\000\
\\034\000\034\000\000\000\034\000\034\000\034\000\034\000\034\000\
\\000\000\000\000\034\000\034\000\034\000\000\000\000\000\034\000\
\\000\000\034\000\000\000\034\000\034\000\000\000\000\000\000\000\
\\034\000\034\000\000\000\034\000\000\000\000\000\000\000\000\000\
\\038\000\034\000\038\000\000\000\034\000\034\000\000\000\038\000\
\\038\000\038\000\000\000\038\000\000\000\000\000\038\000\000\000\
\\038\000\038\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\038\000\038\000\038\000\000\000\038\000\038\000\038\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\038\000\038\000\
\\038\000\038\000\038\000\038\000\038\000\000\000\038\000\038\000\
\\038\000\038\000\038\000\000\000\000\000\038\000\038\000\038\000\
\\000\000\000\000\038\000\000\000\038\000\000\000\038\000\038\000\
\\000\000\000\000\000\000\038\000\038\000\000\000\038\000\000\000\
\\000\000\000\000\000\000\032\000\038\000\032\000\000\000\038\000\
\\038\000\000\000\032\000\032\000\000\000\000\000\032\000\000\000\
\\000\000\032\000\000\000\032\000\032\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\032\000\032\000\032\000\000\000\
\\032\000\032\000\032\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
\\000\000\032\000\032\000\032\000\032\000\032\000\000\000\000\000\
\\032\000\032\000\000\000\000\000\031\000\032\000\031\000\000\000\
\\000\000\032\000\032\000\031\000\031\000\000\000\032\000\032\000\
\\000\000\032\000\031\000\000\000\031\000\031\000\000\000\032\000\
\\000\000\000\000\000\000\032\000\000\000\031\000\031\000\031\000\
\\000\000\031\000\031\000\031\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\031\000\031\000\031\000\031\000\031\000\031\000\
\\031\000\000\000\031\000\031\000\031\000\031\000\031\000\000\000\
\\000\000\000\000\031\000\000\000\000\000\024\000\031\000\024\000\
\\000\000\000\000\031\000\031\000\024\000\024\000\000\000\031\000\
\\031\000\000\000\031\000\024\000\000\000\024\000\024\000\000\000\
\\031\000\000\000\000\000\000\000\031\000\000\000\024\000\024\000\
\\024\000\000\000\024\000\024\000\024\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\024\000\024\000\024\000\024\000\024\000\
\\024\000\024\000\000\000\024\000\024\000\024\000\024\000\024\000\
\\000\000\000\000\000\000\024\000\000\000\000\000\025\000\024\000\
\\025\000\000\000\000\000\024\000\024\000\025\000\025\000\000\000\
\\024\000\024\000\000\000\024\000\025\000\000\000\025\000\025\000\
\\000\000\024\000\000\000\000\000\000\000\024\000\000\000\025\000\
\\025\000\025\000\000\000\025\000\025\000\025\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\025\000\025\000\025\000\025\000\
\\025\000\025\000\025\000\000\000\025\000\025\000\025\000\025\000\
\\025\000\000\000\000\000\000\000\025\000\000\000\000\000\030\000\
\\025\000\030\000\000\000\000\000\025\000\025\000\030\000\030\000\
\\000\000\025\000\025\000\000\000\025\000\030\000\000\000\030\000\
\\030\000\000\000\025\000\000\000\000\000\000\000\025\000\000\000\
\\030\000\030\000\030\000\000\000\030\000\030\000\030\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\030\000\030\000\030\000\
\\030\000\030\000\030\000\030\000\000\000\030\000\030\000\030\000\
\\030\000\030\000\000\000\000\000\000\000\030\000\000\000\000\000\
\\000\000\030\000\000\000\035\000\036\000\030\000\030\000\000\000\
\\000\000\000\000\030\000\030\000\038\000\030\000\039\000\000\000\
\\000\000\040\000\000\000\030\000\041\000\000\000\000\000\030\000\
\\000\000\000\000\042\000\000\000\043\000\044\000\000\000\000\000\
\\045\000\046\000\047\000\000\000\048\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\049\000\050\000\051\000\052\000\000\000\053\000\
\\054\000\000\000\055\000\000\000\000\000\056\000\057\000\058\000\
\\059\000\000\000\000\000\000\000\015\000\000\000\015\000\000\000\
\\000\000\000\000\000\000\015\000\015\000\000\000\000\000\000\000\
\\000\000\060\000\061\000\126\000\015\000\015\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\015\000\
\\000\000\015\000\000\000\015\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\015\000\015\000\015\000\015\000\015\000\015\000\
\\015\000\000\000\015\000\000\000\033\000\000\000\033\000\000\000\
\\000\000\000\000\015\000\033\000\033\000\000\000\015\000\000\000\
\\000\000\000\000\015\000\015\000\033\000\033\000\000\000\015\000\
\\015\000\000\000\015\000\000\000\000\000\000\000\000\000\033\000\
\\015\000\033\000\000\000\033\000\015\000\000\000\000\000\000\000\
\\000\000\000\000\033\000\033\000\033\000\033\000\033\000\033\000\
\\033\000\000\000\033\000\000\000\022\000\000\000\022\000\000\000\
\\000\000\000\000\033\000\022\000\022\000\000\000\033\000\000\000\
\\000\000\000\000\033\000\033\000\022\000\022\000\000\000\033\000\
\\033\000\000\000\033\000\000\000\000\000\000\000\000\000\022\000\
\\033\000\022\000\000\000\022\000\033\000\000\000\000\000\000\000\
\\000\000\000\000\022\000\022\000\022\000\022\000\022\000\022\000\
\\022\000\000\000\022\000\000\000\023\000\000\000\023\000\000\000\
\\000\000\000\000\022\000\023\000\023\000\000\000\022\000\000\000\
\\000\000\000\000\022\000\022\000\023\000\023\000\000\000\022\000\
\\022\000\000\000\022\000\000\000\000\000\000\000\000\000\023\000\
\\022\000\023\000\000\000\023\000\022\000\000\000\000\000\000\000\
\\000\000\000\000\023\000\023\000\023\000\023\000\023\000\023\000\
\\023\000\000\000\023\000\000\000\037\000\000\000\037\000\000\000\
\\000\000\000\000\023\000\037\000\037\000\000\000\023\000\000\000\
\\000\000\000\000\023\000\023\000\037\000\037\000\000\000\023\000\
\\023\000\000\000\023\000\000\000\000\000\000\000\000\000\037\000\
\\023\000\037\000\000\000\037\000\023\000\000\000\000\000\000\000\
\\000\000\000\000\037\000\037\000\037\000\037\000\037\000\037\000\
\\037\000\000\000\037\000\000\000\040\000\000\000\040\000\000\000\
\\000\000\000\000\037\000\040\000\040\000\000\000\037\000\000\000\
\\000\000\000\000\037\000\037\000\040\000\040\000\000\000\037\000\
\\037\000\000\000\037\000\000\000\000\000\000\000\000\000\040\000\
\\037\000\040\000\000\000\040\000\037\000\000\000\000\000\000\000\
\\000\000\000\000\040\000\040\000\040\000\040\000\040\000\040\000\
\\040\000\000\000\040\000\000\000\020\000\000\000\020\000\000\000\
\\000\000\000\000\040\000\020\000\020\000\000\000\040\000\000\000\
\\000\000\000\000\040\000\040\000\020\000\020\000\000\000\040\000\
\\040\000\000\000\040\000\000\000\000\000\000\000\000\000\020\000\
\\040\000\020\000\000\000\020\000\040\000\000\000\000\000\000\000\
\\000\000\000\000\020\000\020\000\020\000\020\000\020\000\020\000\
\\020\000\000\000\020\000\000\000\021\000\000\000\021\000\000\000\
\\000\000\000\000\020\000\021\000\021\000\000\000\020\000\000\000\
\\000\000\000\000\020\000\020\000\021\000\021\000\000\000\020\000\
\\020\000\000\000\020\000\000\000\000\000\000\000\000\000\021\000\
\\020\000\021\000\000\000\021\000\020\000\000\000\000\000\000\000\
\\000\000\000\000\021\000\021\000\021\000\021\000\021\000\021\000\
\\021\000\000\000\021\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\021\000\000\000\000\000\000\000\021\000\000\000\
\\000\000\000\000\021\000\021\000\035\000\036\000\000\000\021\000\
\\021\000\000\000\021\000\000\000\068\000\038\000\000\000\039\000\
\\021\000\000\000\040\000\000\000\021\000\041\000\000\000\000\000\
\\000\000\000\000\000\000\042\000\000\000\043\000\044\000\010\000\
\\000\000\045\000\046\000\047\000\000\000\048\000\000\000\000\000\
\\000\000\000\000\011\000\012\000\013\000\014\000\015\000\016\000\
\\017\000\000\000\018\000\049\000\050\000\051\000\052\000\000\000\
\\053\000\054\000\019\000\055\000\000\000\000\000\056\000\057\000\
\\058\000\059\000\000\000\035\000\036\000\111\000\000\000\000\000\
\\069\000\000\000\000\000\000\000\038\000\000\000\039\000\000\000\
\\020\000\040\000\060\000\061\000\041\000\000\000\000\000\000\000\
\\000\000\000\000\042\000\010\000\043\000\044\000\112\000\000\000\
\\045\000\046\000\047\000\000\000\048\000\000\000\011\000\012\000\
\\013\000\014\000\015\000\016\000\017\000\000\000\018\000\000\000\
\\000\000\000\000\049\000\050\000\051\000\052\000\019\000\053\000\
\\054\000\000\000\055\000\000\000\000\000\056\000\057\000\058\000\
\\059\000\000\000\035\000\036\000\071\000\000\000\000\000\000\000\
\\000\000\000\000\037\000\038\000\020\000\039\000\000\000\000\000\
\\040\000\060\000\061\000\041\000\000\000\000\000\000\000\000\000\
\\000\000\042\000\046\000\043\000\044\000\000\000\000\000\045\000\
\\046\000\047\000\000\000\048\000\000\000\046\000\046\000\046\000\
\\046\000\046\000\046\000\046\000\000\000\046\000\000\000\000\000\
\\000\000\049\000\050\000\051\000\052\000\046\000\053\000\054\000\
\\000\000\055\000\000\000\000\000\056\000\057\000\058\000\059\000\
\\000\000\035\000\036\000\046\000\000\000\000\000\000\000\000\000\
\\000\000\117\000\038\000\046\000\039\000\000\000\000\000\040\000\
\\060\000\061\000\041\000\000\000\000\000\000\000\000\000\000\000\
\\042\000\047\000\043\000\044\000\000\000\000\000\045\000\046\000\
\\047\000\000\000\048\000\000\000\047\000\047\000\047\000\047\000\
\\047\000\047\000\047\000\000\000\047\000\000\000\000\000\000\000\
\\049\000\050\000\051\000\052\000\047\000\053\000\054\000\000\000\
\\055\000\000\000\000\000\056\000\057\000\058\000\059\000\000\000\
\\035\000\036\000\047\000\000\000\000\000\000\000\000\000\121\000\
\\000\000\038\000\047\000\039\000\000\000\000\000\040\000\060\000\
\\061\000\041\000\000\000\000\000\000\000\000\000\000\000\042\000\
\\010\000\043\000\044\000\000\000\000\000\045\000\046\000\047\000\
\\000\000\048\000\000\000\011\000\012\000\013\000\014\000\015\000\
\\016\000\017\000\000\000\018\000\000\000\000\000\000\000\049\000\
\\050\000\051\000\052\000\019\000\053\000\054\000\000\000\055\000\
\\000\000\000\000\056\000\057\000\058\000\059\000\000\000\035\000\
\\036\000\000\000\000\000\000\000\000\000\000\000\122\000\000\000\
\\038\000\020\000\039\000\000\000\000\000\040\000\060\000\061\000\
\\041\000\000\000\000\000\000\000\000\000\000\000\042\000\000\000\
\\043\000\044\000\000\000\000\000\045\000\046\000\047\000\000\000\
\\048\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\049\000\050\000\
\\051\000\052\000\000\000\053\000\054\000\000\000\055\000\000\000\
\\000\000\056\000\057\000\058\000\059\000\000\000\035\000\036\000\
\\000\000\000\000\000\000\000\000\000\000\123\000\000\000\038\000\
\\000\000\039\000\000\000\000\000\040\000\060\000\061\000\041\000\
\\000\000\000\000\000\000\000\000\000\000\042\000\000\000\043\000\
\\044\000\000\000\000\000\045\000\046\000\047\000\000\000\048\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\049\000\050\000\051\000\
\\052\000\000\000\053\000\054\000\000\000\055\000\000\000\000\000\
\\056\000\057\000\058\000\059\000\000\000\035\000\036\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\038\000\000\000\
\\039\000\000\000\000\000\040\000\060\000\061\000\041\000\000\000\
\\000\000\000\000\000\000\000\000\042\000\000\000\043\000\044\000\
\\000\000\000\000\045\000\046\000\047\000\000\000\048\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\049\000\050\000\051\000\052\000\
\\000\000\053\000\054\000\000\000\055\000\000\000\000\000\056\000\
\\057\000\058\000\059\000\125\000\035\000\036\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\038\000\000\000\039\000\
\\000\000\000\000\040\000\060\000\061\000\041\000\000\000\000\000\
\\000\000\000\000\000\000\042\000\000\000\043\000\044\000\000\000\
\\000\000\045\000\046\000\047\000\000\000\048\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\049\000\050\000\051\000\052\000\000\000\
\\053\000\054\000\000\000\055\000\000\000\000\000\056\000\057\000\
\\058\000\059\000\000\000\035\000\036\000\000\000\000\000\000\000\
\\132\000\000\000\000\000\000\000\038\000\000\000\039\000\000\000\
\\000\000\040\000\060\000\061\000\041\000\000\000\000\000\000\000\
\\000\000\000\000\042\000\000\000\043\000\044\000\000\000\000\000\
\\045\000\046\000\047\000\000\000\048\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\049\000\050\000\051\000\052\000\000\000\053\000\
\\054\000\000\000\055\000\000\000\000\000\056\000\057\000\058\000\
\\059\000\000\000\035\000\036\000\000\000\000\000\000\000\133\000\
\\000\000\000\000\000\000\038\000\000\000\039\000\000\000\000\000\
\\040\000\060\000\061\000\041\000\000\000\000\000\000\000\000\000\
\\000\000\042\000\000\000\043\000\044\000\000\000\000\000\045\000\
\\046\000\047\000\000\000\048\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\049\000\050\000\051\000\052\000\000\000\053\000\054\000\
\\000\000\055\000\000\000\000\000\056\000\057\000\058\000\059\000\
\\000\000\035\000\036\000\000\000\000\000\000\000\134\000\000\000\
\\000\000\000\000\038\000\000\000\039\000\000\000\000\000\040\000\
\\060\000\061\000\041\000\000\000\000\000\000\000\000\000\000\000\
\\042\000\000\000\043\000\044\000\000\000\000\000\045\000\046\000\
\\047\000\000\000\048\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\049\000\050\000\051\000\052\000\000\000\053\000\054\000\000\000\
\\055\000\000\000\000\000\056\000\057\000\058\000\059\000\035\000\
\\036\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\038\000\000\000\039\000\000\000\000\000\040\000\000\000\060\000\
\\061\000\000\000\000\000\000\000\000\000\000\000\042\000\000\000\
\\043\000\044\000\000\000\000\000\045\000\046\000\047\000\000\000\
\\048\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\049\000\050\000\
\\051\000\052\000\000\000\053\000\054\000\000\000\055\000\000\000\
\\000\000\056\000\057\000\058\000\059\000\035\000\036\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\038\000\000\000\
\\039\000\000\000\000\000\040\000\000\000\060\000\061\000\000\000\
\\000\000\000\000\000\000\000\000\042\000\000\000\043\000\044\000\
\\000\000\000\000\016\000\046\000\047\000\000\000\048\000\016\000\
\\016\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\016\000\016\000\000\000\000\000\049\000\050\000\051\000\052\000\
\\000\000\053\000\054\000\016\000\055\000\016\000\000\000\000\000\
\\057\000\058\000\059\000\000\000\000\000\000\000\016\000\016\000\
\\016\000\016\000\016\000\016\000\016\000\000\000\016\000\000\000\
\\000\000\000\000\017\000\060\000\061\000\000\000\016\000\017\000\
\\017\000\000\000\016\000\000\000\000\000\000\000\016\000\016\000\
\\017\000\017\000\000\000\016\000\016\000\000\000\016\000\000\000\
\\000\000\000\000\000\000\017\000\016\000\000\000\000\000\000\000\
\\016\000\000\000\000\000\000\000\000\000\000\000\017\000\017\000\
\\017\000\017\000\017\000\017\000\017\000\000\000\017\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\017\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\036\000\017\000\017\000\
\\000\000\000\000\000\000\017\000\017\000\038\000\017\000\039\000\
\\000\000\000\000\040\000\000\000\017\000\000\000\000\000\000\000\
\\017\000\000\000\000\000\042\000\000\000\043\000\044\000\000\000\
\\000\000\013\000\046\000\000\000\000\000\048\000\013\000\013\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\013\000\
\\000\000\000\000\000\000\049\000\050\000\051\000\052\000\000\000\
\\053\000\054\000\013\000\055\000\000\000\000\000\000\000\057\000\
\\058\000\059\000\000\000\000\000\036\000\013\000\013\000\013\000\
\\013\000\013\000\013\000\013\000\038\000\013\000\039\000\000\000\
\\000\000\036\000\060\000\061\000\000\000\013\000\000\000\000\000\
\\000\000\038\000\042\000\039\000\000\000\013\000\013\000\000\000\
\\000\000\000\000\013\000\013\000\048\000\013\000\036\000\042\000\
\\000\000\000\000\000\000\013\000\000\000\000\000\038\000\013\000\
\\000\000\048\000\000\000\000\000\051\000\052\000\000\000\053\000\
\\054\000\000\000\055\000\000\000\042\000\000\000\057\000\058\000\
\\059\000\000\000\000\000\000\000\053\000\054\000\048\000\055\000\
\\000\000\000\000\000\000\057\000\058\000\059\000\000\000\000\000\
\\000\000\060\000\061\000\000\000\026\000\000\000\000\000\000\000\
\\027\000\053\000\000\000\000\000\055\000\010\000\060\000\061\000\
\\057\000\058\000\059\000\000\000\000\000\000\000\000\000\000\000\
\\011\000\012\000\013\000\014\000\015\000\016\000\017\000\000\000\
\\018\000\000\000\000\000\060\000\061\000\000\000\000\000\000\000\
\\019\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\\000\000\000\000\028\000\000\000\000\000\000\000\020\000";

val yycheck = "\017\000\
\\008\001\019\000\017\001\027\000\028\000\017\001\001\000\028\001\
\\017\001\008\001\017\001\029\000\030\000\028\001\017\001\028\001\
\\028\001\035\000\036\000\028\001\038\000\039\000\040\000\041\000\
\\042\000\043\000\044\000\045\000\046\000\047\000\048\000\049\000\
\\050\000\051\000\052\000\053\000\054\000\055\000\056\000\057\000\
\\058\000\059\000\060\000\061\000\062\000\016\000\002\001\018\000\
\\028\001\064\001\068\000\002\001\002\001\068\001\064\001\064\001\
\\071\001\065\001\017\001\039\001\040\001\041\001\042\001\043\001\
\\044\001\045\001\037\000\047\001\024\001\028\001\068\001\028\001\
\\077\001\024\001\024\001\055\001\071\001\009\001\008\001\008\001\
\\104\000\008\001\069\001\037\001\102\000\037\001\065\001\105\000\
\\106\000\107\000\065\001\028\001\064\001\111\000\112\000\075\001\
\\017\001\077\001\017\001\117\000\069\001\021\000\117\000\121\000\
\\122\000\123\000\130\000\131\000\001\001\002\001\003\001\062\001\
\\062\001\255\255\255\255\008\001\009\001\010\001\255\255\012\001\
\\255\255\139\000\015\001\255\255\017\001\018\001\255\255\255\255\
\\079\001\255\255\255\255\024\001\255\255\026\001\027\001\028\001\
\\255\255\030\001\031\001\032\001\255\255\034\001\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\048\001\049\001\050\001\051\001\255\255\
\\053\001\054\001\055\001\056\001\255\255\255\255\059\001\060\001\
\\061\001\062\001\063\001\064\001\255\255\255\255\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\255\255\
\\077\001\255\255\079\001\080\001\081\001\001\001\002\001\003\001\
\\255\255\255\255\255\255\255\255\008\001\009\001\010\001\255\255\
\\012\001\255\255\002\001\015\001\255\255\017\001\018\001\255\255\
\\255\255\255\255\255\255\255\255\024\001\255\255\026\001\027\001\
\\028\001\255\255\030\001\031\001\032\001\255\255\034\001\255\255\
\\024\001\255\255\255\255\039\001\040\001\041\001\042\001\043\001\
\\044\001\045\001\034\001\047\001\048\001\049\001\050\001\051\001\
\\255\255\053\001\054\001\055\001\056\001\255\255\255\255\059\001\
\\060\001\061\001\062\001\063\001\064\001\053\001\255\255\255\255\
\\068\001\069\001\255\255\071\001\060\001\255\255\062\001\255\255\
\\001\001\077\001\003\001\079\001\080\001\081\001\255\255\008\001\
\\009\001\010\001\255\255\012\001\255\255\255\255\015\001\079\001\
\\017\001\018\001\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\026\001\027\001\028\001\255\255\030\001\031\001\032\001\
\\255\255\034\001\255\255\255\255\255\255\255\255\039\001\040\001\
\\041\001\042\001\043\001\044\001\045\001\255\255\047\001\048\001\
\\049\001\050\001\051\001\255\255\053\001\054\001\055\001\056\001\
\\255\255\255\255\059\001\060\001\061\001\062\001\063\001\064\001\
\\255\255\255\255\255\255\068\001\069\001\255\255\071\001\255\255\
\\255\255\255\255\255\255\001\001\077\001\003\001\079\001\080\001\
\\081\001\255\255\008\001\009\001\010\001\255\255\012\001\255\255\
\\255\255\015\001\255\255\017\001\018\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\026\001\027\001\028\001\255\255\
\\030\001\031\001\032\001\255\255\034\001\255\255\255\255\255\255\
\\255\255\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\\255\255\047\001\048\001\049\001\050\001\051\001\255\255\053\001\
\\054\001\055\001\056\001\255\255\255\255\059\001\060\001\061\001\
\\062\001\063\001\064\001\255\255\255\255\255\255\068\001\069\001\
\\255\255\071\001\255\255\255\255\255\255\255\255\001\001\077\001\
\\003\001\079\001\080\001\081\001\255\255\008\001\009\001\010\001\
\\255\255\012\001\255\255\255\255\015\001\255\255\017\001\018\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\026\001\
\\027\001\028\001\255\255\030\001\031\001\032\001\255\255\034\001\
\\255\255\255\255\255\255\255\255\039\001\040\001\041\001\042\001\
\\043\001\044\001\045\001\255\255\047\001\048\001\049\001\050\001\
\\051\001\255\255\053\001\054\001\055\001\056\001\255\255\255\255\
\\059\001\060\001\061\001\255\255\063\001\064\001\255\255\255\255\
\\255\255\068\001\069\001\255\255\071\001\255\255\255\255\255\255\
\\255\255\001\001\077\001\003\001\079\001\080\001\081\001\255\255\
\\008\001\009\001\010\001\255\255\012\001\255\255\255\255\015\001\
\\255\255\017\001\018\001\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\026\001\027\001\028\001\255\255\030\001\031\001\
\\032\001\255\255\034\001\255\255\255\255\255\255\255\255\039\001\
\\040\001\041\001\042\001\043\001\044\001\045\001\255\255\047\001\
\\048\001\049\001\050\001\051\001\255\255\053\001\054\001\055\001\
\\056\001\255\255\255\255\059\001\060\001\061\001\255\255\063\001\
\\064\001\255\255\255\255\255\255\068\001\069\001\255\255\071\001\
\\255\255\255\255\255\255\255\255\001\001\077\001\003\001\255\255\
\\080\001\081\001\255\255\008\001\009\001\010\001\255\255\012\001\
\\255\255\255\255\015\001\255\255\017\001\018\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\026\001\027\001\028\001\
\\255\255\030\001\031\001\032\001\255\255\034\001\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\048\001\049\001\050\001\051\001\255\255\
\\053\001\054\001\055\001\056\001\255\255\255\255\059\001\060\001\
\\061\001\255\255\063\001\064\001\255\255\255\255\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\001\001\
\\077\001\003\001\255\255\080\001\081\001\255\255\008\001\009\001\
\\010\001\255\255\012\001\255\255\255\255\015\001\255\255\017\001\
\\018\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\026\001\027\001\028\001\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\039\001\040\001\041\001\
\\042\001\043\001\044\001\045\001\255\255\047\001\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\055\001\056\001\255\255\
\\255\255\059\001\060\001\061\001\255\255\063\001\064\001\255\255\
\\255\255\255\255\068\001\069\001\255\255\071\001\255\255\255\255\
\\255\255\255\255\001\001\077\001\003\001\255\255\080\001\081\001\
\\255\255\008\001\009\001\010\001\255\255\012\001\255\255\255\255\
\\015\001\255\255\017\001\018\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\026\001\027\001\028\001\255\255\030\001\
\\031\001\032\001\255\255\255\255\255\255\255\255\255\255\255\255\
\\039\001\040\001\041\001\042\001\043\001\044\001\045\001\255\255\
\\047\001\048\001\049\001\050\001\051\001\255\255\255\255\054\001\
\\055\001\056\001\255\255\255\255\059\001\255\255\061\001\255\255\
\\063\001\064\001\255\255\255\255\255\255\068\001\069\001\255\255\
\\071\001\255\255\255\255\255\255\255\255\001\001\077\001\003\001\
\\255\255\080\001\081\001\255\255\008\001\009\001\010\001\255\255\
\\012\001\255\255\255\255\015\001\255\255\017\001\018\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\026\001\027\001\
\\028\001\255\255\030\001\031\001\032\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\039\001\040\001\041\001\042\001\043\001\
\\044\001\045\001\255\255\047\001\048\001\049\001\050\001\051\001\
\\255\255\255\255\054\001\055\001\056\001\255\255\255\255\059\001\
\\255\255\061\001\255\255\063\001\064\001\255\255\255\255\255\255\
\\068\001\069\001\255\255\071\001\255\255\255\255\255\255\255\255\
\\001\001\077\001\003\001\255\255\080\001\081\001\255\255\008\001\
\\009\001\010\001\255\255\012\001\255\255\255\255\015\001\255\255\
\\017\001\018\001\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\026\001\027\001\028\001\255\255\030\001\031\001\032\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\039\001\040\001\
\\041\001\042\001\043\001\044\001\045\001\255\255\047\001\048\001\
\\049\001\050\001\051\001\255\255\255\255\054\001\055\001\056\001\
\\255\255\255\255\059\001\255\255\061\001\255\255\063\001\064\001\
\\255\255\255\255\255\255\068\001\069\001\255\255\071\001\255\255\
\\255\255\255\255\255\255\001\001\077\001\003\001\255\255\080\001\
\\081\001\255\255\008\001\009\001\255\255\255\255\012\001\255\255\
\\255\255\015\001\255\255\017\001\018\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\026\001\027\001\028\001\255\255\
\\030\001\031\001\032\001\255\255\255\255\255\255\255\255\255\255\
\\255\255\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\\255\255\047\001\048\001\049\001\050\001\051\001\255\255\255\255\
\\054\001\055\001\255\255\255\255\001\001\059\001\003\001\255\255\
\\255\255\063\001\064\001\008\001\009\001\255\255\068\001\069\001\
\\255\255\071\001\015\001\255\255\017\001\018\001\255\255\077\001\
\\255\255\255\255\255\255\081\001\255\255\026\001\027\001\028\001\
\\255\255\030\001\031\001\032\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\048\001\049\001\050\001\051\001\255\255\
\\255\255\255\255\055\001\255\255\255\255\001\001\059\001\003\001\
\\255\255\255\255\063\001\064\001\008\001\009\001\255\255\068\001\
\\069\001\255\255\071\001\015\001\255\255\017\001\018\001\255\255\
\\077\001\255\255\255\255\255\255\081\001\255\255\026\001\027\001\
\\028\001\255\255\030\001\031\001\032\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\039\001\040\001\041\001\042\001\043\001\
\\044\001\045\001\255\255\047\001\048\001\049\001\050\001\051\001\
\\255\255\255\255\255\255\055\001\255\255\255\255\001\001\059\001\
\\003\001\255\255\255\255\063\001\064\001\008\001\009\001\255\255\
\\068\001\069\001\255\255\071\001\015\001\255\255\017\001\018\001\
\\255\255\077\001\255\255\255\255\255\255\081\001\255\255\026\001\
\\027\001\028\001\255\255\030\001\031\001\032\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\039\001\040\001\041\001\042\001\
\\043\001\044\001\045\001\255\255\047\001\048\001\049\001\050\001\
\\051\001\255\255\255\255\255\255\055\001\255\255\255\255\001\001\
\\059\001\003\001\255\255\255\255\063\001\064\001\008\001\009\001\
\\255\255\068\001\069\001\255\255\071\001\015\001\255\255\017\001\
\\018\001\255\255\077\001\255\255\255\255\255\255\081\001\255\255\
\\026\001\027\001\028\001\255\255\030\001\031\001\032\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\039\001\040\001\041\001\
\\042\001\043\001\044\001\045\001\255\255\047\001\048\001\049\001\
\\050\001\051\001\255\255\255\255\255\255\055\001\255\255\255\255\
\\255\255\059\001\255\255\001\001\002\001\063\001\064\001\255\255\
\\255\255\255\255\068\001\069\001\010\001\071\001\012\001\255\255\
\\255\255\015\001\255\255\077\001\018\001\255\255\255\255\081\001\
\\255\255\255\255\024\001\255\255\026\001\027\001\255\255\255\255\
\\030\001\031\001\032\001\255\255\034\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\048\001\049\001\050\001\051\001\255\255\053\001\
\\054\001\255\255\056\001\255\255\255\255\059\001\060\001\061\001\
\\062\001\255\255\255\255\255\255\001\001\255\255\003\001\255\255\
\\255\255\255\255\255\255\008\001\009\001\255\255\255\255\255\255\
\\255\255\079\001\080\001\081\001\017\001\018\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\028\001\
\\255\255\030\001\255\255\032\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\001\001\255\255\003\001\255\255\
\\255\255\255\255\055\001\008\001\009\001\255\255\059\001\255\255\
\\255\255\255\255\063\001\064\001\017\001\018\001\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\028\001\
\\077\001\030\001\255\255\032\001\081\001\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\001\001\255\255\003\001\255\255\
\\255\255\255\255\055\001\008\001\009\001\255\255\059\001\255\255\
\\255\255\255\255\063\001\064\001\017\001\018\001\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\028\001\
\\077\001\030\001\255\255\032\001\081\001\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\001\001\255\255\003\001\255\255\
\\255\255\255\255\055\001\008\001\009\001\255\255\059\001\255\255\
\\255\255\255\255\063\001\064\001\017\001\018\001\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\028\001\
\\077\001\030\001\255\255\032\001\081\001\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\001\001\255\255\003\001\255\255\
\\255\255\255\255\055\001\008\001\009\001\255\255\059\001\255\255\
\\255\255\255\255\063\001\064\001\017\001\018\001\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\028\001\
\\077\001\030\001\255\255\032\001\081\001\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\001\001\255\255\003\001\255\255\
\\255\255\255\255\055\001\008\001\009\001\255\255\059\001\255\255\
\\255\255\255\255\063\001\064\001\017\001\018\001\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\028\001\
\\077\001\030\001\255\255\032\001\081\001\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\001\001\255\255\003\001\255\255\
\\255\255\255\255\055\001\008\001\009\001\255\255\059\001\255\255\
\\255\255\255\255\063\001\064\001\017\001\018\001\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\028\001\
\\077\001\030\001\255\255\032\001\081\001\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\001\001\255\255\003\001\255\255\
\\255\255\255\255\055\001\008\001\009\001\255\255\059\001\255\255\
\\255\255\255\255\063\001\064\001\017\001\018\001\255\255\068\001\
\\069\001\255\255\071\001\255\255\255\255\255\255\255\255\028\001\
\\077\001\030\001\255\255\032\001\081\001\255\255\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\055\001\255\255\255\255\255\255\059\001\255\255\
\\255\255\255\255\063\001\064\001\001\001\002\001\255\255\068\001\
\\069\001\255\255\071\001\255\255\009\001\010\001\255\255\012\001\
\\077\001\255\255\015\001\255\255\081\001\018\001\255\255\255\255\
\\255\255\255\255\255\255\024\001\255\255\026\001\027\001\028\001\
\\255\255\030\001\031\001\032\001\255\255\034\001\255\255\255\255\
\\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\\045\001\255\255\047\001\048\001\049\001\050\001\051\001\255\255\
\\053\001\054\001\055\001\056\001\255\255\255\255\059\001\060\001\
\\061\001\062\001\255\255\001\001\002\001\003\001\255\255\255\255\
\\069\001\255\255\255\255\255\255\010\001\255\255\012\001\255\255\
\\077\001\015\001\079\001\080\001\018\001\255\255\255\255\255\255\
\\255\255\255\255\024\001\028\001\026\001\027\001\028\001\255\255\
\\030\001\031\001\032\001\255\255\034\001\255\255\039\001\040\001\
\\041\001\042\001\043\001\044\001\045\001\255\255\047\001\255\255\
\\255\255\255\255\048\001\049\001\050\001\051\001\055\001\053\001\
\\054\001\255\255\056\001\255\255\255\255\059\001\060\001\061\001\
\\062\001\255\255\001\001\002\001\069\001\255\255\255\255\255\255\
\\255\255\255\255\009\001\010\001\077\001\012\001\255\255\255\255\
\\015\001\079\001\080\001\018\001\255\255\255\255\255\255\255\255\
\\255\255\024\001\028\001\026\001\027\001\255\255\255\255\030\001\
\\031\001\032\001\255\255\034\001\255\255\039\001\040\001\041\001\
\\042\001\043\001\044\001\045\001\255\255\047\001\255\255\255\255\
\\255\255\048\001\049\001\050\001\051\001\055\001\053\001\054\001\
\\255\255\056\001\255\255\255\255\059\001\060\001\061\001\062\001\
\\255\255\001\001\002\001\069\001\255\255\255\255\255\255\255\255\
\\255\255\009\001\010\001\077\001\012\001\255\255\255\255\015\001\
\\079\001\080\001\018\001\255\255\255\255\255\255\255\255\255\255\
\\024\001\028\001\026\001\027\001\255\255\255\255\030\001\031\001\
\\032\001\255\255\034\001\255\255\039\001\040\001\041\001\042\001\
\\043\001\044\001\045\001\255\255\047\001\255\255\255\255\255\255\
\\048\001\049\001\050\001\051\001\055\001\053\001\054\001\255\255\
\\056\001\255\255\255\255\059\001\060\001\061\001\062\001\255\255\
\\001\001\002\001\069\001\255\255\255\255\255\255\255\255\008\001\
\\255\255\010\001\077\001\012\001\255\255\255\255\015\001\079\001\
\\080\001\018\001\255\255\255\255\255\255\255\255\255\255\024\001\
\\028\001\026\001\027\001\255\255\255\255\030\001\031\001\032\001\
\\255\255\034\001\255\255\039\001\040\001\041\001\042\001\043\001\
\\044\001\045\001\255\255\047\001\255\255\255\255\255\255\048\001\
\\049\001\050\001\051\001\055\001\053\001\054\001\255\255\056\001\
\\255\255\255\255\059\001\060\001\061\001\062\001\255\255\001\001\
\\002\001\255\255\255\255\255\255\255\255\255\255\008\001\255\255\
\\010\001\077\001\012\001\255\255\255\255\015\001\079\001\080\001\
\\018\001\255\255\255\255\255\255\255\255\255\255\024\001\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\255\255\059\001\060\001\061\001\062\001\255\255\001\001\002\001\
\\255\255\255\255\255\255\255\255\255\255\008\001\255\255\010\001\
\\255\255\012\001\255\255\255\255\015\001\079\001\080\001\018\001\
\\255\255\255\255\255\255\255\255\255\255\024\001\255\255\026\001\
\\027\001\255\255\255\255\030\001\031\001\032\001\255\255\034\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\048\001\049\001\050\001\
\\051\001\255\255\053\001\054\001\255\255\056\001\255\255\255\255\
\\059\001\060\001\061\001\062\001\255\255\001\001\002\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\010\001\255\255\
\\012\001\255\255\255\255\015\001\079\001\080\001\018\001\255\255\
\\255\255\255\255\255\255\255\255\024\001\255\255\026\001\027\001\
\\255\255\255\255\030\001\031\001\032\001\255\255\034\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\048\001\049\001\050\001\051\001\
\\255\255\053\001\054\001\255\255\056\001\255\255\255\255\059\001\
\\060\001\061\001\062\001\063\001\001\001\002\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\010\001\255\255\012\001\
\\255\255\255\255\015\001\079\001\080\001\018\001\255\255\255\255\
\\255\255\255\255\255\255\024\001\255\255\026\001\027\001\255\255\
\\255\255\030\001\031\001\032\001\255\255\034\001\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\053\001\054\001\255\255\056\001\255\255\255\255\059\001\060\001\
\\061\001\062\001\255\255\001\001\002\001\255\255\255\255\255\255\
\\069\001\255\255\255\255\255\255\010\001\255\255\012\001\255\255\
\\255\255\015\001\079\001\080\001\018\001\255\255\255\255\255\255\
\\255\255\255\255\024\001\255\255\026\001\027\001\255\255\255\255\
\\030\001\031\001\032\001\255\255\034\001\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\048\001\049\001\050\001\051\001\255\255\053\001\
\\054\001\255\255\056\001\255\255\255\255\059\001\060\001\061\001\
\\062\001\255\255\001\001\002\001\255\255\255\255\255\255\069\001\
\\255\255\255\255\255\255\010\001\255\255\012\001\255\255\255\255\
\\015\001\079\001\080\001\018\001\255\255\255\255\255\255\255\255\
\\255\255\024\001\255\255\026\001\027\001\255\255\255\255\030\001\
\\031\001\032\001\255\255\034\001\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\048\001\049\001\050\001\051\001\255\255\053\001\054\001\
\\255\255\056\001\255\255\255\255\059\001\060\001\061\001\062\001\
\\255\255\001\001\002\001\255\255\255\255\255\255\069\001\255\255\
\\255\255\255\255\010\001\255\255\012\001\255\255\255\255\015\001\
\\079\001\080\001\018\001\255\255\255\255\255\255\255\255\255\255\
\\024\001\255\255\026\001\027\001\255\255\255\255\030\001\031\001\
\\032\001\255\255\034\001\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\048\001\049\001\050\001\051\001\255\255\053\001\054\001\255\255\
\\056\001\255\255\255\255\059\001\060\001\061\001\062\001\001\001\
\\002\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\010\001\255\255\012\001\255\255\255\255\015\001\255\255\079\001\
\\080\001\255\255\255\255\255\255\255\255\255\255\024\001\255\255\
\\026\001\027\001\255\255\255\255\030\001\031\001\032\001\255\255\
\\034\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\\050\001\051\001\255\255\053\001\054\001\255\255\056\001\255\255\
\\255\255\059\001\060\001\061\001\062\001\001\001\002\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\010\001\255\255\
\\012\001\255\255\255\255\015\001\255\255\079\001\080\001\255\255\
\\255\255\255\255\255\255\255\255\024\001\255\255\026\001\027\001\
\\255\255\255\255\003\001\031\001\032\001\255\255\034\001\008\001\
\\009\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\017\001\018\001\255\255\255\255\048\001\049\001\050\001\051\001\
\\255\255\053\001\054\001\028\001\056\001\030\001\255\255\255\255\
\\060\001\061\001\062\001\255\255\255\255\255\255\039\001\040\001\
\\041\001\042\001\043\001\044\001\045\001\255\255\047\001\255\255\
\\255\255\255\255\003\001\079\001\080\001\255\255\055\001\008\001\
\\009\001\255\255\059\001\255\255\255\255\255\255\063\001\064\001\
\\017\001\018\001\255\255\068\001\069\001\255\255\071\001\255\255\
\\255\255\255\255\255\255\028\001\077\001\255\255\255\255\255\255\
\\081\001\255\255\255\255\255\255\255\255\255\255\039\001\040\001\
\\041\001\042\001\043\001\044\001\045\001\255\255\047\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\055\001\255\255\
\\255\255\255\255\255\255\255\255\255\255\002\001\063\001\064\001\
\\255\255\255\255\255\255\068\001\069\001\010\001\071\001\012\001\
\\255\255\255\255\015\001\255\255\077\001\255\255\255\255\255\255\
\\081\001\255\255\255\255\024\001\255\255\026\001\027\001\255\255\
\\255\255\003\001\031\001\255\255\255\255\034\001\008\001\009\001\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\017\001\
\\255\255\255\255\255\255\048\001\049\001\050\001\051\001\255\255\
\\053\001\054\001\028\001\056\001\255\255\255\255\255\255\060\001\
\\061\001\062\001\255\255\255\255\002\001\039\001\040\001\041\001\
\\042\001\043\001\044\001\045\001\010\001\047\001\012\001\255\255\
\\255\255\002\001\079\001\080\001\255\255\055\001\255\255\255\255\
\\255\255\010\001\024\001\012\001\255\255\063\001\064\001\255\255\
\\255\255\255\255\068\001\069\001\034\001\071\001\002\001\024\001\
\\255\255\255\255\255\255\077\001\255\255\255\255\010\001\081\001\
\\255\255\034\001\255\255\255\255\050\001\051\001\255\255\053\001\
\\054\001\255\255\056\001\255\255\024\001\255\255\060\001\061\001\
\\062\001\255\255\255\255\255\255\053\001\054\001\034\001\056\001\
\\255\255\255\255\255\255\060\001\061\001\062\001\255\255\255\255\
\\255\255\079\001\080\001\255\255\019\001\255\255\255\255\255\255\
\\023\001\053\001\255\255\255\255\056\001\028\001\079\001\080\001\
\\060\001\061\001\062\001\255\255\255\255\255\255\255\255\255\255\
\\039\001\040\001\041\001\042\001\043\001\044\001\045\001\255\255\
\\047\001\255\255\255\255\079\001\080\001\255\255\255\255\255\255\
\\055\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\\255\255\255\255\073\001\255\255\255\255\255\255\077\001";

val yyact = vector_ 63 (fn () => ((raise Fail "parser") : obj));
(* Rule 1, file SLPCParser.grm, line 199 *)
val _ = update_ yyact 1
(fn () => repr(let
val d__1__ = peekVal 1 : PLPCDD.SpecList
in
( (d__1__) ) end : PLPCDD.SpecList))
;
(* Rule 2, file SLPCParser.grm, line 202 *)
val _ = update_ yyact 2
(fn () => repr(let
val d__1__ = peekVal 0 : string
in
( Ident ((d__1__), type_a) 	) end : ExprDD.Expr))
;
(* Rule 3, file SLPCParser.grm, line 203 *)
val _ = update_ yyact 3
(fn () => repr(let
val d__2__ = peekVal 1 : string
in
( mkConstString (d__2__) 	) end : ExprDD.Expr))
;
(* Rule 4, file SLPCParser.grm, line 204 *)
val _ = update_ yyact 4
(fn () => repr(let
in
( Lit ("-[]-", type_a) 	) end : ExprDD.Expr))
;
(* Rule 5, file SLPCParser.grm, line 205 *)
val _ = update_ yyact 5
(fn () => repr(let
in
( Lit ("-{}-", type_a) 	) end : ExprDD.Expr))
;
(* Rule 6, file SLPCParser.grm, line 206 *)
val _ = update_ yyact 6
(fn () => repr(let
val d__1__ = peekVal 0 : string
in
( Lit ((d__1__), type_int)	) end : ExprDD.Expr))
;
(* Rule 7, file SLPCParser.grm, line 207 *)
val _ = update_ yyact 7
(fn () => repr(let
in
( Lit ("T", type_bool)	) end : ExprDD.Expr))
;
(* Rule 8, file SLPCParser.grm, line 208 *)
val _ = update_ yyact 8
(fn () => repr(let
in
( Lit ("F", type_bool)	) end : ExprDD.Expr))
;
(* Rule 9, file SLPCParser.grm, line 210 *)
val _ = update_ yyact 9
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( ArrayAccess ((d__1__),(d__3__)) ) end : ExprDD.Expr))
;
(* Rule 10, file SLPCParser.grm, line 212 *)
val _ = update_ yyact 10
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( App ((d__1__),(d__3__)) ) end : ExprDD.Expr))
;
(* Rule 11, file SLPCParser.grm, line 213 *)
val _ = update_ yyact 11
(fn () => repr(let
val d__2__ = peekVal 1 : ExprDD.Expr
in
( (d__2__)     		) end : ExprDD.Expr))
;
(* Rule 12, file SLPCParser.grm, line 215 *)
val _ = update_ yyact 12
(fn () => repr(let
val d__2__ = peekVal 1 : ExprDD.Expr
in
( (d__2__) ) end : ExprDD.Expr))
;
(* Rule 13, file SLPCParser.grm, line 217 *)
val _ = update_ yyact 13
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "=" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 14, file SLPCParser.grm, line 219 *)
val _ = update_ yyact 14
(fn () => repr(let
val d__2__ = peekVal 0 : ExprDD.Expr
in
( mkUnary "~" (d__2__) ) end : ExprDD.Expr))
;
(* Rule 15, file SLPCParser.grm, line 220 *)
val _ = update_ yyact 15
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "/\\" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 16, file SLPCParser.grm, line 221 *)
val _ = update_ yyact 16
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "\\/" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 17, file SLPCParser.grm, line 222 *)
val _ = update_ yyact 17
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "==>" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 18, file SLPCParser.grm, line 224 *)
val _ = update_ yyact 18
(fn () => repr(let
val d__3__ = peekVal 5 : (string * TypeDD.Type) list
val d__5__ = peekVal 3 : ExprDD.Expr
val d__7__ = peekVal 1 : ExprDD.Expr
in
( mkQuantor "?" (d__3__) (d__5__) (d__7__) ) end : ExprDD.Expr))
;
(* Rule 19, file SLPCParser.grm, line 226 *)
val _ = update_ yyact 19
(fn () => repr(let
val d__3__ = peekVal 5 : (string * TypeDD.Type) list
val d__5__ = peekVal 3 : ExprDD.Expr
val d__7__ = peekVal 1 : ExprDD.Expr
in
( mkQuantor "!" (d__3__) (d__5__) (d__7__) ) end : ExprDD.Expr))
;
(* Rule 20, file SLPCParser.grm, line 229 *)
val _ = update_ yyact 20
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "<" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 21, file SLPCParser.grm, line 230 *)
val _ = update_ yyact 21
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "<=" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 22, file SLPCParser.grm, line 231 *)
val _ = update_ yyact 22
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary ">" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 23, file SLPCParser.grm, line 232 *)
val _ = update_ yyact 23
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary ">=" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 24, file SLPCParser.grm, line 233 *)
val _ = update_ yyact 24
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "max" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 25, file SLPCParser.grm, line 234 *)
val _ = update_ yyact 25
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "min" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 26, file SLPCParser.grm, line 236 *)
val _ = update_ yyact 26
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "+" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 27, file SLPCParser.grm, line 237 *)
val _ = update_ yyact 27
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "*" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 28, file SLPCParser.grm, line 238 *)
val _ = update_ yyact 28
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "-" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 29, file SLPCParser.grm, line 239 *)
val _ = update_ yyact 29
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "^" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 30, file SLPCParser.grm, line 240 *)
val _ = update_ yyact 30
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "mod" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 31, file SLPCParser.grm, line 241 *)
val _ = update_ yyact 31
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "div" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 32, file SLPCParser.grm, line 243 *)
val _ = update_ yyact 32
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "::" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 33, file SLPCParser.grm, line 244 *)
val _ = update_ yyact 33
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "elem" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 34, file SLPCParser.grm, line 245 *)
val _ = update_ yyact 34
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "++" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 35, file SLPCParser.grm, line 246 *)
val _ = update_ yyact 35
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "!!" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 36, file SLPCParser.grm, line 247 *)
val _ = update_ yyact 36
(fn () => repr(let
val d__2__ = peekVal 1 : ExprDD.Expr list
in
( mkEnum "-[.]-" (d__2__) ) end : ExprDD.Expr))
;
(* Rule 37, file SLPCParser.grm, line 249 *)
val _ = update_ yyact 37
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "IN" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 38, file SLPCParser.grm, line 250 *)
val _ = update_ yyact 38
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "|_|" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 39, file SLPCParser.grm, line 251 *)
val _ = update_ yyact 39
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "|^|" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 40, file SLPCParser.grm, line 252 *)
val _ = update_ yyact 40
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( mkBinary "<+" (d__1__) (d__3__) ) end : ExprDD.Expr))
;
(* Rule 41, file SLPCParser.grm, line 254 *)
val _ = update_ yyact 41
(fn () => repr(let
val d__3__ = peekVal 5 : (string * TypeDD.Type) list
val d__5__ = peekVal 3 : ExprDD.Expr
val d__7__ = peekVal 1 : ExprDD.Expr
in
( mkQuantor "SET" (d__3__) (d__5__) (d__7__) ) end : ExprDD.Expr))
;
(* Rule 42, file SLPCParser.grm, line 255 *)
val _ = update_ yyact 42
(fn () => repr(let
val d__2__ = peekVal 1 : ExprDD.Expr list
in
( mkEnum "-{.}-" (d__2__) ) end : ExprDD.Expr))
;
(* Rule 43, file SLPCParser.grm, line 257 *)
val _ = update_ yyact 43
(fn () => repr(let
val d__2__ = peekVal 3 : ExprDD.Expr
val d__4__ = peekVal 1 : ExprDD.Expr
in
( Tuple ((d__2__),(d__4__))     	) end : ExprDD.Expr))
;
(* Rule 44, file SLPCParser.grm, line 260 *)
val _ = update_ yyact 44
(fn () => repr(let
val d__1__ = peekVal 0 : ExprDD.Expr
in
( (d__1__)                	) end : ExprDD.Expr))
;
(* Rule 45, file SLPCParser.grm, line 262 *)
val _ = update_ yyact 45
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr
in
( Tuple ((d__1__),(d__3__))     	) end : ExprDD.Expr))
;
(* Rule 46, file SLPCParser.grm, line 265 *)
val _ = update_ yyact 46
(fn () => repr(let
val d__1__ = peekVal 1 : ExprDD.Expr
val d__2__ = peekVal 0 : ExprDD.Expr
in
( App ((d__1__),(d__2__)) 	) end : ExprDD.Expr))
;
(* Rule 47, file SLPCParser.grm, line 266 *)
val _ = update_ yyact 47
(fn () => repr(let
val d__1__ = peekVal 1 : ExprDD.Expr
val d__2__ = peekVal 0 : ExprDD.Expr
in
( App ((d__1__),(d__2__)) 	) end : ExprDD.Expr))
;
(* Rule 48, file SLPCParser.grm, line 269 *)
val _ = update_ yyact 48
(fn () => repr(let
val d__1__ = peekVal 0 : string
in
( [((d__1__), type_a)] ) end : (string * TypeDD.Type) list))
;
(* Rule 49, file SLPCParser.grm, line 270 *)
val _ = update_ yyact 49
(fn () => repr(let
val d__1__ = peekVal 2 : string
val d__3__ = peekVal 0 : (string * TypeDD.Type) list
in
( ((d__1__), type_a) :: (d__3__) ) end : (string * TypeDD.Type) list))
;
(* Rule 50, file SLPCParser.grm, line 274 *)
val _ = update_ yyact 50
(fn () => repr(let
in
( []	   ) end : ExprDD.Expr list))
;
(* Rule 51, file SLPCParser.grm, line 275 *)
val _ = update_ yyact 51
(fn () => repr(let
val d__1__ = peekVal 0 : ExprDD.Expr list
in
( (d__1__)	   ) end : ExprDD.Expr list))
;
(* Rule 52, file SLPCParser.grm, line 278 *)
val _ = update_ yyact 52
(fn () => repr(let
val d__1__ = peekVal 0 : ExprDD.Expr
in
( [(d__1__)]	   ) end : ExprDD.Expr list))
;
(* Rule 53, file SLPCParser.grm, line 279 *)
val _ = update_ yyact 53
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr
val d__3__ = peekVal 0 : ExprDD.Expr list
in
( (d__1__) :: (d__3__) ) end : ExprDD.Expr list))
;
(* Rule 54, file SLPCParser.grm, line 283 *)
val _ = update_ yyact 54
(fn () => repr(let
val d__1__ = peekVal 1 : PLPCDD.SpecList
in
( (d__1__) 	   ) end : PLPCDD.SpecList))
;
(* Rule 55, file SLPCParser.grm, line 286 *)
val _ = update_ yyact 55
(fn () => repr(let
val d__1__ = peekVal 2 : string
val d__3__ = peekVal 0 : PLPCDD.ProcSpec
in
([((d__1__),(d__3__))]) end : PLPCDD.SpecList))
;
(* Rule 56, file SLPCParser.grm, line 293 *)
val _ = update_ yyact 56
(fn () => repr(let
val d__1__ = peekVal 3 : string
val d__3__ = peekVal 1 : PLPCDD.ProcSpec
val d__4__ = peekVal 0 : PLPCDD.SpecList
in
(((d__1__),(d__3__))::(d__4__)) end : PLPCDD.SpecList))
;
(* Rule 57, file SLPCParser.grm, line 297 *)
val _ = update_ yyact 57
(fn () => repr(let
val d__1__ = peekVal 2 : ExprDD.Expr list
val d__3__ = peekVal 0 : ExprDD.Expr
in
(PLPCDD.VALID((d__1__),(d__3__))) end : PLPCDD.ProcSpec))
;
(* Rule 58, file SLPCParser.grm, line 298 *)
val _ = update_ yyact 58
(fn () => repr(let
val d__1__ = peekVal 3 : ExprDD.Expr list
val d__4__ = peekVal 0 : ExprDD.Expr
in
(PLPCDD.STABLE((d__1__),(d__4__))) end : PLPCDD.ProcSpec))
;
(* Rule 59, file SLPCParser.grm, line 300 *)
val _ = update_ yyact 59
(fn () => repr(let
val d__1__ = peekVal 8 : ExprDD.Expr list
val d__3__ = peekVal 6 : ExprDD.Expr
val d__4__ = peekVal 5 : string
val d__5__ = peekVal 4 : ExprDD.Expr
val d__8__ = peekVal 1 : (string * TypeDD.Type) list
in
(PLPCDD.UNITYREL((d__1__),((d__4__),type_a),(d__3__),(d__5__),(d__8__))) end : PLPCDD.ProcSpec))
;
(* Rule 60, file SLPCParser.grm, line 301 *)
val _ = update_ yyact 60
(fn () => repr(let
val d__1__ = peekVal 0 : ExprDD.Expr list
in
(PLPCDD.DNF (d__1__)) end : PLPCDD.ProcSpec))
;
(* Rule 61, file SLPCParser.grm, line 304 *)
val _ = update_ yyact 61
(fn () => repr(let
val d__1__ = peekVal 10 : ExprDD.Expr list
val d__3__ = peekVal 8 : ExprDD.Expr
val d__5__ = peekVal 6 : ExprDD.Expr
val d__8__ = peekVal 3 : (string * TypeDD.Type) list
val d__10__ = peekVal 1 : string
val d__11__ = peekVal 0 : ExprDD.Expr
in
(PLPCDD.PRESERVES ((d__1__),(d__3__),(d__5__),(d__8__),(d__11__))) end : PLPCDD.ProcSpec))
;
(* Entry START *)
val _ = update_ yyact 62 (fn () => raise yyexit (peekVal 0));
val yytables : parseTables =
  ( yyact,
    yytransl,
    yylhs,
    yylen,
    yydefred,
    yydgoto,
    yysindex,
    yyrindex,
    yygindex,
    YYTABLESIZE,
    yytable,
    yycheck );
fun START lexer lexbuf = yyparse yytables 1 lexer lexbuf;
