structure TypeHol  = struct


(* ============================================================
(*DOC

<MODULE> TypeHol

<AUTHOR> underdarkPrime & ade
<ADDRESS> underdarkPrime@yahoo.com & ade@cs.uu.nl

<DATE> 9 August 2001

<DESC>Provide transformation from Type structure (TypeDD.Expr)
into Hol Type. 

DOC*)
============================================================ *)

local

open HolKernel Parse Psyntax;



open TypeDD  

in

(* ============================================================
(*DOC

<ITEM>TypeInHol
<TYPE>TypeInHol : TypeDD.Type -> hol_type
<CALL>TypeInHol type

<DESC>Transform type into Hol Type.

DOC*)
============================================================ *)

fun typeInHol ty = (case ty of
    TyVar  a       => if (String.isPrefix "dt" a) 
		       then mk_type (a,[])
		       else mk_vartype ("'"^a)
	
  | TyCons ("array",[t]) => mk_type ("fun", [mk_type ("int",[]), typeInHol t])
  | TyCons (nm,tl) => mk_type(nm,map typeInHol tl)
  )
   handle _ => raise Fail 
  	("TypeHol.typeInHol: Invalid Hol type " )

(* ============================================================
(*DOC

<ITEM>TypeFromHol
<TYPE>TypeFromHol : hol_type -> TypeDD.Type
<CALL>TypeFromHol hol_type

<DESC>Transform type into Hol Type.
At this moment no automatic generator of Hol datatype yet.


DOC*)
============================================================ *)

fun typeFromHol ty = 
    if (is_vartype ty) 
    then 
          let val str  = explode (dest_vartype ty)
              val str' = if (List.length str>1) then (List.tl str) else str
          in TyVar (implode str') end
    else 
          let val (tyn,tyl) = dest_type ty
          in TyCons (tyn,List.map typeFromHol tyl) end

fun plainType (TyCons ("fun",[TyCons("fun",[TyVar "var",TyVar "val"]),ty])) 
                = plainType ty
  | plainType (TyCons ("fun",tyl))                             
                = TyCons ("fun",List.map plainType tyl) 
  | plainType (TyCons (nm,tyl)) 
                = TyCons (nm,List.map plainType tyl)                         
  | plainType ty = ty

val typeFromHolSem = plainType o typeFromHol



end

end
