local open Obj Lexing in


 open Lexing TypeParser;

 exception LexicalError of string * int * int (* (message, loc1, loc2) *)

 fun lexerError lexbuf s = 
     raise LexicalError (s, getLexemeStart lexbuf, getLexemeEnd lexbuf);

 val commentStart = ref 0;  (* Start of outermost comment being scanned *)
 
 fun commentNotClosed lexbuf =
     raise LexicalError ("Comment not terminated", 
                         !commentStart, getLexemeEnd lexbuf);
     
 val commentDepth = ref 0;  (* Current comment nesting *)

 (* Scan keywords as identifiers and use this function to distinguish them. *)
 (* If the set of keywords is large, use an auxiliary hashtable.            *)

 fun keyword s =
     case s of
         "int"		=> INT
       | "bool"		=> BOOL
       | "string"       => STRING 
       | _              => TYVAR s;

 
fun action_16 lexbuf = (
 lexerError lexbuf "Illegal symbol in input" )
and action_15 lexbuf = (
 EOF )
and action_14 lexbuf = (
 ARRAYACCESS )
and action_13 lexbuf = (
 RACOL )
and action_12 lexbuf = (
 LACOL )
and action_11 lexbuf = (
 RSBRAC )
and action_10 lexbuf = (
 LSBRAC )
and action_9 lexbuf = (
 RPAR )
and action_8 lexbuf = (
 LPAR )
and action_7 lexbuf = (
 ARROW )
and action_6 lexbuf = (
 commentStart := getLexemeStart lexbuf;
                          commentDepth := 1; 
                          SkipComment lexbuf; Token lexbuf )
and action_5 lexbuf = (
 keyword (getLexeme lexbuf) )
and action_4 lexbuf = (
 Token lexbuf )
and action_3 lexbuf = (
 SkipComment lexbuf )
and action_2 lexbuf = (
 commentNotClosed lexbuf )
and action_1 lexbuf = (
 commentDepth := !commentDepth + 1; 
                          SkipComment lexbuf )
and action_0 lexbuf = (
 commentDepth := !commentDepth - 1;  
                          if !commentDepth = 0 then ()
                          else SkipComment lexbuf 
                        )
and state_0 lexbuf = (
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"*" => state_21 lexbuf
 |  #"(" => state_20 lexbuf
 |  #"\^Z" => action_2 lexbuf
 |  #"\^@" => action_2 lexbuf
 |  _ => action_3 lexbuf
 end)
and state_1 lexbuf = (
 let val currChar = getNextChar lexbuf in
 if currChar >= #"A" andalso currChar <= #"Z" then  state_9 lexbuf
 else if currChar >= #"a" andalso currChar <= #"z" then  state_9 lexbuf
 else case currChar of
    #"\n" => action_4 lexbuf
 |  #"\t" => action_4 lexbuf
 |  #"\r" => action_4 lexbuf
 |  #" " => action_4 lexbuf
 |  #"}" => action_13 lexbuf
 |  #"{" => action_12 lexbuf
 |  #"]" => action_11 lexbuf
 |  #"[" => action_10 lexbuf
 |  #"-" => state_8 lexbuf
 |  #")" => action_9 lexbuf
 |  #"(" => state_6 lexbuf
 |  #"#" => action_14 lexbuf
 |  #"\^@" => action_15 lexbuf
 |  _ => action_16 lexbuf
 end)
and state_6 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_8);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"*" => action_6 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_8 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_16);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #">" => action_7 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_9 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_5);
 let val currChar = getNextChar lexbuf in
 if currChar >= #"0" andalso currChar <= #"9" then  state_14 lexbuf
 else if currChar >= #"A" andalso currChar <= #"Z" then  state_14 lexbuf
 else if currChar >= #"a" andalso currChar <= #"z" then  state_14 lexbuf
 else backtrack lexbuf
 end)
and state_14 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_5);
 let val currChar = getNextChar lexbuf in
 if currChar >= #"0" andalso currChar <= #"9" then  state_14 lexbuf
 else if currChar >= #"A" andalso currChar <= #"Z" then  state_14 lexbuf
 else if currChar >= #"a" andalso currChar <= #"z" then  state_14 lexbuf
 else backtrack lexbuf
 end)
and state_20 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_3);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #"*" => action_1 lexbuf
 |  _ => backtrack lexbuf
 end)
and state_21 lexbuf = (
 setLexLastPos lexbuf (getLexCurrPos lexbuf);
 setLexLastAction lexbuf (magic action_3);
 let val currChar = getNextChar lexbuf in
 case currChar of
    #")" => action_0 lexbuf
 |  _ => backtrack lexbuf
 end)
and Token lexbuf =
  (setLexLastAction lexbuf (magic dummyAction);
   setLexStartPos lexbuf (getLexCurrPos lexbuf);
   state_1 lexbuf)

and SkipComment lexbuf =
  (setLexLastAction lexbuf (magic dummyAction);
   setLexStartPos lexbuf (getLexCurrPos lexbuf);
   state_0 lexbuf)

(* The following checks type consistency of actions *)
val _ = fn _ => [action_16, action_15, action_14, action_13, action_12, action_11, action_10, action_9, action_8, action_7, action_6, action_5, action_4];
val _ = fn _ => [action_3, action_2, action_1, action_0];

end
