structure exConst = struct

local 

open HolKernel boolSyntax listSyntax Psyntax TypeDD MoreList ;

open String intLib;

fun get_plusBaseType (TyCons ("fun", [_,TyCons (a ,[])])) = a

in

exception ContextFail of string;


fun i x n = List.nth (x,n);

(* get the in side type, for example : 
   [a] => a *)
fun inType tl ind = (hd o snd o dest_type o type_of) (i tl ind);

fun tyi    tl ind = type_of (i tl ind);

fun genType [] tyr     = tyr
  | genType (x::xs) tyr = mk_type("fun",[type_of x,genType xs tyr]);

fun Term_ tyr nm xl = 
		list_mk_comb(mk_const(nm,genType xl tyr),xl)
	
fun TermS x = Parse.Term[(QUOTE x)];


val notes = Term_ ;

val DEFAULT = "default";
val ty_bool = mk_type("bool",[]);
val ty_int = mk_type("int",[]);

(* providing the context with all external constants used in PL0 *)

val context
	=
	[ ("=",		"a->a->bool",		"infix",  
	   [("default" , "intLib" , fn (x) => mk_eq(i x 0, i x 1),"")
	   ]),

	  (* (0) boolean functions			  	*)

	  ("/\\",	"bool->bool->bool",	"infix",  
	   [("default" , "bool Lib" , fn (x) => mk_conj(i x 0, i x 1),"")
	   ]),
	  ("\\/",	"bool->bool->bool",	"infix",  
	   [("default" , "bool Lib" , fn (x) => mk_disj(i x 0, i x 1),"")
	   ]),
	  ("~",		"bool->bool",		"prefix", 
	   [("default" , "bool Lib" , fn (x) => mk_neg (i x 0),"")
	   ]),
	  ("==>",	"bool->bool->bool",	"infixr", 
	   [("default" , "bool Lib" , fn (x) => mk_imp(i x 0, i x 1),"")
	   ]),
	  ("?",		"bool->bool",		"quantor",
	   []),	    
	  ("!",		"bool->bool",		"quantor",
	   []),
	    

	  (* (1) relational operators				*)

	  (">",		"a->a->bool",		"nofix",  
	   [("default" , "intLib" , fn (x) => mk_great(i x 0, i x 1),"")
	   ]),
	  (">=",	"a->a->bool",		"nofix",  
	   [("default" , "intLib" , fn (x) => mk_geq(i x 0, i x 1),"")
	   ]),
	  ("<",		"a->a->bool",		"nofix",  
	   [("default" , "intLib" , fn (x) => mk_less(i x 0, i x 1),"")
	   ]),
	  ("<=",	"a->a->bool",		"nofix",  
	   [("default" , "intLib" , fn (x) => mk_leq(i x 0, i x 1),"")
	   ]),

	  ("max",	"a->a->a",		"infix",  
	   []),
	  ("min",	"a->a->a",		"infix",  
	   []),
	    

	  (* (2) numeric functions				*)
	   
	  ("+",		"a->a->a",		"infix",  
	   [("int->int->int" , "intLib" , fn (x) => mk_plus(i x 0, i x 1),""),
            ("num->num->num" , "numLib" , fn (x) => mk_comb(mk_comb(TermS "+",i x 0), i x 1),""),
	    ("default"       , "intLib" , fn (x) => mk_plus(i x 0, i x 1),"")                
	   ]),
	  ("-",		"a->a->a",		"infix",  
	   [("default" , "intLib" , fn (x) => mk_minus(i x 0, i x 1),"")
	   ]),
	  ("*",		"a->a->a",		"infix",  
	   [("default" , "intLib" , fn (x) => mk_mult(i x 0, i x 1),"")
	   ]),
	    
	  ("/",		"a->a->a",		"infix",  
	   []),
	    
	  ("^",		"a->int->a",		"infix", 
	   []),	    

	  ("mod",	"int->int->int",	"nofix",  
	   []),	    

	  ("div",	"int->int->int",	"nofix",  
	   [("default" , "intLib" , fn (x) => mk_divides(i x 0, i x 1),"")
	   ]),	    

	  (* (3) list functions					*)
	
	  ("hd",	"[a]->a",		"prefix", 
	   [("default" , "listLib(HD)" , fn (x) => Term_ (inType x 0) "HD" x,"")
	   ]),	    
	  ("tl",	"[a]->[a]",		"prefix",
	   [("default" , "listLib(TL)" , fn (x) => Term_ (tyi x 0) "TL" x,"")
	   ]),	    
 	  ("::",	"a->[a]->[a]",		"infixr", 
	   [("default" , "listLib(CONS)",fn (x) => Term_ (tyi x 1) "CONS" x,"")
	   ]),	    
	  ("#",	"[a]->int->a",		"infix",  
	   [("default" , "listLib(EL)" , fn (x) => Term_ (inType x 0) "EL" x,"")
	   ]),	    
	  ("++",	"[a]->[a]->[a]",	"infix",  
	   [("default" , "listLib(APPEND)",fn (x) => Term_ (tyi x 0) "APPEND" x,"")
	   ]),	        
	  ("elem",	"a->[a]->bool",		"nofix",  
	   [("default" , "listLib(MEM)", fn (x) => Term_ ty_bool "MEM" x,"")
	   ]),	    
          ("map",	"(a->b)->[a]->[b]",	"prefix", 
	   [("default" , "listLib(MAP)", fn (x) => Term_ ty_bool "MAP" x,"")  
	   ]),	    
	  ("filter",	"(a->bool)->[a]->[a]",	"prefix", 
	   [("default" , "listLib(FILTER)",fn (x) => Term_ (tyi x 1) "FILTER" x,"")
	   ]),	    
	  ("concat",    "[[a]]->[a]",		"prefix", 
	   [("default" , "listLib(FLAT)", fn (x) => Term_ (inType x 0) "FLAT" x,"")
	   ]),	    
	  ("length",   	"[a]->int",		"prefix", 
	   [("default" , "listLib(LENGTH)", fn (x) => Term_ ty_int "LENGTH" x,"")
	   ]),	    
	  ("-[]-",	"[a]",			"lit",    
	   [("default" , "listLib(NIL)" , fn (x) => TermS "NIL","")
	   ]),	    

	  ("-[.]-",	"a->[a]",		"enum",   
	   [("default" , "listLib" , fn (x) => mk_list (x,tyi x 0),"")
	   ]),	    

          (* (3b) list function extra *) 

	  ("maximum",   "[a]->a",		"prefix", 
	   []),	    
	  ("sum",   	"[a]->a",		"prefix", 
	   []),	    

	  (* (4) set functions					*)

	  ("IN",	"a->{a}->bool",		"nofix",  
	   [("default" , "setLib(IN))",fn (x) => mk_comb(mk_comb(TermS "IN",i x 0), i x 1),"")
	   ]),	    
	  ("-{}-",	"{a}",			"lit",    
	   []),
	  ("-{.}-",	"a->[a]",		"enum",   
	   []),
	  ("<+",	"{a}->a->{a}",		"prefix",   (* insert operator *)
	   []),
	  ("SET",	"a->{a}",		"quantor",
	   []),

	  (* (4b) set functions	extra				*)

	  ("INV",	"{a}->{a}",		"prefix",
	   []),
 	  ("|_|",	"{a}->{a}->{a}",	"prefix",
	   []),
	  ("|^|",	"{a}->{a}->{a}",	"prefix",
	   []),
	  ("count",	"{a}->int",		"prefix", 
	   []),
	  ("MAX",	"{a}->a",		"prefix",
	   []),
	  ("MIN",	"{a}->a",		"prefix",
	   []),
	  ("SUM",	"{a}->a",		"prefix", 
	   [])
 	]


fun isExists x 
	=
	let
	fun p (y,_,_,_) = (x=y)
	in List.exists p context
	end

fun getType cs x
	=
	let
	fun p (y,_,_,_) = x=y
	in
	case List.find p cs of
		  NONE			=> TyVar "a"
		| SOME (_,t,_,_)	=> TypePara.parseInLine t
	end


fun getEnumBrackets enr
	=
	let
	val enr'  = explode enr
	val (l,r) = split (fn c=> c <> #".") enr'
	in
	(implode l, implode (tl r))
	end
	
(* added 20 August , needed by ExprHol.sml *)

fun constType x = getType context x;

val quanConst 
   = 
   (*   idName      , function *) 			       
   [(  "!"     , fn (x,y,z)=> list_mk_forall(x,mk_imp (y,z))),
    (  "?"      , fn (x,y,z)=> list_mk_exists(x,mk_conj(y,z)))
   ]
(* obsolute nov 5th 2001 
val enumConst
   =
   (*   idName      , function *) 			       
   [(  "-[.]-"       , fn (x,y)=> mk_list(x,y)     ),
    (  "-{.}-"        , fn (x,y)=> mk_list(x,y)      )
   ]
*)

fun funQuan id _ = (snd (Option.valOf (List.find (fn (x,_)=> x=id) quanConst))
                  handle _ => raise ContextFail 
                  ("exConst.funQuan:  Quantor "^id^" is not defined in exConst.sml"))

	(* obsolute nov 5th 2001  
fun funEnum id _ = (snd (Option.valOf (List.find (fn (x,_)=> x=id) enumConst))
                  handle _ => raise ContextFail 
                  ("exConst.funEnum:  Enum "^id^" is not defined in exConst.sml"))
*)

(* get the infix information of the binary operator *) 

fun checkConst v = 
	let
	fun p (y,_,_,_) = v=y
	in
	case List.find p context of
		  NONE			=> v
		| SOME (_,_,"infix",_)	=> "$"^v
                | SOME (_,_,_,_)        => v
	end
end

(* get the unary and binary operator *)
fun st (x,_,_,_) = x
fun nd (_,x,_,_) = x
fun rd (_,_,x,_) = x
fun th (_,_,_,x) = x

fun myprint_term x = (print "\n"; Parse.print_term x)

val printTermList  = List.map myprint_term ; 

fun funHol opName ty xl = 
	if (List.null xl) 
		   then raise ContextFail 
		        ("ExConst: No transformation function for "^opName^" !")
		   else
	case (List.find (fn (x,y,z,_)=> ((TypePara.parseInLine x)=ty orelse x=DEFAULT))  xl)
	 of 
	   NONE   => raise ContextFail 
	              ("(exConst.funHol: No matching type for "
		       ^opName^":"^(TypeLib.toString ty)^" !")
	 | SOME r => let val func = rd r 
	                 val mesg = nd r
	            in 
	               (fn (inl)=>(func inl
			           handle (ContextFail ms) => (printTermList inl;
			                       raise ContextFail 
                                             (ms^"exConst: Please consult " ^mesg^ 
					      " library (possible mismatch argument)."))

			           handle _ => (printTermList inl;
			                       raise ContextFail 
                                             ("exConst: Please consult " ^mesg^ 
					      " library (possible mismatch argument)."))))
		    end
	     ;


fun funOp id ty = 
	(case (List.find (fn (x,_,_,_)=> x=id) context) of
	      NONE => raise ContextFail 
                  ("exConst.funOp:  operator "^id^" is not defined in exConst.sml")
	    | SOME xl => funHol id ty (th xl) 
	)       

end
