structure semConst = struct

local 

open HolKernel  Psyntax TypeDD MoreList ;

open String intLib;


fun get_plusBaseType (TyCons ("fun", [_,TyCons (a ,[])])) = a

in

exception ConstantFail of string;
exception ContextFail of string;

(* constant variable *)

val DEFAULT = "default";
val CASTOPERATOR = "CASTOPERATOR";
val STATEVAR = "STATEVAR";


(* type abbreviation *)

val boolTy      = mk_type ("bool",[]);
val varTy	= mk_vartype "'var";	
val valTy	= mk_vartype "'val";	
val stateTy     = mk_type ("fun",[varTy,valTy]);
val predTy      = mk_type ("fun",[stateTy,boolTy]);

val actionTy    = mk_type ("fun",[stateTy,mk_type("fun",[stateTy,boolTy])]);
val prgTy       = mk_type ("fun",[actionTy,boolTy]);

val prgBinTy    = mk_type ("fun",[prgTy,mk_type("fun",[prgTy,prgTy])]);



fun i x n = List.nth (x,n);
fun Term_ x = Parse.Term[(QUOTE x)];
val notes = Term_ ;

(* providing the context with all external constants used in PL0 *)

val mk_unaOp                 = mk_comb
fun mk_binOp (ope,arg1,arg2) = mk_comb(mk_comb(ope,arg1),arg2)

fun TermB_ ope = mk_const(ope,mk_type ("fun",[predTy,mk_type("fun",[predTy,predTy])]));
fun TermU_ ope = mk_const(ope,mk_type ("fun",[predTy,predTy]));


(* construct UNITY relation constant with correct typing *)
fun unityTerm nmStr =
    let
       val prTy    = mk_type("fun",[mk_type("fun",[stateTy,predTy]),boolTy])
       val useTy   = mk_type("fun",[varTy,boolTy])
       val arg0    = mk_type("fun",[predTy,boolTy])
       val arg1    = mk_type("fun",[predTy,mk_type("fun",[predTy,arg0])])

       val unityTy = mk_type("fun",[prTy,mk_type("fun",[useTy,arg1])])
    in
       mk_const (nmStr, unityTy) 
    end



(* List of context *) 

val context
	=
	[ ("=",		"a->a->bool",		"infix",  
	   [("default" , "statePredicate" , 
	    fn (x) => mk_binOp(TermB_ "EQ",i x 0, i x 1),"")
	   ]),
	  (* (0) boolean functions			  	*)
	  ("/\\",	"bool->bool->bool",	"infix",  
	   [("default" , "statePredicate" , 
	    fn (x) => mk_binOp(TermB_ "AND",i x 0, i x 1),"")
	   ]),
	  ("\\/",	"bool->bool->bool",	"infix",  
	   [("default" , "statePredicate" , 
	    fn (x) => mk_binOp(TermB_ "OR",i x 0, i x 1),"")
	   ]),

	  ("~",		"bool->bool",		"prefix", 
	   [("default" , "statePredicate" , 
	    fn (x) => mk_unaOp (TermU_ "NOT",i x 0),"")
	   ]),

	  ("==>",	"bool->bool->bool",	"infixr", 
	   [("default" , "statePredicate" , 
	    fn (x) => mk_binOp(TermB_ "IMP",i x 0, i x 1),"")
	   ])
(*	    ,
	  ("?",		"bool->bool",		"quantor",
	   [("default" , "statePredicate" , 
	    fn (x) => mk_quan(i x 0, i x 1),"")
	   ]),	    
	  ("!",		"bool->bool",		"quantor",
	   [("default" , "statePredicate" , 
	    fn (x) => mk_quan(Term_ "IMP",i x 0, i x 1),"")
	   ])	
 *)	]



fun getType cs x
	=
	let
	fun p (y,_,_,_) = x=y
	in
	case List.find p cs of
		  NONE			=> TyVar "a"
		| SOME (_,t,_,_)	=> TypePara.parseInLine t
	end


fun getEnumBrackets enr
	=
	let
	val enr'  = explode enr
	val (l,r) = split (fn c=> c <> #".") enr'
	in
	(implode l, implode (tl r))
	end
	
(* added 20 August , needed by ExprHol.sml *)

fun constType x = getType context x;

fun mk_state nmTerm (x,y,z) = let val r   = mk_abs(x,y)
                                 val p   = mk_abs(x,z)
                                 val rty = type_of r
                                 val pty = type_of p
                                 val exT = mk_const (nmTerm,
	                                             mk_type ("fun",[rty,
	                                                       mk_type("fun",[pty,predTy])]));  
                             in
                             mk_comb(mk_comb(exT,r),p)
                             end
       
val quanConst 
   = 
   (*   idName      , function *) 			       
   [(  "!"     , fn (x)=> mk_state "RES_qAND" (i x 0, i x 1, i x 2)),
    (  "?"     , fn (x)=> mk_state "RES_qOR"  (i x 0, i x 1, i x 2))
   ]


fun funQuan id _ = (snd (Option.valOf (List.find (fn (x,_)=> x=id) quanConst))
                  handle _ => raise ContextFail 
                  ("semConst.funQuan:  Quantor "^id^" is not defined in exConst.sml"))

	
(* get the infix information of the binary operator *) 

fun checkConst v = 
	let
	fun p (y,_,_,_) = v=y
	in
	case List.find p context of
		  NONE			=> v
		| SOME (_,_,"infix",_)	=> "$"^v
                | SOME (_,_,_,_)        => v
	end
end

(* get the unary and binary operator *)
fun st (x,_,_,_) = x
fun nd (_,x,_,_) = x
fun rd (_,_,x,_) = x
fun th (_,_,_,x) = x

fun funHol opName ty xl = 
	if (List.null xl) 
		   then raise ContextFail 
		        ("semConst: No transformation function for "^opName^" !")
		   else
	case (List.find (fn (x,y,z,_)=> ((TypePara.parseInLine x)=ty orelse x=DEFAULT))  xl)
	 of 
	   NONE   => raise ContextFail 
	              ("(semConst.funHol: No matching type for "
		       ^opName^":"^(TypeLib.toString ty)^" !")
	 | SOME r => let val func = rd r 
	                 val mesg = nd r
	            in 
	               (fn (inl)=>(func inl
			           handle _ => raise ContextFail 
                                             ("semConst: Please consult " ^mesg^ 
					      " library (possible mismatch argument).")))
		    end
	     ;



fun is_visible id = case (List.find (fn (x,_,_,_)=> x=id) context) of
	      NONE   => false                  
	    | SOME _ => true
	
fun funOp id ty = 
	case (List.find (fn (x,_,_,_)=> x=id) context) of
	      NONE => raise ContextFail 
                  ("semConst.funOp:  operator "^id^" is not defined in exConst.sml")
	    | SOME xl => funHol id ty (th xl) 

(* being use for invert function from hol to expr *)



val holcontext = 
    [("RES_qAND"  ,   "!"    ),
     ("RES_qOR"   ,   "?"    ),
     ("AND"       ,   "/\\"  ),
     ("OR"        ,   "\\/"  ),
     ("IMP"       ,   "==>"  ),
     ("EQ"        ,   "="    ),
     ("int_ge"    ,   ">="   ),
     ("int_gt"    ,   ">"    ),
     ("int_le"    ,   "<="   ),
     ("int_lt"    ,   "<"    ),
     ("int_add"   ,   "+"    )
 
    ];


fun holDict str = case (List.find (fn (x,y)=> x=str) holcontext) of
	      NONE => if (exConst.isExists str) then str 
                      else raise ContextFail 
                  ("semConst.holDict:  operator "^str^" is not defined in the context (")
	    | SOME (x,y) => y


fun is_number te = (intLib.is_int_literal te) orelse (Term.is_numeral te)

fun dest_number te = let val ty   = Term.type_of te
		            val tynm = if (ty = Parse.Type`:int`) then "int" 
		                       else if (ty = Parse.Type`:num`) then "num"
		                       else raise Fail "Unrecognized numeral";
		            fun remove_ []      = []
		              | remove_ [#"i"]  = []
		              | remove_ (c::cl) = c::(remove_ cl)
		            fun removeLast str = (String.implode o remove_ o String.explode) str 
		        in ((case tynm of 
		              "num"  => (Arbnum.toString o Term.dest_numeral) te
		            | "int"  => (removeLast o Arbint.toString o intLib.int_of_term) te
		            | _      => raise Fail "Unrecognized numeral")
                            , ty)
		        end
fun inferType ty (ExprDD.Ident (nm,TypeDD.TyVar x)) = ExprDD.Ident (nm,ty)
  | inferType ty  e = e

fun exprConst (oper,ty) expl varl = 
    let val l      = List.length expl
                    (* assumming the last one is the longest one, base on the quantor structure *)
    in
       case l of 
         1 => if (oper=STATEVAR) then (i expl 0)
              else if (oper=CASTOPERATOR) then  inferType ty (i expl 0)
              else ExprDD.Unary ((oper,ty), i expl 0)


       | 2 => if (String.isPrefix "RES" oper) 
	      then ExprDD.Quantor((holDict oper,ty), List.tl varl,i expl 0, i expl 1)
              else ExprDD.Binary((holDict oper,ty), i expl 0, i expl 1) 
       | _ => raise Fail ("exInvers.exprConst: unsupported n-ary operator")
      
    end	       

end


