(* ------------------------------------------------------------------
   an array of some helpful basic rules, conversions, and tactics
   that we use.
------------------------------------------------------------------ *)

structure tacticPL = struct

local open HolKernel BasicProvers Conv Rewrite Tactical Tactic 
	   Drule boolSyntax Parse in

  infix THEN THENL THENC ORELSE ORELSEC THEN_TCL ORELSE_TCL ## |-> ;
  infixr --> ;

  (* open "bossLib" ; *)
 
  open Term ;
  
  fun PRO_COOPER_TAC thms = 
      bossLib.PROVE_TAC (map intLib.COOPER_CONV thms) ;


  fun RESTRICT_DEF_RULE thm = 
      BETA_RULE (REWRITE_RULE [res_quanTheory.RES_FORALL,
                               res_quanTheory.RES_EXISTS] 
                 thm) ;

  val RESTRICT_DEF_TAC  = REWRITE_TAC [res_quanTheory.RES_FORALL,
                                       res_quanTheory.RES_EXISTS] 
                          THEN BETA_TAC ;

  fun RESTRICT_SHIFT thm =
      let 
      val th1 = SPEC_ALL (RESTRICT_DEF_RULE thm) 
      val asm = fst (dest_imp(concl th1)) 
      in
      (GEN_ALL o (DISCH asm) o SPEC_ALL o UNDISCH) th1 
      end ;

  fun IMP_LEFT_RULE thm =
      let 
      val th1 = SPEC_ALL thm 
      val asm = fst (dest_imp(concl th1)) 
      in
      (GEN_ALL o (DISCH asm) o CONJUNCT1 o UNDISCH) th1 
      end ;

  fun IMP_RIGHT_RULE thm =
      let 
      val th1 = SPEC_ALL thm 
      val asm = fst (dest_imp(concl th1)) 
      in
      (GEN_ALL o (DISCH asm) o CONJUNCT2 o UNDISCH) th1 
      end ;

  val IMP_CONJ = bossLib.PROVE [] (Term`!p q r. (p ==> q ==> r) = (p /\ q ==> r)`) ;

  val IMP_CONJ_CONV = REWRITE_CONV [IMP_CONJ] ;

  fun REPEATC_FIN n conv =
      if n = 0 then ALL_CONV
      else conv THENC REPEATC_FIN (n-1) conv ;  

  fun QUAFF_IMP_CONV n =
      REPEATC_FIN n 
        ((ONCE_DEPTH_CONV RIGHT_IMP_FORALL_CONV)
        THENC (ONCE_DEPTH_CONV IMP_CONJ_CONV)) ;

  fun QUAFF_RULE n thm =
      CONV_RULE (QUAFF_IMP_CONV n) (RESTRICT_SHIFT thm) ;

  fun REPEAT_FIN n tac =
      if n=0 then ALL_TAC
      else (tac THEN REPEAT_FIN (n-1) tac) ;

  fun UNDISCH_ALL_TAC (asml,g) =
      if (asml = []) then ALL_TAC (asml,g)
      else (UNDISCH_TAC (hd asml) THEN UNDISCH_ALL_TAC) (asml,g) ;

  val EXT_TAC  =
      let 
      fun EXT_SPEC_TAC (asml,g) = 
            (REWRITE_TAC [FUN_EQ_CONV g] 
            THEN BETA_TAC THEN GEN_TAC) (asml,g) 
      in
      REPEAT GEN_TAC THEN EXT_SPEC_TAC 
      end ;



  fun ASM_TAC rule = EVERY_ASSUM (liteLib.orelsef (ASSUME_TAC o rule,
                                                 (fn thm=> ALL_TAC))) ;

  fun XRULE_ASSUM_TAC rule = RULE_ASSUM_TAC (liteLib.orelsef (rule,I)) ;


  (* remove all assumption *)
  fun DEL_ALL_TAC (asml,gl) =
      if (asml=[]) then ALL_TAC (asml,gl)
      else (POP_ASSUM (fn thm=> ALL_TAC) THEN DEL_ALL_TAC) (asml,gl) ;

  fun DEL_TAC trm =
      UNDISCH_TAC trm THEN DISCH_TAC
      THEN POP_ASSUM (fn thm=> ALL_TAC) ;

  fun EXISTSL_TAC trml = 
      if trml=[] then ALL_TAC 
                 else EXISTS_TAC (hd trml) THEN EXISTSL_TAC (tl trml) ;

  fun MK_ABS_CONV x trm = SYM (BETA_CONV (Parse.Term`(\^x. ^trm) ^x`)) ;


  end

end
