
(*---------------------------------------------------------------------------*
 *       Establish the basic environment.                                    *
 *---------------------------------------------------------------------------*)

open HolKernel Globals;
infix ## |->;
infixr 3 -->;

(*---------------------------------------------------------------------------*
 * Often, people want to use "standard" HOL tools: tactics, conversions,     *
 * rewriting, etc. That's what the next few lines achieve.                   *
 *---------------------------------------------------------------------------*)

open Parse basicHol90Lib goalstackLib Psyntax;

infix THEN THENL THENC ORELSE ORELSEC THEN_TCL ORELSE_TCL;
infix 8 via;


(* PLSEQTheory.sml 
   -------------------------------------------------------------------------*)


val _ = new_theory "PLSEQTheory";

(* Embedding PLSEQ - hoare triple logic in HOL *)


open statePredTheory;

(* general help function *) 
fun dest_word x = if (is_const x) then (dest_const x)
		   else if (is_var x) then (dest_var x)
		   else raise (Fail "this term is not constant nor var");



val HOA_def = Define
  ` HOA (A:^Action) P Q = (!s t. P s /\ A s t ==> Q t)`;


(*-------------------------------------------------------------------
   some basic laws for Hoare triple
---------------------------------------------------------------------*)


(* Preconditioning strengthening *)


val preStrengthening = store_thm
  ("preStrengthening",
 --` (VALID (P IMP (Q:^Pred)) /\ HOA A Q R)
     ==> 
     HOA A P R
   `--,
   REWRITE_TAC [VALID_def,IMP_def,HOA_def]
   THEN BETA_TAC
   THEN PROVE_TAC[]);

val postWeakening = store_thm
  ("postWeakening",
 --`HOA A (P:^Pred) Q /\ VALID (Q IMP R)
    ==>
    HOA A P R
   `--,
   REWRITE_TAC [VALID_def,IMP_def,HOA_def]
   THEN BETA_TAC
   THEN PROVE_TAC[]);

(* Conjuntion *)


val HOA_CONJ = store_thm
  ("HOA_CONJ",
 --`HOA (A:^Action) P1 Q1 /\ HOA A P2 Q2
    ==>
    HOA A (P1 AND P2) (Q1 AND Q2)
   `--,
   REWRITE_TAC [AND_def,HOA_def]
   THEN PROVE_TAC []);
 
(* Disjunction *)


val HOA_DISJ = store_thm
  ("HOA_DISJ",
 --`HOA (A:^Action) P1 Q1 /\ HOA A P2 Q2
    ==>
    HOA A (P1 OR P2) (Q1 OR Q2)
   `--,
   REWRITE_TAC [OR_def,HOA_def]
   THEN PROVE_TAC []);

val HOA_OR = store_thm
  ("HOA_OR",
 --`HOA a (p OR q) (r:^Pred) 
    = 
    HOA a p r /\ HOA a q r`--,
    REWRITE_TAC [HOA_def, OR_def] THEN BETA_TAC
    THEN PROVE_TAC[]) ;

val HOA_basic_defs = 
   [HOA_def,HOA_DISJ, HOA_CONJ,postWeakening,preStrengthening];



(* Defining SKIP, Assignments and Conditionals *)


val SKIP_def = Define 
   `SKIP s (t:^State) = (s = t) `;

val IFTHENELSE_def = Define
  `IFTHENELSE g (A:^Action) B s t
   =
   (g s ==> A s t) /\ (~(g s) ==> B s t)
   `;

val IFTHEN_def = Define
  `IFTHEN g (A:^Action) s t  = IFTHENELSE g A SKIP s t`;

val update_def = Define  
   `(update [] (s:^State) = s) /\ 
         (update (CONS (x:string,Val:'val) r) s 
                	  = update r (\v:string. v=x => Val | s v))
   `;

val ASG_def = Define
   `ASG (x:^Var) (E:^State->'val) (s:^State) (t:^State) 
    = (t = update [(x, E s)] s)`;

(*
[*] make this function polymorfis num -> to 'val again 
*)
val l_asg_def = Define
   `(l_asg [] (s:^State) = []) /\ 
    (l_asg (CONS ((x:^Var), (E:^State->'val)) r) s
			  = (CONS (x, E s) (l_asg r s)))`;

val ASGL_def = Define
   `ASGL l s (t:^State) 
    = (t = (update (l_asg l s) s))`;
	
val _ = Parse.add_infix ("SEQ", 500, HOLgrammars.LEFT);
val SEQ_def = Define 
   `(A:^Action) SEQ B
    =
    (\s (t:^State). (?s'.  A s s' /\ B s' t))
   `; 

(* SUB TASK 3, Basic inference Rules for the Statements *)

val IMP_SKIP_thm = store_thm 
  ("IMP_SKIP_thm",
 --` VALID (P IMP (Q:^Pred)) ==> HOA SKIP P Q `--,
  RW_TAC bool_ss [VALID_def, IMP_def, HOA_def, SKIP_def]
  );

val ifTHEN_thm = store_thm
  ("ifTHEN_thm",
 --` HOA A (P AND G) (Q:^Pred) 
     /\
     VALID ((P AND (NOT G)) IMP Q)
     ==> 
     HOA (ifTHEN G A) P Q
   `--,
   RW_TAC bool_ss (pred_defs @ HOA_basic_defs @
  		   [ifTHENelse_def,ifTHEN_def,SKIP_def])
   THEN PROVE_TAC[]);

val ifTHENelse_thm = store_thm
  ("ifTHENelse_thm",
 --`HOA (A:^Action) (P AND g) Q
    /\
    HOA B (P AND NOT g) Q
    ==> 
    HOA (ifTHENelse g A B) P Q
   `--,
   REWRITE_TAC [HOA_def,ifTHENelse_def,AND_def,NOT_def]
   THEN RW_TAC bool_ss[]
   THEN PROVE_TAC[]
   );

val IFTHENELSE_TAC = MATCH_MP_TAC ifTHENelse_thm;

val ASG_thm = store_thm
  ("ASG_thm",
 --`(!s.P s ==> Q (update [(x,E s) ] s))  
    ==>
    HOA (ASG (x:^Var) (E:^State->'val)) P (Q:^Pred)`--,
    REWRITE_TAC [HOA_def,ASG_def]
    THEN PROVE_TAC[]);


val ASGL_thm = store_thm
  ("ASGL_thm",
 --`(!s.P s ==> Q (update (l_asg L s) s))  
    ==>
    HOA (ASGL (L:(^Var#(^State->'val)) list)) P (Q:^Pred)`--,
    REWRITE_TAC [HOA_def,ASGL_def]
    THEN PROVE_TAC[]);


val SEQ_thm = store_thm
  ("SEQ_thm",
 --`
    (?Q'. HOA A P Q' /\ HOA B Q' Q) 
    ==>
    HOA ((A:^Action) SEQ B) P Q 
`--,

   REWRITE_TAC [HOA_def, SEQ_def]
   THEN BETA_TAC
   THEN PROVE_TAC[]
);



(* Loops *)

(* version 0 *)
val WHILEINV_def = Define
  `WHILEINV g J (A:^Action) s t
   =
   ((HOA A (J AND g) J) /\ J s /\ (J AND NOT g) t)
   `;

val iterate_def = Define
   `(iterate 0 g (A:^Action) s t =  (t=s)) /\
    (iterate (SUC n) (g:^Pred) A s t   
		= (?s'.  A s' t /\ iterate n g A s s' /\ g s' ))`;

(* version 1 *)
val FORLOOP_def = Define
   `FORLOOP (g:^Pred) (J:^Pred) A s t
    = ?n. iterate n g A s t /\ ~(g t) `;

(* version 2 *)
(*
val WHILE_def = Define
   `WHILE (g:^Pred) A s t
    = ?J n. iterate n g A s t `;
*)

(* while basic inference rule *) 
val WHILE_thm = store_thm
  ("WHILE_thm",
 --`
    HOA A (J AND g) (J:^Pred) /\
    VALID ((J AND NOT g) IMP Q) 
    ==>
    HOA (whileDOinv g J A)
	P Q
   `--,
   RW_TAC bool_ss (pred_defs @ HOA_basic_defs @ [whileDOinv_def])
);


(* while maintain the invariant over *)
val WHILE_thm2 = store_thm
  ("WHILE_thm2",
 --`HOA (A:^Action) (J AND g) J
    ==>
    HOA (whileDOinv g J A) J (J AND NOT g)
   `--,
   RW_TAC bool_ss(HOA_basic_defs @ pred_defs @ [whileDOinv_def, iterate_def])
  );


(* SUB TASK 5: Implementing Hoare Logic Rules as HOL Tactics *)


val IFTHENELSE_TAC = MATCH_MP_TAC ifTHENelse_thm;

val SKIP_TAC = MATCH_MP_TAC IMP_SKIP_thm;

val HOA_BASE_TAC = 
    FIRST 
    (map (MATCH_MP_TAC o GEN_ALL)
         [IMP_SKIP_thm, SEQ_thm, ASG_thm, ASGL_thm, ifTHENelse_thm, ifTHEN_thm, 
	  WHILE_thm, WHILE_thm2]);

val HOA_SINGLE_TAC =
    SKIP_TAC ORELSE  
    HOA_BASE_TAC THEN REWRITE_TAC ([update_def] @ pred_defs) 
   		 THEN BETA_TAC THEN BETA_TAC;

(* using HOA_SINGLE_TAC, for single program (without SEQ) *)

(* some  example *)

val ASG_test = prove
  (--`HOA (ASG "x" (\s. (s "x") + 1)) 
	(\s. (s "x") = 0)
	(\t. (t "x") > 0)
     `--,
     HOA_SINGLE_TAC 
     THEN RW_TAC arith_ss[]);


val ifTHENelse_test = prove
  (--`HOA 
	(ifTHENelse
	   (\s. (s "x") = 0)
	   (ASG "x" (\s. (s "x") + 1))
	   (ASG "x" (\s. 1)) )
    	(\s. ((s "x") = 0) \/ ((s "x") = 9) )
        (\s. (s "x") = 1) 
	`--,
	HOA_SINGLE_TAC
	THEN CONJ_TAC
	THEN HOA_SINGLE_TAC
	THEN RW_TAC arith_ss[]);



val ifTHEN_test = prove
 (--` HOA 
	(ifTHEN
	   (\s. (s "x") = 0)
	   (ASG "x" (\s. (s "x") + 1) ) )
	(\s. (s "x") = 0)
	(\s. ~( (s "x") = 0) )
	`--,
	HOA_SINGLE_TAC
	THEN CONJ_TAC
	THENL
	[ HOA_SINGLE_TAC THEN RW_TAC arith_ss[],
	  RW_TAC arith_ss[]
	]);


val WHILE_test = prove
 (--`HOA
      (whileDOinv (\s. (s "i") < 3)  
		  (\s. (s "i") > 0)
		  (ASG "i" (\s. (s "i") + 1)) )
 	(\s. ((s "i") = 1))
	(\t. ((t "i") > 2))
     `--,
     HOA_SINGLE_TAC 
     THEN REPEAT (CONJ_TAC)
     THEN TRY (HOA_SINGLE_TAC)
     THEN TRY (RW_TAC arith_ss[])
     );



(* SUB TASK 6: Automating Hoare Triple Decomposition *)

(* Checking function *)


fun isSKIP t	= 
    (fst o dest_word) t = "SKIP"
    handle _ => false;
		
fun isASG t 	= 
    fst (dest_word (rator (rator t))) = "ASG"
    handle _ => false;

fun isASGL t 	= 
    fst (dest_word  (rator t)) = "ASGL"
    handle _ => false;

fun isTHEN t 	= 
    fst ((dest_word o rator o rator) t) = "ifTHEN"
    handle _ => false;

fun isTHENelse t	= 
    fst ((dest_const o rator o rator o rator) t) = "ifTHENelse"
    handle _ => false;

fun is_THEN t	= 
    (fst o dest_const o rator) t = "ifTHENelse"
    handle _ => false;

fun isWHILE t 	= 
    fst ((dest_const o rator o rator o rator) t) = "whileDOinv"
    handle _ => false;

fun isSEQ t 	= 
    fst ((dest_const o rator o rator) t) = "SEQ"
    handle _ => false;

(* grab the argument  *)

fun dest_ASG t 	=
    (rand (rator t), rand t);

fun dest_ASGL t =
    (rand t);

fun dest_THEN t =
    (rand (rator t), rand t);

fun dest_THENelse t =
    (rand (rator (rator t)), rand (rator t), rand t);

fun dest_WHILE t =
    (rand (rator (rator t)), rand (rator t), rand t);

fun dest_SEQ t = 
    (rand (rator t), rand t);

fun dest_HOA t = 
    (rand (rator (rator t)), rand (rator t), rand t);

fun WP t Q     =
    
    if isSEQ t then 
	let val (A,B) = dest_SEQ t
	in WP A (WP B Q) end
    else if isASG t then
	let 
	val (x,E) = dest_ASG t 
	in (--`(\s. ^Q (update [(^x, ^E s)] s))`--)
	end

    else if isASGL t then
	let 
	val L = dest_ASGL t 
	in (--`(\s. ^Q (update (l_asg L s) s))`--)
	end

    else if isTHENelse t then 
	let 
	val (g, A, B) = dest_THENelse t
	in 
	(--`(^g IMP ^(WP A Q)) AND
	    (NOT ^g IMP ^(WP B Q))`--)
	end 

    else if isTHEN t then 
	let 
	val (g, A) = dest_THEN t
	in 
	(--`(^g IMP ^(WP A Q)) AND
	    (NOT ^g IMP ^Q)`--)
	end 

    else if isWHILE t then 
	let 
	val (g, J, A) = dest_WHILE t
	in J
	end

    else Q;

(* end of fun WP *)

fun SEQ_TAC (asml, h) =

   let 
   val (A, P, Q) = dest_HOA h
     in
     if isSEQ A then

	let
	val (B, C) = dest_SEQ A
	val   Q'   = WP C Q
	in 
	(MATCH_MP_TAC (GEN_ALL SEQ_thm)
 	 THEN EXISTS_TAC Q' )
	(asml, h)
	
	end
      else NO_TAC (asml, h)
   end;

val HOA_TAC
    = SEQ_TAC ORELSE HOA_SINGLE_TAC;

val WHILE_thm3 = store_thm
  ("WHILE_thm3",
 --`
    HOA A P J 			/\
    HOA B (J AND g) (J:^Pred) 	/\
    VALID ((J AND NOT g) IMP Q) 
    ==>
    HOA (A SEQ (whileDOinv g J B))
	P Q
   `--,
   RW_TAC bool_ss (pred_defs @ HOA_basic_defs @ 
	[whileDOinv_def,SEQ_def, SEQ_thm, 
	 WHILE_thm, WHILE_thm2])
   THEN PROVE_TAC[]
); 


val hoare_phase1_TAC = 
    FIRST 
    (map (MATCH_MP_TAC o GEN_ALL)
         [IMP_SKIP_thm, SEQ_thm, ASG_thm, ASGL_thm, ifTHENelse_thm, ifTHEN_thm,
	  WHILE_thm, WHILE_thm2,WHILE_thm3]);

(* redefine the tactic *)

val HOA_SINGLE_TAC =
    SKIP_TAC ORELSE  
    hoare_phase1_TAC THEN REWRITE_TAC ([update_def,l_asg_def] @ pred_defs) 
   		 THEN BETA_TAC THEN BETA_TAC;


val HOA_TAC
    = SEQ_TAC ORELSE HOA_SINGLE_TAC;

	

val SEQ_test1 = prove
  (--`HOA 
	( (ASG "x" (\s. (s "x") + 1)) 
	  SEQ
 	  (ASG "x" (\s. (s "x") - 1)) )
  	(\s. (s "x") = 0)
	(\t. (t "x") = 0)
     `--,
     HOA_TAC 
     THEN CONJ_TAC 
     THEN HOA_TAC 
     THEN RW_TAC arith_ss[] );


val WHILE_SEQ_test = prove
 (--`HOA
       (
        (ASG "i" (\s. 1))
	SEQ
        (whileDOinv (\s. (s "i") < 3)  
		  (\s. (s "i") > 0)
		  (ASG "i" (\s. (s "i") + 1)) ))
 	(True)
	(\t. ((t "i") > 2))
      
     `--,
     TRY HOA_TAC 
     THEN TRY (REPEAT (CONJ_TAC))
     THEN TRY (HOA_TAC)
     THEN TRY (REPEAT CONJ_TAC)
     THEN TRY (HOA_TAC)
     THEN TRY (RW_TAC arith_ss[])
     );

val WHILE_SEQ_test2 = prove
 (--`HOA
       (
        (ASGL [("i",(\s. 1))])
	SEQ
        (whileDOinv (\s. (s "i") < 3)  
		  (\s. (s "i") > 0)
		  (ASG "i" (\s. (s "i") + 1)) ))
 	(True)
	(\t. ((t "i") > 2))
      
     `--,
     TRY HOA_TAC 
     THEN TRY (REPEAT (CONJ_TAC))
     THEN TRY (HOA_TAC)
     THEN TRY (REPEAT CONJ_TAC)
     THEN TRY (HOA_TAC) 
     THEN TRY (RW_TAC arith_ss[])
     );

val SIMP_HOA_TAC = REPEAT (HOA_TAC THEN (TRY CONJ_TAC));
  
(* proving using more automated tactic *)

val WHILE_SEQ_test1 = prove
 (--`HOA
       (
        (ASG "i" (\s. 1) )
	SEQ
        (whileDOinv (\s. (s "i") < 3)  
		  (\s. (s "i") > 0)
		  (ASG "i" (\s. (s "i") + 1) ) ))
 	(True)
	(\t. ((t "i") > 2))
     `--,
     SIMP_HOA_TAC
     THEN RW_TAC arith_ss[]
     );


val WHILE_SEQ_test2 = prove
 (--`HOA
       (
        (ASGL [("i", (\s. 1))])
	SEQ
        (whileDOinv (\s. (s "i") < 3)  
		  (\s. (s "i") > 0)
		  (ASGL [ ("i",(\s. (s "i") + 1)) ]) ))
 	(True)
	(\t. ((t "i") > 2))
     `--,
     SIMP_HOA_TAC
     THEN RW_TAC arith_ss[]
     );


val _ = export_theory() ; 

